<?php
require_once 'config/config.php';
require_once 'models/TipoInspeccion.php';

requireLogin();

// Solo administradores pueden acceder
if (!isAdmin()) {
    header('Location: dashboard.php');
    exit();
}

$tipoInspeccion = new TipoInspeccion();
$tipos = $tipoInspeccion->getAll();

$message = '';
$message_type = '';

// Procesar acciones
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        if (isset($_POST['action'])) {
            switch ($_POST['action']) {
                case 'create':
                    $data = [
                        'nombre' => cleanInput($_POST['nombre']),
                        'descripcion' => cleanInput($_POST['descripcion']),
                        'activo' => isset($_POST['activo']) ? 1 : 0
                    ];
                    
                    if ($tipoInspeccion->create($data)) {
                        $message = 'Tipo de inspección creado exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al crear el tipo de inspección';
                        $message_type = 'danger';
                    }
                    break;
                    
                case 'update':
                    $data = [
                        'nombre' => cleanInput($_POST['nombre']),
                        'descripcion' => cleanInput($_POST['descripcion']),
                        'activo' => isset($_POST['activo']) ? 1 : 0
                    ];
                    
                    if ($tipoInspeccion->update($_POST['id'], $data)) {
                        $message = 'Tipo de inspección actualizado exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al actualizar el tipo de inspección';
                        $message_type = 'danger';
                    }
                    break;
                    
                case 'toggle_status':
                    $tipo = $tipoInspeccion->getById($_POST['id']);
                    if ($tipo) {
                        $nuevo_estado = $tipo['activo'] ? 0 : 1;
                        if ($tipoInspeccion->update($_POST['id'], ['activo' => $nuevo_estado])) {
                            $message = 'Estado actualizado exitosamente';
                            $message_type = 'success';
                        } else {
                            $message = 'Error al actualizar el estado';
                            $message_type = 'danger';
                        }
                    }
                    break;
                    
                case 'duplicate':
                    $nuevo_nombre = cleanInput($_POST['nuevo_nombre']);
                    if ($tipoInspeccion->duplicar($_POST['id'], $nuevo_nombre)) {
                        $message = 'Tipo de inspección duplicado exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al duplicar el tipo de inspección';
                        $message_type = 'danger';
                    }
                    break;
                    
                case 'delete':
                    if ($tipoInspeccion->delete($_POST['id'])) {
                        $message = 'Tipo de inspección eliminado exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al eliminar el tipo de inspección';
                        $message_type = 'danger';
                    }
                    break;
            }
        }
        
        // Recargar datos
        $tipos = $tipoInspeccion->getAll();
        
    } catch (Exception $e) {
        $message = 'Error: ' . $e->getMessage();
        $message_type = 'danger';
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Administrar Inspecciones - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary: #0070f3;
            --success: #00d084;
            --warning: #f5a623;
            --danger: #e00;
            --gray-50: #fafafa;
            --gray-100: #f4f4f5;
            --gray-200: #e4e4e7;
            --gray-300: #d4d4d8;
            --gray-600: #52525b;
            --gray-700: #3f3f46;
            --gray-900: #18181b;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
            background-color: var(--gray-50);
            color: var(--gray-900);
        }

        .header {
            background: white;
            border-bottom: 1px solid var(--gray-200);
            padding: 1rem 0;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
        }

        .main-container {
            max-width: 1400px;
            margin: 0 auto;
            padding: 2rem 1rem;
        }

        .card {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 12px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
            margin-bottom: 1.5rem;
            transition: all 0.2s;
        }

        .card:hover {
            box-shadow: 0 4px 12px rgba(0,0,0,0.15);
        }

        .card-header {
            padding: 1.5rem;
            border-bottom: 1px solid var(--gray-200);
            background-color: var(--gray-50);
        }

        .card-body {
            padding: 1.5rem;
        }

        .btn {
            padding: 0.5rem 1rem;
            border: none;
            border-radius: 6px;
            font-weight: 500;
            cursor: pointer;
            transition: all 0.2s;
            text-decoration: none;
            display: inline-flex;
            align-items: center;
            gap: 0.5rem;
        }

        .btn-primary {
            background: var(--primary);
            color: white;
        }

        .btn-success {
            background: var(--success);
            color: white;
        }

        .btn-warning {
            background: var(--warning);
            color: white;
        }

        .btn-danger {
            background: var(--danger);
            color: white;
        }

        .btn-outline-primary {
            border: 1px solid var(--primary);
            color: var(--primary);
            background: transparent;
        }

        .btn-outline-secondary {
            border: 1px solid var(--gray-300);
            color: var(--gray-700);
            background: transparent;
        }

        .btn-outline-success {
            border: 1px solid var(--success);
            color: var(--success);
            background: transparent;
        }

        .btn-outline-warning {
            border: 1px solid var(--warning);
            color: var(--warning);
            background: transparent;
        }

        .btn-outline-danger {
            border: 1px solid var(--danger);
            color: var(--danger);
            background: transparent;
        }

        .btn-sm {
            padding: 0.375rem 0.75rem;
            font-size: 0.875rem;
        }

        .status-badge {
            padding: 0.25rem 0.75rem;
            border-radius: 12px;
            font-size: 0.75rem;
            font-weight: 600;
            text-transform: uppercase;
        }

        .status-active {
            background: rgba(0, 208, 132, 0.1);
            color: var(--success);
        }

        .status-inactive {
            background: var(--gray-100);
            color: var(--gray-600);
        }

        .tipo-card {
            border-left: 4px solid var(--primary);
        }

        .tipo-card.inactive {
            border-left-color: var(--gray-300);
            opacity: 0.7;
        }

        .stats-badge {
            background: var(--gray-100);
            color: var(--gray-700);
            padding: 0.25rem 0.5rem;
            border-radius: 6px;
            font-size: 0.75rem;
            font-weight: 500;
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="header">
        <div class="container-fluid">
            <div class="d-flex justify-content-between align-items-center">
                <a href="dashboard.php" class="text-decoration-none text-dark fw-bold">
                    <i class="fas fa-fire-extinguisher me-2"></i>
                    <?php echo APP_NAME; ?>
                </a>
                <div>
                    <a href="dashboard.php" class="btn btn-outline-secondary btn-sm">
                        <i class="fas fa-home"></i> Dashboard
                    </a>
                </div>
            </div>
        </div>
    </header>

    <div class="main-container">
        <!-- Alert -->
        <?php if ($message): ?>
            <div class="alert alert-<?php echo $message_type; ?> alert-dismissible fade show" role="alert">
                <i class="fas fa-<?php echo $message_type === 'success' ? 'check-circle' : 'exclamation-triangle'; ?> me-2"></i>
                <?php echo $message; ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
            </div>
        <?php endif; ?>

        <!-- Page Header -->
        <div class="d-flex justify-content-between align-items-center mb-4">
            <div>
                <h1 class="h3 mb-1">Administrar Tipos de Inspección</h1>
                <p class="text-muted mb-0">Gestiona los diferentes tipos de inspecciones disponibles en el sistema</p>
            </div>
            <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#createTipoModal">
                <i class="fas fa-plus"></i> Nuevo Tipo
            </button>
        </div>

        <!-- Tipos de Inspección -->
        <?php if (empty($tipos)): ?>
            <div class="card">
                <div class="card-body text-center py-5">
                    <i class="fas fa-clipboard-list fa-4x text-muted mb-3"></i>
                    <h5 class="text-muted">No hay tipos de inspección configurados</h5>
                    <p class="text-muted">Crea el primer tipo de inspección para comenzar</p>
                    <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#createTipoModal">
                        <i class="fas fa-plus me-2"></i>Crear Primer Tipo
                    </button>
                </div>
            </div>
        <?php else: ?>
            <div class="row">
                <?php foreach ($tipos as $tipo): ?>
                    <div class="col-md-6 col-lg-4 mb-4">
                        <div class="card tipo-card <?php echo !$tipo['activo'] ? 'inactive' : ''; ?>">
                            <div class="card-body">
                                <div class="d-flex justify-content-between align-items-start mb-3">
                                    <div class="flex-grow-1">
                                        <h5 class="card-title mb-1">
                                            <?php echo htmlspecialchars($tipo['nombre']); ?>
                                        </h5>
                                        <p class="card-text text-muted small mb-2">
                                            <?php echo htmlspecialchars($tipo['descripcion'] ?? 'Sin descripción'); ?>
                                        </p>
                                    </div>
                                    <span class="status-badge <?php echo $tipo['activo'] ? 'status-active' : 'status-inactive'; ?>">
                                        <?php echo $tipo['activo'] ? 'Activo' : 'Inactivo'; ?>
                                    </span>
                                </div>

                                <!-- Estadísticas -->
                                <div class="d-flex gap-2 mb-3">
                                    <?php
                                    $secciones = $tipoInspeccion->getSecciones($tipo['id']);
                                    $elementos = $tipoInspeccion->getElementos($tipo['id']);
                                    ?>
                                    <span class="stats-badge">
                                        <i class="fas fa-layer-group me-1"></i>
                                        <?php echo count($secciones); ?> secciones
                                    </span>
                                    <span class="stats-badge">
                                        <i class="fas fa-question-circle me-1"></i>
                                        <?php echo count($elementos); ?> preguntas
                                    </span>
                                </div>

                                <!-- Acciones -->
                                <div class="d-flex gap-1 flex-wrap">
                                    <a href="admin_elementos.php?tipo_id=<?php echo $tipo['id']; ?>" 
                                       class="btn btn-primary btn-sm">
                                        <i class="fas fa-cog"></i> Configurar
                                    </a>
                                    <button type="button" class="btn btn-outline-primary btn-sm" 
                                            onclick="editarTipo(<?php echo htmlspecialchars(json_encode($tipo)); ?>)">
                                        <i class="fas fa-edit"></i> Editar
                                    </button>
                                    <button type="button" class="btn btn-outline-<?php echo $tipo['activo'] ? 'warning' : 'success'; ?> btn-sm" 
                                            onclick="toggleStatus(<?php echo $tipo['id']; ?>, '<?php echo htmlspecialchars($tipo['nombre']); ?>', <?php echo $tipo['activo']; ?>)">
                                        <i class="fas fa-<?php echo $tipo['activo'] ? 'pause' : 'play'; ?>"></i>
                                        <?php echo $tipo['activo'] ? 'Desactivar' : 'Activar'; ?>
                                    </button>
                                    <div class="btn-group">
                                        <button type="button" class="btn btn-outline-secondary btn-sm dropdown-toggle" 
                                                data-bs-toggle="dropdown">
                                            <i class="fas fa-ellipsis-h"></i>
                                        </button>
                                        <ul class="dropdown-menu">
                                            <li>
                                                <a class="dropdown-item" href="#" 
                                                   onclick="duplicarTipo(<?php echo $tipo['id']; ?>, '<?php echo htmlspecialchars($tipo['nombre']); ?>')">
                                                    <i class="fas fa-copy me-2"></i>Duplicar
                                                </a>
                                            </li>
                                            <li><hr class="dropdown-divider"></li>
                                            <li>
                                                <a class="dropdown-item text-danger" href="#" 
                                                   onclick="eliminarTipo(<?php echo $tipo['id']; ?>, '<?php echo htmlspecialchars($tipo['nombre']); ?>')">
                                                    <i class="fas fa-trash me-2"></i>Eliminar
                                                </a>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>
    </div>

    <!-- Create Modal -->
    <div class="modal fade" id="createTipoModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST">
                    <div class="modal-header">
                        <h5 class="modal-title">
                            <i class="fas fa-plus me-2"></i>Nuevo Tipo de Inspección
                        </h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="action" value="create">
                        
                        <div class="mb-3">
                            <label class="form-label">Nombre *</label>
                            <input type="text" class="form-control" name="nombre" required 
                                   placeholder="Ej: Extintores, Rociadores, Alarmas...">
                        </div>
                        
                        <div class="mb-3">
                            <label class="form-label">Descripción</label>
                            <textarea class="form-control" name="descripcion" rows="3" 
                                      placeholder="Descripción del tipo de inspección..."></textarea>
                        </div>
                        
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="activo" id="activo_create" checked>
                            <label class="form-check-label" for="activo_create">
                                Tipo activo (visible para crear inspecciones)
                            </label>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                        <button type="submit" class="btn btn-primary">
                            <i class="fas fa-save me-2"></i>Crear Tipo
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Edit Modal -->
    <div class="modal fade" id="editTipoModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST">
                    <div class="modal-header">
                        <h5 class="modal-title">
                            <i class="fas fa-edit me-2"></i>Editar Tipo de Inspección
                        </h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="action" value="update">
                        <input type="hidden" name="id" id="edit_id">
                        
                        <div class="mb-3">
                            <label class="form-label">Nombre *</label>
                            <input type="text" class="form-control" name="nombre" id="edit_nombre" required>
                        </div>
                        
                        <div class="mb-3">
                            <label class="form-label">Descripción</label>
                            <textarea class="form-control" name="descripcion" id="edit_descripcion" rows="3"></textarea>
                        </div>
                        
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="activo" id="edit_activo">
                            <label class="form-check-label" for="edit_activo">
                                Tipo activo (visible para crear inspecciones)
                            </label>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                        <button type="submit" class="btn btn-primary">
                            <i class="fas fa-save me-2"></i>Actualizar
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Duplicate Modal -->
    <div class="modal fade" id="duplicateTipoModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST">
                    <div class="modal-header">
                        <h5 class="modal-title">
                            <i class="fas fa-copy me-2"></i>Duplicar Tipo de Inspección
                        </h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="action" value="duplicate">
                        <input type="hidden" name="id" id="duplicate_id">
                        
                        <div class="alert alert-info">
                            <i class="fas fa-info-circle me-2"></i>
                            Se duplicará el tipo "<strong id="duplicate_original_name"></strong>" con todas sus secciones y elementos.
                        </div>
                        
                        <div class="mb-3">
                            <label class="form-label">Nombre del nuevo tipo *</label>
                            <input type="text" class="form-control" name="nuevo_nombre" id="duplicate_nuevo_nombre" required 
                                   placeholder="Nombre para la copia...">
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                        <button type="submit" class="btn btn-warning">
                            <i class="fas fa-copy me-2"></i>Duplicar
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function editarTipo(tipo) {
            document.getElementById('edit_id').value = tipo.id;
            document.getElementById('edit_nombre').value = tipo.nombre;
            document.getElementById('edit_descripcion').value = tipo.descripcion || '';
            document.getElementById('edit_activo').checked = tipo.activo == 1;
            
            new bootstrap.Modal(document.getElementById('editTipoModal')).show();
        }

        function toggleStatus(id, nombre, activo) {
            const accion = activo ? 'desactivar' : 'activar';
            if (confirm(`¿Estás seguro de ${accion} el tipo "${nombre}"?`)) {
                const form = document.createElement('form');
                form.method = 'POST';
                form.innerHTML = `
                    <input type="hidden" name="action" value="toggle_status">
                    <input type="hidden" name="id" value="${id}">
                `;
                document.body.appendChild(form);
                form.submit();
            }
        }

        function duplicarTipo(id, nombre) {
            document.getElementById('duplicate_id').value = id;
            document.getElementById('duplicate_original_name').textContent = nombre;
            document.getElementById('duplicate_nuevo_nombre').value = nombre + ' (Copia)';
            
            new bootstrap.Modal(document.getElementById('duplicateTipoModal')).show();
        }

        function eliminarTipo(id, nombre) {
            if (confirm(`¿Estás seguro de eliminar el tipo "${nombre}"? Esta acción no se puede deshacer.`)) {
                const form = document.createElement('form');
                form.method = 'POST';
                form.innerHTML = `
                    <input type="hidden" name="action" value="delete">
                    <input type="hidden" name="id" value="${id}">
                `;
                document.body.appendChild(form);
                form.submit();
            }
        }
    </script>
</body>
</html>
