<?php
require_once 'config/config.php';

requireLogin();

// Solo admin puede aprobar
if (!isAdmin()) {
    header('Location: dashboard.php?error=sin_permisos');
    exit();
}

if (!isset($_GET['id'])) {
    header('Location: inspecciones.php?error=id_requerido');
    exit();
}

$inspeccion_id = (int)$_GET['id'];

// Conexión directa a la base de datos
try {
    $pdo = new PDO("mysql:host=localhost;dbname=sistema_inspeccion;charset=utf8", "root", "");
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    
    // Obtener datos de la inspección
    $stmt = $pdo->prepare("SELECT * FROM inspecciones WHERE id = ?");
    $stmt->execute([$inspeccion_id]);
    $inspeccion = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$inspeccion) {
        header('Location: inspecciones.php?error=inspeccion_no_encontrada');
        exit();
    }
    
    if ($inspeccion['estado'] !== 'completada') {
        header('Location: inspecciones.php?error=solo_completadas');
        exit();
    }
    
    $mensaje = '';
    $error = '';
    
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $accion = $_POST['accion'] ?? '';
        
        if ($accion === 'aprobar') {
            try {
                // Verificar primero si el campo acepta 'aprobada'
                $stmt = $pdo->query("SHOW COLUMNS FROM inspecciones LIKE 'estado'");
                $campo_estado = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if ($campo_estado && strpos($campo_estado['Type'], 'enum') !== false) {
                    // Es ENUM, verificar si incluye 'aprobada'
                    preg_match_all("/'([^']+)'/", $campo_estado['Type'], $matches);
                    $valores_permitidos = $matches[1];
                    
                    if (!in_array('aprobada', $valores_permitidos)) {
                        $error = "El campo 'estado' no permite el valor 'aprobada'. Valores permitidos: " . implode(', ', $valores_permitidos);
                        $error .= "<br><br><a href='fix_estado_campo.php' class='btn btn-warning btn-sm'>🔧 Reparar Campo Estado</a>";
                    } else {
                        // ENUM incluye 'aprobada', proceder
                        $stmt = $pdo->prepare("UPDATE inspecciones SET estado = 'aprobada' WHERE id = ? AND estado = 'completada'");
                        if ($stmt->execute([$inspeccion_id])) {
                            header('Location: inspecciones.php?success=inspeccion_aprobada');
                            exit();
                        } else {
                            $error = 'Error al aprobar la inspección';
                        }
                    }
                } else {
                    // No es ENUM, proceder normalmente
                    $stmt = $pdo->prepare("UPDATE inspecciones SET estado = 'aprobada' WHERE id = ? AND estado = 'completada'");
                    if ($stmt->execute([$inspeccion_id])) {
                        header('Location: inspecciones.php?success=inspeccion_aprobada');
                        exit();
                    } else {
                        $error = 'Error al aprobar la inspección';
                    }
                }
            } catch (Exception $e) {
                $error = 'Error al aprobar: ' . $e->getMessage();
                if (strpos($e->getMessage(), 'Data truncated') !== false) {
                    $error .= "<br><br>🔧 <strong>Solución:</strong> <a href='fix_estado_campo.php' class='btn btn-warning btn-sm'>Reparar Campo Estado</a>";
                }
            }
        } elseif ($accion === 'rechazar') {
            // Rechazar y devolver a borrador
            $stmt = $pdo->prepare("UPDATE inspecciones SET estado = 'borrador' WHERE id = ? AND estado = 'completada'");
            if ($stmt->execute([$inspeccion_id])) {
                header('Location: inspecciones.php?success=inspeccion_rechazada');
                exit();
            } else {
                $error = 'Error al rechazar la inspección';
            }
        }
    }
    
} catch (Exception $e) {
    $error = 'Error de conexión: ' . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Aprobar Inspección Simple #<?php echo $inspeccion_id; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
</head>
<body class="bg-light">
    <div class="container py-5">
        <div class="row justify-content-center">
            <div class="col-md-8">
                <div class="card">
                    <div class="card-header bg-primary text-white">
                        <h4 class="mb-0">
                            <i class="fas fa-clipboard-check me-2"></i>
                            Aprobar Inspección #<?php echo $inspeccion_id; ?>
                        </h4>
                    </div>
                    <div class="card-body">
                        <?php if ($error): ?>
                        <div class="alert alert-danger">
                            <i class="fas fa-exclamation-triangle me-2"></i>
                            <?php echo $error; ?>
                        </div>
                        <?php endif; ?>
                        
                        <div class="row mb-4">
                            <div class="col-md-6">
                                <h5>📋 Información de la Inspección</h5>
                                <p><strong>ID:</strong> <?php echo $inspeccion['id']; ?></p>
                                <p><strong>Estado Actual:</strong> 
                                    <span class="badge bg-warning"><?php echo ucfirst($inspeccion['estado']); ?></span>
                                </p>
                                <p><strong>Fecha:</strong> <?php echo date('d/m/Y', strtotime($inspeccion['fecha_inspeccion'])); ?></p>
                                <p><strong>Contrato:</strong> <?php echo htmlspecialchars($inspeccion['numero_contrato'] ?? 'N/A'); ?></p>
                            </div>
                            <div class="col-md-6">
                                <h5>🎯 Acciones Disponibles</h5>
                                <p>Esta inspección está completada y lista para revisión.</p>
                                <p>Puedes aprobarla o rechazarla para que vuelva a borrador.</p>
                                
                                <?php if ($error && strpos($error, 'estado') !== false): ?>
                                <div class="alert alert-warning">
                                    <h6>🔧 Problema Detectado:</h6>
                                    <p>El campo 'estado' necesita ser reparado para permitir aprobaciones.</p>
                                    <a href="fix_estado_campo.php" class="btn btn-warning btn-sm">
                                        <i class="fas fa-wrench me-1"></i>Reparar Ahora
                                    </a>
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        
                        <?php if (!$error || strpos($error, 'estado') === false): ?>
                        <div class="row">
                            <div class="col-md-6">
                                <div class="card bg-success text-white">
                                    <div class="card-body text-center">
                                        <h5><i class="fas fa-check-circle me-2"></i>Aprobar</h5>
                                        <p>La inspección cumple con los estándares</p>
                                        <form method="POST" style="display: inline;">
                                            <input type="hidden" name="accion" value="aprobar">
                                            <button type="submit" class="btn btn-light" 
                                                    onclick="return confirm('¿Aprobar esta inspección?')">
                                                <i class="fas fa-check me-2"></i>Aprobar
                                            </button>
                                        </form>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="card bg-danger text-white">
                                    <div class="card-body text-center">
                                        <h5><i class="fas fa-times-circle me-2"></i>Rechazar</h5>
                                        <p>Devolver a borrador para correcciones</p>
                                        <form method="POST" style="display: inline;">
                                            <input type="hidden" name="accion" value="rechazar">
                                            <button type="submit" class="btn btn-light" 
                                                    onclick="return confirm('¿Rechazar y devolver a borrador?')">
                                                <i class="fas fa-times me-2"></i>Rechazar
                                            </button>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endif; ?>
                        
                        <div class="text-center mt-4">
                            <a href="ver_inspeccion.php?id=<?php echo $inspeccion_id; ?>" class="btn btn-outline-primary me-2">
                                <i class="fas fa-eye me-2"></i>Ver Detalles
                            </a>
                            <a href="inspecciones.php" class="btn btn-outline-secondary">
                                <i class="fas fa-arrow-left me-2"></i>Volver
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</body>
</html>
