<?php
// Habilitar reporte de errores para debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Debug de inicio
echo "<!-- Debug: Iniciando dashboard -->";

require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/Inmueble.php';
require_once 'models/User.php';

requireLogin();

$inspeccion = new Inspeccion();
$inmueble = new Inmueble();
$user = new User();

// Obtener datos del usuario actual con manejo de errores
try {
    $userData = $user->getById($_SESSION['user_id']);
    echo "<!-- Debug: Usuario obtenido correctamente -->";
} catch (Exception $e) {
    echo "<!-- Debug Error: " . $e->getMessage() . " -->";
    $userData = ['foto_perfil' => null];
}

// Obtener foto de perfil de forma segura
$foto_perfil = isset($userData['foto_perfil']) ? $userData['foto_perfil'] : null;

// Obtener estadísticas con manejo de errores
try {
    $inspecciones_recientes = $inspeccion->getAll();
    $total_inspecciones = count($inspecciones_recientes);
    echo "<!-- Debug: " . $total_inspecciones . " inspecciones encontradas -->";
} catch (Exception $e) {
    echo "<!-- Debug Error inspecciones: " . $e->getMessage() . " -->";
    $inspecciones_recientes = [];
    $total_inspecciones = 0;
}

try {
    $inmuebles = $inmueble->getAll();
    $total_inmuebles = count($inmuebles);
    echo "<!-- Debug: " . $total_inmuebles . " inmuebles encontrados -->";
} catch (Exception $e) {
    echo "<!-- Debug Error inmuebles: " . $e->getMessage() . " -->";
    $inmuebles = [];
    $total_inmuebles = 0;
}

// Estadísticas por estado
$stats = [
    'total' => 0,
    'completadas' => 0,
    'borradores' => 0,
    'aprobadas' => 0
];

// Estadísticas por mes (últimos 6 meses)
$stats_mensuales = [];
$meses = ['Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun'];
for ($i = 5; $i >= 0; $i--) {
    $fecha = date('Y-m', strtotime("-$i months"));
    $stats_mensuales[$fecha] = 0;
}

foreach ($inspecciones_recientes as $insp) {
    $stats['total']++;
    if ($insp['estado'] === 'completada') {
        $stats['completadas']++;
    } elseif ($insp['estado'] === 'borrador') {
        $stats['borradores']++;
    } elseif ($insp['estado'] === 'aprobada') {
        $stats['aprobadas']++;
    }
    
    // Contar por mes
    $mes_inspeccion = date('Y-m', strtotime($insp['fecha_inspeccion']));
    if (isset($stats_mensuales[$mes_inspeccion])) {
        $stats_mensuales[$mes_inspeccion]++;
    }
}

// Limitar inspecciones recientes a las últimas 5
$inspecciones_recientes = array_slice($inspecciones_recientes, 0, 5);
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard - <?php echo APP_NAME; ?></title>
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700;800&display=swap" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        :root {
            --primary: #3b82f6;
            --primary-dark: #2563eb;
            --primary-light: #dbeafe;
            --success: #10b981;
            --success-light: #d1fae5;
            --warning: #f59e0b;
            --warning-light: #fef3c7;
            --danger: #ef4444;
            --danger-light: #fee2e2;
            --purple: #8b5cf6;
            --purple-light: #ede9fe;
            --gray-50: #f9fafb;
            --gray-100: #f3f4f6;
            --gray-200: #e5e7eb;
            --gray-300: #d1d5db;
            --gray-400: #9ca3af;
            --gray-500: #6b7280;
            --gray-600: #4b5563;
            --gray-700: #374151;
            --gray-800: #1f2937;
            --gray-900: #111827;
            --white: #ffffff;
            --shadow-sm: 0 1px 2px 0 rgb(0 0 0 / 0.05);
            --shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);
            --shadow-md: 0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);
            --shadow-lg: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);
            --shadow-xl: 0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1);
        }

        * {
            box-sizing: border-box;
            margin: 0;
            padding: 0;
        }

        body {
            font-family: 'Inter', -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            min-height: 100vh;
            color: var(--gray-900);
            line-height: 1.6;
        }

        /* Header */
        .header {
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border-bottom: 1px solid rgba(255, 255, 255, 0.2);
            padding: 1rem 0;
            position: sticky;
            top: 0;
            z-index: 50;
            box-shadow: var(--shadow-sm);
        }

        .header-content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 0 1.5rem;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .logo {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            font-weight: 700;
            font-size: 1.25rem;
            color: var(--gray-900);
            text-decoration: none;
            transition: all 0.2s ease;
        }

        .logo:hover {
            color: var(--primary);
            transform: translateY(-1px);
        }

        .logo i {
            font-size: 1.5rem;
            color: var(--primary);
        }

        .user-menu {
            display: flex;
            align-items: center;
            gap: 1rem;
        }

        .user-info {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            padding: 0.5rem 1rem;
            background: var(--gray-50);
            border-radius: 50px;
            border: 1px solid var(--gray-200);
        }

        .user-avatar {
            width: 36px;
            height: 36px;
            border-radius: 50%;
            object-fit: cover;
            border: 2px solid var(--primary-light);
        }

        .user-avatar-placeholder {
            width: 36px;
            height: 36px;
            border-radius: 50%;
            background: linear-gradient(135deg, var(--primary), var(--primary-dark));
            display: flex;
            align-items: center;
            justify-content: center;
            color: white;
            font-size: 0.875rem;
            font-weight: 600;
        }

        .user-details {
            display: flex;
            flex-direction: column;
            gap: 0.125rem;
        }

        .user-name {
            font-weight: 600;
            font-size: 0.875rem;
            color: var(--gray-900);
        }

        .user-role {
            font-size: 0.75rem;
            color: var(--gray-500);
            text-transform: uppercase;
            letter-spacing: 0.05em;
        }

        /* Main Container */
        .main-container {
            max-width: 1400px;
            margin: 0 auto;
            padding: 2rem 1.5rem;
        }

        /* Welcome Section */
        .welcome-section {
            background: linear-gradient(135deg, rgba(255, 255, 255, 0.95), rgba(255, 255, 255, 0.8));
            backdrop-filter: blur(20px);
            border: 1px solid rgba(255, 255, 255, 0.2);
            border-radius: 24px;
            padding: 3rem 2rem;
            margin-bottom: 2rem;
            text-align: center;
            box-shadow: var(--shadow-xl);
            position: relative;
            overflow: hidden;
        }

        .welcome-section::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: linear-gradient(135deg, var(--primary-light), var(--purple-light));
            opacity: 0.1;
            z-index: -1;
        }

        .welcome-title {
            font-size: 2.5rem;
            font-weight: 800;
            margin: 0 0 0.5rem 0;
            background: linear-gradient(135deg, var(--gray-900), var(--gray-700));
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
            background-clip: text;
        }

        .welcome-subtitle {
            font-size: 1.125rem;
            color: var(--gray-600);
            margin: 0 0 2rem 0;
            font-weight: 400;
        }

        .welcome-cta {
            display: inline-flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.875rem 2rem;
            background: linear-gradient(135deg, var(--primary), var(--primary-dark));
            color: white;
            border-radius: 50px;
            text-decoration: none;
            font-weight: 600;
            font-size: 1rem;
            box-shadow: var(--shadow-lg);
            transition: all 0.3s ease;
            border: none;
        }

        .welcome-cta:hover {
            transform: translateY(-2px);
            box-shadow: var(--shadow-xl);
            color: white;
        }

        /* Stats Grid */
        .stats-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(280px, 1fr));
            gap: 1.5rem;
            margin-bottom: 2rem;
        }

        .stat-card {
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border: 1px solid rgba(255, 255, 255, 0.2);
            border-radius: 20px;
            padding: 2rem;
            box-shadow: var(--shadow-lg);
            transition: all 0.3s ease;
            position: relative;
            overflow: hidden;
        }

        .stat-card::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            height: 4px;
            background: linear-gradient(90deg, var(--primary), var(--primary-dark));
        }

        .stat-card:hover {
            transform: translateY(-4px);
            box-shadow: var(--shadow-xl);
        }

        .stat-header {
            display: flex;
            justify-content: space-between;
            align-items: flex-start;
            margin-bottom: 1.5rem;
        }

        .stat-title {
            color: var(--gray-600);
            font-size: 0.875rem;
            font-weight: 600;
            margin: 0;
            text-transform: uppercase;
            letter-spacing: 0.05em;
        }

        .stat-icon {
            width: 48px;
            height: 48px;
            border-radius: 16px;
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 1.5rem;
            box-shadow: var(--shadow-md);
        }

        .stat-icon.primary {
            background: linear-gradient(135deg, var(--primary), var(--primary-dark));
            color: white;
        }

        .stat-icon.success {
            background: linear-gradient(135deg, var(--success), #059669);
            color: white;
        }

        .stat-icon.warning {
            background: linear-gradient(135deg, var(--warning), #d97706);
            color: white;
        }

        .stat-icon.purple {
            background: linear-gradient(135deg, var(--purple), #7c3aed);
            color: white;
        }

        .stat-number {
            font-size: 3rem;
            font-weight: 800;
            color: var(--gray-900);
            margin: 0 0 0.5rem 0;
            line-height: 1;
        }

        .stat-change {
            font-size: 0.875rem;
            color: var(--gray-500);
            margin: 0;
            font-weight: 500;
        }

        /* Charts Section */
        .charts-section {
            display: grid;
            grid-template-columns: 2fr 1fr;
            gap: 2rem;
            margin-bottom: 2rem;
        }

        .chart-card {
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border: 1px solid rgba(255, 255, 255, 0.2);
            border-radius: 20px;
            padding: 2rem;
            box-shadow: var(--shadow-lg);
        }

        .chart-title {
            font-size: 1.25rem;
            font-weight: 700;
            color: var(--gray-900);
            margin: 0 0 1.5rem 0;
            display: flex;
            align-items: center;
            gap: 0.75rem;
        }

        .chart-container {
            position: relative;
            height: 300px;
        }

        /* Quick Actions */
        .quick-actions {
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border: 1px solid rgba(255, 255, 255, 0.2);
            border-radius: 20px;
            padding: 2rem;
            margin-bottom: 2rem;
            box-shadow: var(--shadow-lg);
        }

        .section-title {
            font-size: 1.5rem;
            font-weight: 700;
            color: var(--gray-900);
            margin: 0 0 2rem 0;
            display: flex;
            align-items: center;
            gap: 0.75rem;
        }

        .actions-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(240px, 1fr));
            gap: 1.5rem;
        }

        .action-card {
            background: rgba(255, 255, 255, 0.8);
            border: 1px solid rgba(255, 255, 255, 0.3);
            border-radius: 16px;
            padding: 2rem;
            text-align: center;
            text-decoration: none;
            color: var(--gray-700);
            transition: all 0.3s ease;
            position: relative;
            overflow: hidden;
        }

        .action-card::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: linear-gradient(135deg, var(--primary-light), var(--purple-light));
            opacity: 0;
            transition: opacity 0.3s ease;
        }

        .action-card:hover {
            color: var(--primary);
            transform: translateY(-4px);
            box-shadow: var(--shadow-xl);
        }

        .action-card:hover::before {
            opacity: 0.1;
        }

        .action-icon {
            font-size: 2.5rem;
            margin-bottom: 1rem;
            color: var(--primary);
            position: relative;
            z-index: 1;
        }

        .action-title {
            font-weight: 600;
            margin: 0 0 0.5rem 0;
            font-size: 1.125rem;
            position: relative;
            z-index: 1;
        }

        .action-description {
            font-size: 0.875rem;
            color: var(--gray-500);
            margin: 0;
            position: relative;
            z-index: 1;
        }

        /* Recent Inspections */
        .recent-section {
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border: 1px solid rgba(255, 255, 255, 0.2);
            border-radius: 20px;
            padding: 2rem;
            box-shadow: var(--shadow-lg);
        }

        .section-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 2rem;
            padding-bottom: 1rem;
            border-bottom: 1px solid var(--gray-200);
        }

        .inspections-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(400px, 1fr));
            gap: 1.5rem;
            margin-bottom: 2rem;
        }

        .inspection-card {
            background: rgba(255, 255, 255, 0.9);
            border: 1px solid rgba(255, 255, 255, 0.3);
            border-radius: 16px;
            padding: 0;
            box-shadow: var(--shadow-md);
            transition: all 0.3s ease;
            overflow: hidden;
        }

        .inspection-card:hover {
            transform: translateY(-4px);
            box-shadow: var(--shadow-xl);
        }

        .inspection-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 1.25rem 1.5rem;
            background: linear-gradient(135deg, var(--gray-50), var(--gray-100));
            border-bottom: 1px solid var(--gray-200);
        }

        .inspection-id {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            font-weight: 700;
            color: var(--gray-700);
            font-size: 0.875rem;
        }

        .inspection-id i {
            color: var(--primary);
        }

        .status-badge {
            display: flex;
            align-items: center;
            gap: 0.375rem;
            padding: 0.5rem 1rem;
            border-radius: 50px;
            font-size: 0.75rem;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.05em;
        }

        .status-draft {
            background: var(--gray-100);
            color: var(--gray-600);
        }

        .status-completed {
            background: var(--success-light);
            color: var(--success);
        }

        .status-approved {
            background: var(--primary-light);
            color: var(--primary);
        }

        .inspection-content {
            padding: 1.5rem;
        }

        .inspection-title {
            font-size: 1.25rem;
            font-weight: 700;
            color: var(--gray-900);
            margin: 0 0 1rem 0;
            line-height: 1.4;
        }

        .inspection-meta {
            display: flex;
            flex-direction: column;
            gap: 0.75rem;
        }

        .meta-item {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            font-size: 0.875rem;
        }

        .meta-item i {
            width: 18px;
            color: var(--gray-500);
            flex-shrink: 0;
        }

        .meta-label {
            font-weight: 600;
            color: var(--gray-600);
            min-width: 80px;
        }

        .meta-value {
            color: var(--gray-900);
            font-weight: 500;
        }

        .inspection-actions {
            display: flex;
            gap: 0.75rem;
            padding: 1.25rem 1.5rem;
            background: var(--gray-50);
            border-top: 1px solid var(--gray-200);
        }

        .action-btn {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.625rem 1rem;
            border: 1px solid transparent;
            border-radius: 8px;
            font-size: 0.875rem;
            font-weight: 600;
            text-decoration: none;
            transition: all 0.2s ease;
            flex: 1;
            justify-content: center;
        }

        .action-btn.primary {
            background: linear-gradient(135deg, var(--primary), var(--primary-dark));
            color: white;
        }

        .action-btn.primary:hover {
            transform: translateY(-1px);
            box-shadow: var(--shadow-md);
            color: white;
        }

        .action-btn.secondary {
            border-color: var(--gray-300);
            color: var(--gray-700);
            background: white;
        }

        .action-btn.secondary:hover {
            background: var(--gray-50);
            color: var(--gray-900);
            border-color: var(--gray-400);
        }

        .action-btn.danger {
            border-color: var(--danger);
            color: var(--danger);
            background: white;
        }

        .action-btn.danger:hover {
            background: var(--danger);
            color: white;
        }

        .action-btn.warning {
            border-color: var(--warning);
            color: var(--warning);
            background: white;
        }

        .action-btn.warning:hover {
            background: var(--warning);
            color: white;
        }

        /* Buttons */
        .btn {
            display: inline-flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.625rem 1.25rem;
            border: 1px solid transparent;
            border-radius: 8px;
            font-size: 0.875rem;
            font-weight: 600;
            text-decoration: none;
            cursor: pointer;
            transition: all 0.2s ease;
        }

        .btn-primary {
            background: linear-gradient(135deg, var(--primary), var(--primary-dark));
            color: white;
        }

        .btn-primary:hover {
            transform: translateY(-1px);
            box-shadow: var(--shadow-md);
            color: white;
        }

        .btn-outline-primary {
            border-color: var(--primary);
            color: var(--primary);
            background: white;
        }

        .btn-outline-primary:hover {
            background: var(--primary);
            color: white;
        }

        .btn-outline-secondary {
            border-color: var(--gray-300);
            color: var(--gray-700);
            background: white;
        }

        .btn-outline-secondary:hover {
            background: var(--gray-50);
            color: var(--gray-900);
        }

        .btn-sm {
            padding: 0.5rem 1rem;
            font-size: 0.8125rem;
        }

        /* Empty State */
        .empty-state {
            text-align: center;
            padding: 4rem 2rem;
        }

        .empty-icon {
            font-size: 4rem;
            color: var(--gray-400);
            margin-bottom: 1.5rem;
        }

        .empty-title {
            font-size: 1.5rem;
            font-weight: 700;
            color: var(--gray-700);
            margin: 0 0 0.75rem 0;
        }

        .empty-description {
            color: var(--gray-500);
            margin: 0 0 2rem 0;
            font-size: 1.125rem;
        }

        /* Responsive */
        @media (max-width: 1024px) {
            .charts-section {
                grid-template-columns: 1fr;
            }
        }

        @media (max-width: 768px) {
            .main-container {
                padding: 1rem;
            }

            .welcome-section {
                padding: 2rem 1.5rem;
            }

            .welcome-title {
                font-size: 2rem;
            }

            .stats-grid {
                grid-template-columns: 1fr;
            }

            .actions-grid {
                grid-template-columns: 1fr;
            }

            .inspections-grid {
                grid-template-columns: 1fr;
            }

            .inspection-header {
                flex-direction: column;
                gap: 1rem;
                align-items: flex-start;
            }

            .inspection-actions {
                flex-wrap: wrap;
            }

            .action-btn {
                flex: 1 1 calc(50% - 0.375rem);
                min-width: 0;
            }

            .section-header {
                flex-direction: column;
                gap: 1rem;
                align-items: flex-start;
            }

            .user-info {
                display: none;
            }
        }

        @media (max-width: 480px) {
            .action-btn span {
                display: none;
            }

            .meta-item {
                flex-direction: column;
                align-items: flex-start;
                gap: 0.25rem;
            }

            .meta-label {
                min-width: auto;
                font-size: 0.75rem;
                text-transform: uppercase;
                letter-spacing: 0.05em;
            }
        }

        /* Loading Animation */
        @keyframes pulse {
            0%, 100% { opacity: 1; }
            50% { opacity: 0.5; }
        }

        .loading {
            animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;
        }

        /* Scroll Animations */
        @keyframes fadeInUp {
            from {
                opacity: 0;
                transform: translateY(30px);
            }
            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .animate-fade-in-up {
            animation: fadeInUp 0.6s ease-out;
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="header">
        <div class="header-content">
            <a href="dashboard.php" class="logo">
                <i class="fas fa-fire-extinguisher"></i>
                <?php echo APP_NAME; ?>
            </a>
            
            <div class="user-menu">
                <div class="user-info">
                    <?php if ($foto_perfil && file_exists($foto_perfil)): ?>
                        <img src="<?php echo htmlspecialchars($foto_perfil); ?>" 
                             alt="Foto de perfil" 
                             class="user-avatar">
                    <?php else: ?>
                        <div class="user-avatar-placeholder">
                            <i class="fas fa-user"></i>
                        </div>
                    <?php endif; ?>
                    <div class="user-details">
                        <div class="user-name"><?php echo htmlspecialchars($_SESSION['user_name']); ?></div>
                        <div class="user-role"><?php echo ucfirst($_SESSION['user_role']); ?></div>
                    </div>
                </div>
                <a href="perfil.php" class="btn btn-outline-secondary btn-sm">
                    <i class="fas fa-user-cog"></i>
                    Perfil
                </a>
                <a href="logout.php" class="btn btn-outline-secondary btn-sm">
                    <i class="fas fa-sign-out-alt"></i>
                    Salir
                </a>
            </div>
        </div>
    </header>

    <div class="main-container">
        <!-- Welcome Section -->
        <div class="welcome-section animate-fade-in-up">
            <h1 class="welcome-title">
                ¡Bienvenido, <?php echo htmlspecialchars($_SESSION['user_name']); ?>!
            </h1>
            <p class="welcome-subtitle">
                Sistema de Inspección de Bombas Contra Incendios
            </p>
            <a href="nueva_inspeccion.php" class="welcome-cta">
                <i class="fas fa-plus"></i>
                Nueva Inspección
            </a>
        </div>

        <!-- Statistics -->
        <div class="stats-grid">
            <div class="stat-card animate-fade-in-up" style="animation-delay: 0.1s;">
                <div class="stat-header">
                    <h3 class="stat-title">Total Inspecciones</h3>
                    <div class="stat-icon primary">
                        <i class="fas fa-clipboard-list"></i>
                    </div>
                </div>
                <p class="stat-number" data-target="<?php echo $stats['total']; ?>">0</p>
                <p class="stat-change">Todas las inspecciones registradas</p>
            </div>

            <div class="stat-card animate-fade-in-up" style="animation-delay: 0.2s;">
                <div class="stat-header">
                    <h3 class="stat-title">Completadas</h3>
                    <div class="stat-icon success">
                        <i class="fas fa-check-circle"></i>
                    </div>
                </div>
                <p class="stat-number" data-target="<?php echo $stats['completadas']; ?>">0</p>
                <p class="stat-change">Inspecciones finalizadas</p>
            </div>

            <div class="stat-card animate-fade-in-up" style="animation-delay: 0.3s;">
                <div class="stat-header">
                    <h3 class="stat-title">Aprobadas</h3>
                    <div class="stat-icon purple">
                        <i class="fas fa-star"></i>
                    </div>
                </div>
                <p class="stat-number" data-target="<?php echo $stats['aprobadas']; ?>">0</p>
                <p class="stat-change">Inspecciones aprobadas</p>
            </div>

            <div class="stat-card animate-fade-in-up" style="animation-delay: 0.4s;">
                <div class="stat-header">
                    <h3 class="stat-title">Inmuebles</h3>
                    <div class="stat-icon warning">
                        <i class="fas fa-building"></i>
                    </div>
                </div>
                <p class="stat-number" data-target="<?php echo $total_inmuebles; ?>">0</p>
                <p class="stat-change">Inmuebles registrados</p>
            </div>
        </div>

        <!-- Charts Section -->
        <div class="charts-section animate-fade-in-up" style="animation-delay: 0.5s;">
            <div class="chart-card">
                <h3 class="chart-title">
                    <i class="fas fa-chart-line"></i>
                    Inspecciones por Mes
                </h3>
                <div class="chart-container">
                    <canvas id="monthlyChart"></canvas>
                </div>
            </div>
            
            <div class="chart-card">
                <h3 class="chart-title">
                    <i class="fas fa-chart-pie"></i>
                    Estados de Inspecciones
                </h3>
                <div class="chart-container">
                    <canvas id="statusChart"></canvas>
                </div>
            </div>
        </div>

        <!-- Quick Actions -->
        <div class="quick-actions animate-fade-in-up" style="animation-delay: 0.6s;">
            <h2 class="section-title">
                <i class="fas fa-bolt"></i>
                Acciones Rápidas
            </h2>
            <div class="actions-grid">
                <a href="nueva_inspeccion.php" class="action-card">
                    <div class="action-icon">
                        <i class="fas fa-plus-circle"></i>
                    </div>
                    <h3 class="action-title">Nueva Inspección</h3>
                    <p class="action-description">Crear una nueva inspección de bomba contra incendios</p>
                </a>

                <a href="inspecciones.php" class="action-card">
                    <div class="action-icon">
                        <i class="fas fa-list"></i>
                    </div>
                    <h3 class="action-title">Ver Inspecciones</h3>
                    <p class="action-description">Revisar todas las inspecciones realizadas</p>
                </a>

                <a href="inmuebles.php" class="action-card">
                    <div class="action-icon">
                        <i class="fas fa-building"></i>
                    </div>
                    <h3 class="action-title">Gestionar Inmuebles</h3>
                    <p class="action-description">Administrar inmuebles y propiedades</p>
                </a>

                <a href="gestionar_equipos.php" class="action-card">
                    <div class="action-icon">
                        <i class="fas fa-cogs"></i>
                    </div>
                    <h3 class="action-title">Gestionar Equipos</h3>
                    <p class="action-description">Registrar y administrar equipos individuales</p>
                </a>

                <a href="inspeccion_equipos_completa.php" class="action-card">
                    <div class="action-icon" style="color: var(--success);">
                        <i class="fas fa-clipboard-check"></i>
                    </div>
                    <h3 class="action-title">Inspección por Equipos</h3>
                    <p class="action-description">Inspecciona equipos específicos individualmente</p>
                </a>

                <a href="informes.php" class="action-card">
                    <div class="action-icon" style="color: var(--warning);">
                        <i class="fas fa-chart-line"></i>
                    </div>
                    <h3 class="action-title">Informes</h3>
                    <p class="action-description">Ver problemas y seguimiento</p>
                </a>

                <?php if (isAdmin()): ?>
                <a href="usuarios.php" class="action-card">
                    <div class="action-icon" style="color: var(--purple);">
                        <i class="fas fa-users"></i>
                    </div>
                    <h3 class="action-title">Gestionar Usuarios</h3>
                    <p class="action-description">Crear y administrar usuarios del sistema</p>
                </a>

                <a href="admin_inspecciones.php" class="action-card">
                    <div class="action-icon" style="color: var(--success);">
                        <i class="fas fa-cogs"></i>
                    </div>
                    <h3 class="action-title">Administrar Inspecciones</h3>
                    <p class="action-description">Configurar tipos y preguntas de inspección</p>
                </a>
                <?php endif; ?>
            </div>
        </div>

        <!-- Recent Inspections -->
        <div class="recent-section animate-fade-in-up" style="animation-delay: 0.7s;">
            <div class="section-header">
                <h2 class="section-title">
                    <i class="fas fa-clock"></i>
                    Inspecciones Recientes
                </h2>
                <div class="section-actions">
                    <a href="inspecciones.php" class="btn btn-outline-primary btn-sm">
                        <i class="fas fa-list"></i>
                        Ver Todas
                    </a>
                </div>
            </div>

            <?php if (empty($inspecciones_recientes)): ?>
                <div class="empty-state">
                    <div class="empty-icon">
                        <i class="fas fa-clipboard-list"></i>
                    </div>
                    <h3 class="empty-title">No hay inspecciones</h3>
                    <p class="empty-description">
                        Aún no has realizado ninguna inspección. ¡Comienza creando tu primera inspección!
                    </p>
                    <a href="nueva_inspeccion.php" class="btn btn-primary">
                        <i class="fas fa-plus"></i>
                        Crear Primera Inspección
                    </a>
                </div>
            <?php else: ?>
                <div class="inspections-grid">
                    <?php foreach ($inspecciones_recientes as $insp): ?>
                        <div class="inspection-card">
                            <div class="inspection-header">
                                <div class="inspection-id">
                                    <i class="fas fa-hashtag"></i>
                                    <?php echo $insp['id']; ?>
                                </div>
                                <div class="inspection-status">
                                    <?php
                                    $status_config = [
                                        'borrador' => ['icon' => 'fas fa-edit', 'class' => 'status-draft', 'text' => 'Borrador'],
                                        'completada' => ['icon' => 'fas fa-check-circle', 'class' => 'status-completed', 'text' => 'Completada'],
                                        'aprobada' => ['icon' => 'fas fa-star', 'class' => 'status-approved', 'text' => 'Aprobada']
                                    ];
                                    $status = $status_config[$insp['estado']] ?? $status_config['borrador'];
                                    ?>
                                    <span class="status-badge <?php echo $status['class']; ?>">
                                        <i class="<?php echo $status['icon']; ?>"></i>
                                        <?php echo $status['text']; ?>
                                    </span>
                                </div>
                            </div>

                            <div class="inspection-content">
                                <h4 class="inspection-title">
                                    <?php echo htmlspecialchars($insp['inmueble_nombre']); ?>
                                </h4>
                                
                                <div class="inspection-meta">
                                    <div class="meta-item">
                                        <i class="fas fa-calendar-alt"></i>
                                        <span class="meta-label">Fecha:</span>
                                        <span class="meta-value">
                                            <?php 
                                            $fecha = new DateTime($insp['fecha_inspeccion']);
                                            $ahora = new DateTime();
                                            $diff = $ahora->diff($fecha);
                                            
                                            if ($diff->days == 0) {
                                                echo "Hoy";
                                            } elseif ($diff->days == 1) {
                                                echo "Ayer";
                                            } elseif ($diff->days < 7) {
                                                echo "Hace " . $diff->days . " días";
                                            } else {
                                                echo $fecha->format('d/m/Y');
                                            }
                                            ?>
                                        </span>
                                    </div>
                                    
                                    <div class="meta-item">
                                        <i class="fas fa-user"></i>
                                        <span class="meta-label">Inspector:</span>
                                        <span class="meta-value"><?php echo htmlspecialchars($insp['inspector_nombre']); ?></span>
                                    </div>
                                    
                                    <?php if (!empty($insp['numero_contrato'])): ?>
                                    <div class="meta-item">
                                        <i class="fas fa-file-contract"></i>
                                        <span class="meta-label">Contrato:</span>
                                        <span class="meta-value"><?php echo htmlspecialchars($insp['numero_contrato']); ?></span>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>

                            <div class="inspection-actions">
                                <a href="ver_inspeccion.php?id=<?php echo $insp['id']; ?>" 
                                   class="action-btn primary" 
                                   title="Ver Inspección">
                                    <i class="fas fa-eye"></i>
                                    <span>Ver</span>
                                </a>
                                
                                <?php if ($insp['estado'] === 'borrador' || isAdmin()): ?>
                                <a href="editar_inspeccion.php?id=<?php echo $insp['id']; ?>" 
                                   class="action-btn secondary" 
                                   title="Editar Inspección">
                                    <i class="fas fa-edit"></i>
                                    <span>Editar</span>
                                </a>
                                <?php endif; ?>
                                
                                <a href="generar_pdf_simple.php?id=<?php echo $insp['id']; ?>" 
                                   class="action-btn danger" 
                                   title="Generar PDF" 
                                   target="_blank">
                                    <i class="fas fa-file-pdf"></i>
                                    <span>PDF</span>
                                </a>
                                
                                <?php if ($insp['estado'] === 'completada' && isAdmin()): ?>
                                <a href="aprobar_inspeccion.php?id=<?php echo $insp['id']; ?>" 
                                   class="action-btn warning" 
                                   title="Aprobar Inspección">
                                    <i class="fas fa-check"></i>
                                    <span>Aprobar</span>
                                </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // Animación de números
        function animateNumbers() {
            const numbers = document.querySelectorAll('.stat-number[data-target]');
            
            numbers.forEach(number => {
                const target = parseInt(number.getAttribute('data-target'));
                const duration = 2000;
                const step = target / (duration / 16);
                let current = 0;
                
                const timer = setInterval(() => {
                    current += step;
                    if (current >= target) {
                        current = target;
                        clearInterval(timer);
                    }
                    number.textContent = Math.floor(current);
                }, 16);
            });
        }

        // Configurar gráficos
        function setupCharts() {
            // Gráfico de líneas - Inspecciones por mes
            const monthlyCtx = document.getElementById('monthlyChart').getContext('2d');
            const monthlyData = <?php echo json_encode(array_values($stats_mensuales)); ?>;
            const monthlyLabels = <?php echo json_encode($meses); ?>;
            
            new Chart(monthlyCtx, {
                type: 'line',
                data: {
                    labels: monthlyLabels,
                    datasets: [{
                        label: 'Inspecciones',
                        data: monthlyData,
                        borderColor: 'rgb(59, 130, 246)',
                        backgroundColor: 'rgba(59, 130, 246, 0.1)',
                        borderWidth: 3,
                        fill: true,
                        tension: 0.4,
                        pointBackgroundColor: 'rgb(59, 130, 246)',
                        pointBorderColor: '#fff',
                        pointBorderWidth: 2,
                        pointRadius: 6,
                        pointHoverRadius: 8
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        legend: {
                            display: false
                        }
                    },
                    scales: {
                        y: {
                            beginAtZero: true,
                            grid: {
                                color: 'rgba(0, 0, 0, 0.05)'
                            },
                            ticks: {
                                color: '#6b7280'
                            }
                        },
                        x: {
                            grid: {
                                display: false
                            },
                            ticks: {
                                color: '#6b7280'
                            }
                        }
                    }
                }
            });

            // Gráfico de dona - Estados
            const statusCtx = document.getElementById('statusChart').getContext('2d');
            const statusData = [
                <?php echo $stats['borradores']; ?>,
                <?php echo $stats['completadas']; ?>,
                <?php echo $stats['aprobadas']; ?>
            ];
            
            new Chart(statusCtx, {
                type: 'doughnut',
                data: {
                    labels: ['Borradores', 'Completadas', 'Aprobadas'],
                    datasets: [{
                        data: statusData,
                        backgroundColor: [
                            '#9ca3af',
                            '#10b981',
                            '#3b82f6'
                        ],
                        borderWidth: 0,
                        hoverOffset: 10
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        legend: {
                            position: 'bottom',
                            labels: {
                                padding: 20,
                                usePointStyle: true,
                                color: '#6b7280'
                            }
                        }
                    }
                }
            });
        }

        // Inicializar cuando la página carga
        document.addEventListener('DOMContentLoaded', function() {
            setTimeout(() => {
                animateNumbers();
                setupCharts();
            }, 500);
        });

        // Efectos de hover para las cards
        document.querySelectorAll('.stat-card, .action-card, .inspection-card').forEach(card => {
            card.addEventListener('mouseenter', function() {
                this.style.transform = 'translateY(-4px)';
            });
            
            card.addEventListener('mouseleave', function() {
                this.style.transform = 'translateY(0)';
            });
        });
    </script>
</body>
</html>
