<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';

requireLogin();

echo "<h2>🔍 Debug del Sistema de Aprobación</h2>";

// Verificar si existe la tabla y columnas
try {
    $database = new Database();
    $conn = $database->getConnection();
    
    echo "<h3>📋 Verificando estructura de tabla inspecciones:</h3>";
    
    $query = "DESCRIBE inspecciones";
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $columns = $stmt->fetchAll();
    
    echo "<table border='1' style='border-collapse: collapse; margin: 10px 0;'>";
    echo "<tr><th>Campo</th><th>Tipo</th><th>Nulo</th><th>Clave</th><th>Default</th></tr>";
    
    $required_fields = ['aprobador_id', 'fecha_aprobacion', 'comentarios_aprobacion', 'rechazador_id', 'fecha_rechazo', 'motivo_rechazo'];
    $existing_fields = [];
    
    foreach ($columns as $col) {
        echo "<tr>";
        echo "<td>" . $col['Field'] . "</td>";
        echo "<td>" . $col['Type'] . "</td>";
        echo "<td>" . $col['Null'] . "</td>";
        echo "<td>" . $col['Key'] . "</td>";
        echo "<td>" . $col['Default'] . "</td>";
        echo "</tr>";
        
        $existing_fields[] = $col['Field'];
    }
    echo "</table>";
    
    echo "<h3>✅ Campos requeridos para aprobación:</h3>";
    foreach ($required_fields as $field) {
        $exists = in_array($field, $existing_fields);
        echo "<p>" . ($exists ? "✅" : "❌") . " $field " . ($exists ? "(Existe)" : "(FALTA)") . "</p>";
    }
    
    // Verificar inspecciones completadas
    echo "<h3>📊 Inspecciones completadas disponibles:</h3>";
    $query = "SELECT id, inmueble_id, estado, fecha_inspeccion FROM inspecciones WHERE estado = 'completada'";
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $completadas = $stmt->fetchAll();
    
    if (empty($completadas)) {
        echo "<p>❌ No hay inspecciones completadas para aprobar</p>";
    } else {
        echo "<table border='1' style='border-collapse: collapse; margin: 10px 0;'>";
        echo "<tr><th>ID</th><th>Inmueble ID</th><th>Estado</th><th>Fecha</th></tr>";
        foreach ($completadas as $insp) {
            echo "<tr>";
            echo "<td>" . $insp['id'] . "</td>";
            echo "<td>" . $insp['inmueble_id'] . "</td>";
            echo "<td>" . $insp['estado'] . "</td>";
            echo "<td>" . $insp['fecha_inspeccion'] . "</td>";
            echo "</tr>";
        }
        echo "</table>";
    }
    
    // Probar método de aprobación
    echo "<h3>🧪 Probando método aprobarInspeccion:</h3>";
    $inspeccion = new Inspeccion();
    
    if (!empty($completadas)) {
        $test_id = $completadas[0]['id'];
        echo "<p>Probando con inspección ID: $test_id</p>";
        
        // Verificar que el método existe
        if (method_exists($inspeccion, 'aprobarInspeccion')) {
            echo "<p>✅ Método aprobarInspeccion existe</p>";
        } else {
            echo "<p>❌ Método aprobarInspeccion NO existe</p>";
        }
        
        if (method_exists($inspeccion, 'rechazarInspeccion')) {
            echo "<p>✅ Método rechazarInspeccion existe</p>";
        } else {
            echo "<p>❌ Método rechazarInspeccion NO existe</p>";
        }
    }
    
} catch (Exception $e) {
    echo "<p style='color: red;'>❌ Error: " . $e->getMessage() . "</p>";
}

echo "<hr>";
echo "<h3>🔧 Acciones recomendadas:</h3>";
echo "<ol>";
echo "<li><a href='scripts/15_add_approval_fields.sql' target='_blank'>Ejecutar script SQL para agregar campos</a></li>";
echo "<li><a href='crear_borrador.php'>Crear inspección de prueba</a></li>";
echo "<li><a href='dashboard.php'>Volver al Dashboard</a></li>";
echo "</ol>";
?>
