<?php
session_start();
require_once 'config/database.php';
require_once 'config/config.php';
require_once 'models/Inspeccion.php';

// Obtener el ID de la inspección
$inspeccion_id = isset($_GET['id']) ? (int)$_GET['id'] : 1;

echo "<h2>🔍 Debug de Permisos de Edición</h2>";
echo "<p><strong>Inspección ID:</strong> $inspeccion_id</p>";

// Verificar sesión
echo "<h3>📊 Estado de la Sesión:</h3>";
echo "<ul>";
echo "<li><strong>session_id():</strong> " . session_id() . "</li>";
echo "<li><strong>user_id:</strong> " . ($_SESSION['user_id'] ?? 'NO DEFINIDO') . "</li>";
echo "<li><strong>user_name:</strong> " . ($_SESSION['user_name'] ?? 'NO DEFINIDO') . "</li>";
echo "<li><strong>rol:</strong> " . ($_SESSION['rol'] ?? 'NO DEFINIDO') . "</li>";
echo "<li><strong>user_role:</strong> " . ($_SESSION['user_role'] ?? 'NO DEFINIDO') . "</li>";
echo "</ul>";

// Verificar funciones
echo "<h3>🔧 Verificación de Funciones:</h3>";
echo "<ul>";
echo "<li><strong>isLoggedIn():</strong> " . (isLoggedIn() ? '✅ SÍ' : '❌ NO') . "</li>";
echo "<li><strong>isAdmin():</strong> " . (isAdmin() ? '✅ SÍ' : '❌ NO') . "</li>";
echo "</ul>";

// Función isAdmin local para comparar
function isAdminLocal() {
    return isset($_SESSION['rol']) && $_SESSION['rol'] === 'administrador';
}

function isAdminLocal2() {
    return isset($_SESSION['rol']) && $_SESSION['rol'] === 'admin';
}

function isAdminLocal3() {
    return isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'admin';
}

echo "<h3>🧪 Pruebas de Función isAdmin():</h3>";
echo "<ul>";
echo "<li><strong>isAdminLocal() (busca 'administrador'):</strong> " . (isAdminLocal() ? '✅ SÍ' : '❌ NO') . "</li>";
echo "<li><strong>isAdminLocal2() (busca 'admin' en rol):</strong> " . (isAdminLocal2() ? '✅ SÍ' : '❌ NO') . "</li>";
echo "<li><strong>isAdminLocal3() (busca 'admin' en user_role):</strong> " . (isAdminLocal3() ? '✅ SÍ' : '❌ NO') . "</li>";
echo "</ul>";

try {
    // Obtener datos de la inspección
    $inspeccion = new Inspeccion();
    $inspeccion_data = $inspeccion->getById($inspeccion_id);
    
    if (!$inspeccion_data) {
        echo "<div style='color: red;'>❌ <strong>Error:</strong> Inspección no encontrada.</div>";
        exit();
    }
    
    echo "<h3>📋 Datos de la Inspección:</h3>";
    echo "<ul>";
    echo "<li><strong>ID:</strong> " . $inspeccion_data['id'] . "</li>";
    echo "<li><strong>Estado:</strong> " . $inspeccion_data['estado'] . "</li>";
    echo "<li><strong>Inspector ID:</strong> " . $inspeccion_data['inspector_id'] . "</li>";
    echo "<li><strong>Fecha:</strong> " . $inspeccion_data['fecha_inspeccion'] . "</li>";
    echo "<li><strong>Tipo:</strong> " . ($inspeccion_data['tipo_inspeccion_nombre'] ?? 'N/A') . "</li>";
    echo "</ul>";
    
    // Verificar permisos paso a paso
    echo "<h3>🔐 Análisis de Permisos:</h3>";
    
    $user_id = $_SESSION['user_id'] ?? 0;
    $inspector_id = $inspeccion_data['inspector_id'];
    $estado = $inspeccion_data['estado'];
    
    echo "<ul>";
    echo "<li><strong>Usuario actual ID:</strong> $user_id</li>";
    echo "<li><strong>Inspector de la inspección ID:</strong> $inspector_id</li>";
    echo "<li><strong>¿Es la misma persona?:</strong> " . ($user_id == $inspector_id ? '✅ SÍ' : '❌ NO') . "</li>";
    echo "<li><strong>Estado de la inspección:</strong> $estado</li>";
    echo "<li><strong>¿Es borrador?:</strong> " . ($estado === 'borrador' ? '✅ SÍ' : '❌ NO') . "</li>";
    echo "</ul>";
    
    // Lógica de permisos
    echo "<h3>⚖️ Lógica de Permisos:</h3>";
    
    $puede_editar = false;
    $razon = "";
    
    if (isAdmin()) {
        $puede_editar = true;
        $razon = "✅ ES ADMINISTRADOR - Puede editar cualquier inspección";
    } else {
        if ($user_id == $inspector_id && $estado === 'borrador') {
            $puede_editar = true;
            $razon = "✅ ES SU INSPECCIÓN Y ESTÁ EN BORRADOR";
        } else if ($user_id != $inspector_id) {
            $razon = "❌ NO ES SU INSPECCIÓN (Inspector: $inspector_id, Usuario: $user_id)";
        } else if ($estado !== 'borrador') {
            $razon = "❌ LA INSPECCIÓN NO ESTÁ EN BORRADOR (Estado: $estado)";
        } else {
            $razon = "❌ RAZÓN DESCONOCIDA";
        }
    }
    
    echo "<div style='padding: 15px; border: 2px solid " . ($puede_editar ? 'green' : 'red') . "; border-radius: 8px; margin: 10px 0;'>";
    echo "<strong>RESULTADO FINAL:</strong> " . ($puede_editar ? '✅ PUEDE EDITAR' : '❌ NO PUEDE EDITAR') . "<br>";
    echo "<strong>RAZÓN:</strong> $razon";
    echo "</div>";
    
    // Enlaces de prueba
    echo "<h3>🔗 Enlaces de Prueba:</h3>";
    echo "<ul>";
    echo "<li><a href='editar_inspeccion.php?id=$inspeccion_id' target='_blank'>🔧 Probar editar_inspeccion.php?id=$inspeccion_id</a></li>";
    echo "<li><a href='inspecciones.php' target='_blank'>📋 Volver a inspecciones.php</a></li>";
    echo "<li><a href='crear_borrador.php' target='_blank'>📝 Crear inspección borrador</a></li>";
    echo "</ul>";
    
    // Mostrar función isAdmin del archivo config
    echo "<h3>📄 Función isAdmin() en config/config.php:</h3>";
    $config_content = file_get_contents('config/config.php');
    if (preg_match('/function isAdmin$$$$.*?\{.*?\}/s', $config_content, $matches)) {
        echo "<pre style='background: #f5f5f5; padding: 10px; border-radius: 5px;'>";
        echo htmlspecialchars($matches[0]);
        echo "</pre>";
    } else {
        echo "<p style='color: red;'>❌ No se encontró la función isAdmin() en config/config.php</p>";
    }
    
} catch (Exception $e) {
    echo "<div style='color: red;'>❌ <strong>Error:</strong> " . $e->getMessage() . "</div>";
}

echo "<hr>";
echo "<p><small>🕒 Generado: " . date('Y-m-d H:i:s') . "</small></p>";
?>
