<?php
session_start();
require_once 'config/config.php'; // Mover aquí
require_once 'config/database.php';
require_once 'models/Inspeccion.php';
require_once 'models/Inmueble.php';

// Debug temporal
error_log("=== DEBUG FUNCIÓN isAdmin ===");
error_log("function_exists('isAdmin'): " . (function_exists('isAdmin') ? 'SÍ' : 'NO'));
error_log("isAdmin() result: " . (isAdmin() ? 'SÍ' : 'NO'));
error_log("SESSION rol: " . ($_SESSION['rol'] ?? 'NO DEFINIDO'));
error_log("SESSION user_role: " . ($_SESSION['user_role'] ?? 'NO DEFINIDO'));

// Verificar si el usuario está logueado
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Obtener el ID de la inspección
$inspeccion_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if (!$inspeccion_id) {
    header('Location: inspecciones.php');
    exit();
}

try {
    $inspeccion = new Inspeccion();
    $inmueble = new Inmueble();
    
    // Obtener datos de la inspección usando el método correcto
    $inspeccion_data = $inspeccion->getById($inspeccion_id);
    
    if (!$inspeccion_data) {
        $_SESSION['error'] = 'Inspección no encontrada.';
        header('Location: inspecciones.php');
        exit();
    }
    
    // Verificar permisos de edición
    $puede_editar = false;

    // Debug: mostrar información para diagnóstico
    error_log("=== DEBUG PERMISOS EDICIÓN ===");
    error_log("Usuario ID: " . $_SESSION['user_id']);
    error_log("Inspector ID de inspección: " . $inspeccion_data['inspector_id']);
    error_log("Estado inspección: " . $inspeccion_data['estado']);
    error_log("isAdmin(): " . (isAdmin() ? 'SÍ' : 'NO'));

    if (isAdmin()) {
        // Los administradores pueden editar cualquier inspección
        $puede_editar = true;
        error_log("Permiso concedido: ES ADMINISTRADOR");
    } else {
        // Los usuarios normales solo pueden editar sus propios borradores
        $puede_editar = ($inspeccion_data['inspector_id'] == $_SESSION['user_id'] && 
                        $inspeccion_data['estado'] === 'borrador');
        error_log("Permiso usuario normal: " . ($puede_editar ? 'SÍ' : 'NO'));
        error_log("Es su inspección: " . ($inspeccion_data['inspector_id'] == $_SESSION['user_id'] ? 'SÍ' : 'NO'));
        error_log("Es borrador: " . ($inspeccion_data['estado'] === 'borrador' ? 'SÍ' : 'NO'));
    }

    error_log("RESULTADO FINAL puede_editar: " . ($puede_editar ? 'SÍ' : 'NO'));
    error_log("=== FIN DEBUG ===");

    if (!$puede_editar) {
        $_SESSION['error'] = 'No tienes permisos para editar esta inspección. Debug: isAdmin=' . (isAdmin() ? 'SÍ' : 'NO') . ', estado=' . $inspeccion_data['estado'];
        header('Location: inspecciones.php');
        exit();
    }
    
    // Procesar el formulario si se envió
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $inmueble_id = $_POST['inmueble_id'] ?? '';
        $fecha_inspeccion = $_POST['fecha_inspeccion'] ?? '';
        $comentarios = $_POST['comentarios'] ?? '';
        $completar = isset($_POST['completar']);
        
        // Validaciones básicas
        if (empty($inmueble_id) || empty($fecha_inspeccion)) {
            $error = 'Todos los campos obligatorios deben ser completados.';
        } else {
            $database = new Database();
            $db = $database->getConnection();
            
            // Actualizar datos básicos de la inspección
            $stmt = $db->prepare("
                UPDATE inspecciones 
                SET inmueble_id = ?, fecha_inspeccion = ?, comentarios = ?
                WHERE id = ?
            ");
            $stmt->execute([$inmueble_id, $fecha_inspeccion, $comentarios, $inspeccion_id]);
            
            // Procesar respuestas de elementos
            $respuestas = [];
            foreach ($_POST as $key => $value) {
                if (strpos($key, 'elemento_') === 0) {
                    $elemento_id = str_replace('elemento_', '', $key);
                    $respuestas[$elemento_id] = [
                        'respuesta' => $value,
                        'observaciones' => $_POST['obs_' . $elemento_id] ?? ''
                    ];
                }
            }
            
            // Procesar fotos
            if (!empty($_FILES)) {
                foreach ($_FILES as $key => $file) {
                    if (strpos($key, 'foto_') === 0 && $file['error'] === UPLOAD_ERR_OK) {
                        $elemento_id = str_replace('foto_', '', $key);
                        
                        // Validar archivo
                        $allowed_types = ['image/jpeg', 'image/png', 'image/gif'];
                        if (in_array($file['type'], $allowed_types) && $file['size'] <= 5 * 1024 * 1024) {
                            $upload_dir = 'uploads/fotos/';
                            if (!is_dir($upload_dir)) {
                                mkdir($upload_dir, 0777, true);
                            }
                            
                            $filename = uniqid() . '_' . basename($file['name']);
                            $filepath = $upload_dir . $filename;
                            
                            if (move_uploaded_file($file['tmp_name'], $filepath)) {
                                if (isset($respuestas[$elemento_id])) {
                                    $respuestas[$elemento_id]['foto'] = $filepath;
                                }
                            }
                        }
                    }
                }
            }
            
            // Guardar respuestas usando el método de la clase
            if (!empty($respuestas)) {
                $inspeccion->saveRespuestas($inspeccion_id, $respuestas);
            }
            
            // Si se está completando la inspección
            if ($completar && $inspeccion_data['estado'] === 'borrador') {
                $inspeccion->completarInspeccion($inspeccion_id);
                $_SESSION['success'] = 'Inspección completada exitosamente.';
                header('Location: inspecciones.php');
                exit();
            } else {
                $_SESSION['success'] = 'Inspección actualizada exitosamente.';
                header('Location: editar_inspeccion.php?id=' . $inspeccion_id);
                exit();
            }
        }
    }
    
    // Obtener datos para el formulario
    $inmuebles = $inmueble->getAll();
    
    // Obtener elementos de inspección
    $elementos_inspeccion = $inspeccion->getElementosInspeccion($inspeccion_data['tipo_inspeccion_id']);
    
    // Organizar elementos por sección
    $elementos_por_seccion = [];
    foreach ($elementos_inspeccion as $elem) {
        $seccion_nombre = $elem['seccion_nombre'];
        if (!isset($elementos_por_seccion[$seccion_nombre])) {
            $elementos_por_seccion[$seccion_nombre] = [];
        }
        $elementos_por_seccion[$seccion_nombre][] = $elem;
    }
    
    // Obtener respuestas existentes
    $respuestas_inspeccion = $inspeccion->getRespuestas($inspeccion_id);
    $respuestas_existentes = [];
    foreach ($respuestas_inspeccion as $resp) {
        $respuestas_existentes[$resp['elemento_id']] = $resp['respuesta'];
    }
    
    // Obtener fotos existentes
    $database = new Database();
    $db = $database->getConnection();
    $stmt = $db->prepare("
        SELECT elemento_id, ruta_archivo 
        FROM fotos_inspeccion 
        WHERE inspeccion_id = ?
    ");
    $stmt->execute([$inspeccion_id]);
    $fotos_existentes = [];
    while ($row = $stmt->fetch()) {
        $fotos_existentes[$row['elemento_id']] = $row['ruta_archivo'];
    }
    
} catch (Exception $e) {
    error_log("Error en editar_inspeccion.php: " . $e->getMessage());
    $_SESSION['error'] = 'Error al cargar la inspección: ' . $e->getMessage();
    header('Location: inspecciones.php');
    exit();
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Editar Inspección</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        :root {
            --primary: #2c3e50;
            --secondary: #3498db;
            --success: #27ae60;
            --warning: #f39c12;
            --danger: #e74c3c;
            --gray-100: #f8f9fa;
            --gray-200: #e9ecef;
            --gray-300: #dee2e6;
        }

        body {
            background-color: var(--gray-100);
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }

        .main-header {
            background: linear-gradient(135deg, var(--primary) 0%, var(--secondary) 100%);
            color: white;
            padding: 2rem 0;
            margin-bottom: 2rem;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
        }

        .progress-circle {
            width: 80px;
            height: 80px;
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            font-weight: bold;
            font-size: 1.1rem;
            color: white;
            background: conic-gradient(var(--success) 0deg, var(--gray-200) 0deg);
        }

        .inspection-form {
            background: white;
            border-radius: 12px;
            box-shadow: 0 4px 6px rgba(0,0,0,0.1);
            overflow: hidden;
        }

        .section-badge {
            font-size: 0.75rem;
            padding: 0.25rem 0.5rem;
            border-radius: 12px;
            font-weight: 600;
        }

        .badge-pending { background-color: var(--gray-300); color: #666; }
        .badge-partial { background-color: var(--warning); color: white; }
        .badge-complete { background-color: var(--success); color: white; }

        .inspection-element {
            border-bottom: 1px solid var(--gray-200);
            padding: 1.5rem;
            transition: background-color 0.2s;
        }

        .inspection-element:hover {
            background-color: #f8f9fa;
        }

        .inspection-element:last-child {
            border-bottom: none;
        }

        .radio-group {
            display: flex;
            gap: 1rem;
            margin-top: 0.5rem;
        }

        .radio-option {
            flex: 1;
        }

        .radio-option input[type="radio"] {
            display: none;
        }

        .radio-option label {
            display: block;
            padding: 0.75rem;
            border: 2px solid var(--gray-300);
            border-radius: 8px;
            text-align: center;
            cursor: pointer;
            transition: all 0.2s;
            font-weight: 500;
        }

        .radio-option input[type="radio"]:checked + label {
            border-color: var(--success);
            background-color: var(--success);
            color: white;
        }

        .radio-option.danger input[type="radio"]:checked + label {
            border-color: var(--danger);
            background-color: var(--danger);
        }

        .photo-upload {
            border: 2px dashed var(--gray-300);
            border-radius: 8px;
            padding: 2rem;
            text-align: center;
            cursor: pointer;
            transition: all 0.2s;
            margin-top: 1rem;
        }

        .photo-upload:hover {
            border-color: var(--secondary);
            background-color: #f8f9fa;
        }

        .photo-upload.has-image {
            border-color: var(--success);
            background-color: #f0f9f0;
        }

        .photo-upload input[type="file"] {
            display: none;
        }

        .photo-preview {
            max-width: 200px;
            max-height: 200px;
            border-radius: 8px;
            margin-top: 1rem;
            display: none;
        }

        .action-buttons {
            background: white;
            padding: 2rem;
            border-top: 1px solid var(--gray-200);
            display: flex;
            gap: 1rem;
            justify-content: center;
        }

        .btn-custom {
            padding: 0.75rem 2rem;
            border-radius: 8px;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.5px;
            transition: all 0.2s;
        }

        .accordion-button {
            background-color: var(--gray-100);
            border: none;
            font-weight: 600;
            color: var(--primary);
        }

        .accordion-button:not(.collapsed) {
            background-color: var(--secondary);
            color: white;
        }

        .accordion-button:focus {
            box-shadow: none;
            border-color: var(--secondary);
        }

        .alert-admin {
            background: linear-gradient(135deg, #3498db 0%, #2980b9 100%);
            border: none;
            color: white;
            border-radius: 8px;
        }
    </style>
</head>
<body>
    <div class="main-header">
        <div class="container">
            <div class="row align-items-center">
                <div class="col-md-8">
                    <h1 class="mb-0">
                        <i class="fas fa-edit me-3"></i>
                        Editar Inspección
                    </h1>
                    <p class="mb-0 mt-2 opacity-75">
                        Tipo: <?php echo htmlspecialchars($inspeccion_data['tipo_inspeccion_nombre'] ?? 'N/A'); ?> | 
                        Estado: <?php echo ucfirst($inspeccion_data['estado']); ?>
                    </p>
                </div>
                <div class="col-md-4 text-end">
                    <div class="progress-circle" id="progressCircle">
                        <span id="progressText">0%</span>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="container">
        <?php if (isAdmin() && $inspeccion_data['estado'] !== 'borrador'): ?>
        <div class="alert alert-admin mb-4">
            <i class="fas fa-crown me-2"></i>
            <strong>Modo Administrador:</strong> Estás editando una inspección <?php echo $inspeccion_data['estado']; ?> con permisos de administrador.
        </div>
        <?php endif; ?>

        <?php if (isset($error)): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-triangle me-2"></i>
            <?php echo $error; ?>
        </div>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
        <div class="alert alert-success">
            <i class="fas fa-check-circle me-2"></i>
            <?php echo $_SESSION['success']; unset($_SESSION['success']); ?>
        </div>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-triangle me-2"></i>
            <?php echo $_SESSION['error']; unset($_SESSION['error']); ?>
        </div>
        <?php endif; ?>

        <form method="POST" enctype="multipart/form-data" id="inspectionForm">
            <div class="inspection-form">
                <!-- Datos básicos -->
                <div class="p-4 border-bottom">
                    <h5 class="mb-3">
                        <i class="fas fa-info-circle me-2"></i>
                        Datos Básicos
                    </h5>
                    <div class="row">
                        <div class="col-md-6">
                            <label for="inmueble_id" class="form-label">Inmueble *</label>
                            <select name="inmueble_id" id="inmueble_id" class="form-select" required>
                                <option value="">Seleccionar inmueble...</option>
                                <?php foreach ($inmuebles as $inm): ?>
                                <option value="<?php echo $inm['id']; ?>" 
                                        <?php echo ($inm['id'] == $inspeccion_data['inmueble_id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($inm['nombre']); ?>
                                </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="col-md-6">
                            <label for="fecha_inspeccion" class="form-label">Fecha de Inspección *</label>
                            <input type="date" name="fecha_inspeccion" id="fecha_inspeccion" 
                                   class="form-control" required
                                   value="<?php echo $inspeccion_data['fecha_inspeccion']; ?>">
                        </div>
                    </div>
                    <div class="mt-3">
                        <label for="comentarios" class="form-label">Comentarios Generales</label>
                        <textarea name="comentarios" id="comentarios" class="form-control" rows="3"
                                  placeholder="Comentarios adicionales sobre la inspección..."><?php echo htmlspecialchars($inspeccion_data['comentarios'] ?? ''); ?></textarea>
                    </div>
                </div>

                <!-- Elementos de inspección -->
                <?php if (!empty($elementos_por_seccion)): ?>
                <div class="accordion" id="inspectionAccordion">
                    <?php foreach ($elementos_por_seccion as $seccion_nombre => $elementos): ?>
                    <div class="accordion-item">
                        <h2 class="accordion-header">
                            <button class="accordion-button collapsed" type="button" 
                                    data-bs-toggle="collapse" 
                                    data-bs-target="#section-<?php echo md5($seccion_nombre); ?>">
                                <i class="fas fa-list-check me-2"></i>
                                <?php echo htmlspecialchars($seccion_nombre); ?>
                                <span class="section-badge ms-auto me-3" id="section-badge-<?php echo md5($seccion_nombre); ?>">
                                    0/<?php echo count($elementos); ?>
                                </span>
                            </button>
                        </h2>
                        <div id="section-<?php echo md5($seccion_nombre); ?>" 
                             class="accordion-collapse collapse" 
                             data-bs-parent="#inspectionAccordion">
                            <div class="accordion-body p-0">
                                <?php foreach ($elementos as $elem): ?>
                                <div class="inspection-element" data-section="<?php echo md5($seccion_nombre); ?>">
                                    <h6 class="mb-2">
                                        <i class="fas fa-check-circle me-2 text-muted"></i>
                                        <?php echo htmlspecialchars($elem['descripcion']); ?>
                                    </h6>

                                    <div class="radio-group">
                                        <div class="radio-option">
                                            <input type="radio" 
                                                   id="elemento_<?php echo $elem['id']; ?>_bueno" 
                                                   name="elemento_<?php echo $elem['id']; ?>" 
                                                   value="bueno"
                                                   <?php echo (isset($respuestas_existentes[$elem['id']]) && $respuestas_existentes[$elem['id']] === 'bueno') ? 'checked' : ''; ?>>
                                            <label for="elemento_<?php echo $elem['id']; ?>_bueno">
                                                <i class="fas fa-check me-1"></i>
                                                Bueno
                                            </label>
                                        </div>
                                        <div class="radio-option">
                                            <input type="radio" 
                                                   id="elemento_<?php echo $elem['id']; ?>_regular" 
                                                   name="elemento_<?php echo $elem['id']; ?>" 
                                                   value="regular"
                                                   <?php echo (isset($respuestas_existentes[$elem['id']]) && $respuestas_existentes[$elem['id']] === 'regular') ? 'checked' : ''; ?>>
                                            <label for="elemento_<?php echo $elem['id']; ?>_regular">
                                                <i class="fas fa-exclamation me-1"></i>
                                                Regular
                                            </label>
                                        </div>
                                        <div class="radio-option danger">
                                            <input type="radio" 
                                                   id="elemento_<?php echo $elem['id']; ?>_malo" 
                                                   name="elemento_<?php echo $elem['id']; ?>" 
                                                   value="malo"
                                                   <?php echo (isset($respuestas_existentes[$elem['id']]) && $respuestas_existentes[$elem['id']] === 'malo') ? 'checked' : ''; ?>>
                                            <label for="elemento_<?php echo $elem['id']; ?>_malo">
                                                <i class="fas fa-times me-1"></i>
                                                Malo
                                            </label>
                                        </div>
                                    </div>

                                    <!-- Subida de foto -->
                                    <div class="photo-upload" onclick="document.getElementById('foto_<?php echo $elem['id']; ?>').click()">
                                        <input type="file" 
                                               id="foto_<?php echo $elem['id']; ?>" 
                                               name="foto_<?php echo $elem['id']; ?>" 
                                               accept="image/*"
                                               onchange="previewPhoto(this, <?php echo $elem['id']; ?>)">
                                        <div id="upload-content-<?php echo $elem['id']; ?>">
                                            <?php if (isset($fotos_existentes[$elem['id']])): ?>
                                            <i class="fas fa-check-circle fa-2x text-success mb-2"></i>
                                            <p class="mb-0 text-success">✓ Foto cargada</p>
                                            <small class="text-muted">Haz clic para cambiar</small>
                                            <?php else: ?>
                                            <i class="fas fa-camera fa-2x text-muted mb-2"></i>
                                            <p class="mb-0">Subir foto (opcional)</p>
                                            <small class="text-muted">Haz clic para seleccionar</small>
                                            <?php endif; ?>
                                        </div>
                                        <img id="preview_<?php echo $elem['id']; ?>" class="photo-preview"
                                             <?php if (isset($fotos_existentes[$elem['id']])): ?>
                                             src="<?php echo htmlspecialchars($fotos_existentes[$elem['id']]); ?>" style="display: block;"
                                             <?php endif; ?>>
                                    </div>
                                </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                    <?php endforeach; ?>
                </div>
                <?php else: ?>
                <div class="p-4 text-center text-muted">
                    <i class="fas fa-info-circle fa-2x mb-3"></i>
                    <p>No hay elementos de inspección configurados para este tipo.</p>
                </div>
                <?php endif; ?>
            </div>

            <div class="action-buttons">
                <button type="submit" class="btn btn-primary btn-custom" id="saveBtn">
                    <i class="fas fa-save me-2"></i>
                    Guardar Cambios
                </button>
                
                <?php if ($inspeccion_data['estado'] === 'borrador'): ?>
                <button type="submit" name="completar" class="btn btn-success btn-custom" id="completeBtn">
                    <i class="fas fa-check-double me-2"></i>
                    Completar Inspección
                </button>
                <?php endif; ?>
                
                <a href="inspecciones.php" class="btn btn-secondary btn-custom">
                    <i class="fas fa-arrow-left me-2"></i>
                    Volver
                </a>
            </div>
        </form>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Variables globales
        const totalElements = <?php echo array_sum(array_map('count', $elementos_por_seccion)); ?>;
        let answeredElements = 0;
        let photosUploaded = 0;

        console.log('🚀 Editor iniciado - Total elementos:', totalElements);

        // Función para previsualizar fotos
        function previewPhoto(input, elementId) {
            console.log('📸 Previsualizando foto para elemento:', elementId);
            
            const preview = document.getElementById('preview_' + elementId);
            const uploadContent = document.getElementById('upload-content-' + elementId);
            const uploadZone = input.closest('.photo-upload');
            
            if (input.files && input.files[0]) {
                const file = input.files[0];
                console.log('📁 Archivo:', file.name, 'Tamaño:', file.size);
                
                if (!file.type.startsWith('image/')) {
                    alert('❌ Solo se permiten imágenes');
                    input.value = '';
                    return;
                }
                
                if (file.size > 5 * 1024 * 1024) {
                    alert('❌ Archivo muy grande (máximo 5MB)');
                    input.value = '';
                    return;
                }
                
                const reader = new FileReader();
                reader.onload = function(e) {
                    preview.src = e.target.result;
                    preview.style.display = 'block';
                    uploadContent.innerHTML = `
                        <i class="fas fa-check-circle fa-2x text-success mb-2"></i>
                        <p class="mb-0 text-success">✓ ${file.name}</p>
                        <small class="text-muted">Haz clic para cambiar</small>
                    `;
                    uploadZone.classList.add('has-image');
                    photosUploaded++;
                    console.log('✅ Foto cargada exitosamente');
                };
                reader.readAsDataURL(file);
            }
        }

        // Función para actualizar progreso
        function updateProgress() {
            const checkedRadios = document.querySelectorAll('input[type="radio"]:checked');
            answeredElements = checkedRadios.length;
            
            const percentage = Math.round((answeredElements / totalElements) * 100);
            
            const progressCircle = document.getElementById('progressCircle');
            const progressText = document.getElementById('progressText');
            
            if (progressCircle && progressText) {
                const degrees = (percentage / 100) * 360;
                progressCircle.style.background = `conic-gradient(var(--success) ${degrees}deg, var(--gray-200) ${degrees}deg)`;
                progressText.textContent = percentage + '%';
            }
            
            // Actualizar badges por sección
            const sections = {};
            checkedRadios.forEach(radio => {
                const element = radio.closest('.inspection-element');
                if (element) {
                    const section = element.dataset.section;
                    if (!sections[section]) sections[section] = 0;
                    sections[section]++;
                }
            });
            
            <?php foreach ($elementos_por_seccion as $seccion_nombre => $elementos_seccion): ?>
                const sectionId_<?php echo md5($seccion_nombre); ?> = '<?php echo md5($seccion_nombre); ?>';
                const count_<?php echo md5($seccion_nombre); ?> = sections[sectionId_<?php echo md5($seccion_nombre); ?>] || 0;
                const total_<?php echo md5($seccion_nombre); ?> = <?php echo count($elementos_seccion); ?>;
                
                const sectionBadge_<?php echo md5($seccion_nombre); ?> = document.getElementById('section-badge-<?php echo md5($seccion_nombre); ?>');
                
                if (sectionBadge_<?php echo md5($seccion_nombre); ?>) {
                    sectionBadge_<?php echo md5($seccion_nombre); ?>.textContent = count_<?php echo md5($seccion_nombre); ?> + '/' + total_<?php echo md5($seccion_nombre); ?>;
                    sectionBadge_<?php echo md5($seccion_nombre); ?>.className = 'section-badge ms-auto me-3 ';
                    
                    if (count_<?php echo md5($seccion_nombre); ?> === total_<?php echo md5($seccion_nombre); ?>) {
                        sectionBadge_<?php echo md5($seccion_nombre); ?>.className += 'badge-complete';
                    } else if (count_<?php echo md5($seccion_nombre); ?> > 0) {
                        sectionBadge_<?php echo md5($seccion_nombre); ?>.className += 'badge-partial';
                    } else {
                        sectionBadge_<?php echo md5($seccion_nombre); ?>.className += 'badge-pending';
                    }
                }
            <?php endforeach; ?>
        }

        // Inicializar
        document.addEventListener('DOMContentLoaded', function() {
            console.log('🎯 DOM cargado, configurando eventos...');
            
            // Configurar radio buttons
            const radioButtons = document.querySelectorAll('input[type="radio"]');
            radioButtons.forEach(radio => {
                radio.addEventListener('change', updateProgress);
            });

            // Configurar formulario
            const form = document.getElementById('inspectionForm');
            if (form) {
                form.addEventListener('submit', function(e) {
                    console.log('📤 Actualizando inspección...');
                    
                    const inmueble = document.querySelector('select[name="inmueble_id"]').value;
                    const fecha = document.querySelector('input[name="fecha_inspeccion"]').value;
                    
                    if (!inmueble) {
                        e.preventDefault();
                        alert('❌ Selecciona un inmueble');
                        return false;
                    }
                    
                    if (!fecha) {
                        e.preventDefault();
                        alert('❌ Selecciona la fecha');
                        return false;
                    }
                    
                    const isCompleting = e.submitter && e.submitter.name === 'completar';
                    
                    if (isCompleting && answeredElements < totalElements) {
                        e.preventDefault();
                        alert(`❌ Para completar debe responder todo.\nProgreso: ${answeredElements}/${totalElements}`);
                        return false;
                    }
                    
                    const saveBtn = document.getElementById('saveBtn');
                    const completeBtn = document.getElementById('completeBtn');
                    
                    if (saveBtn) saveBtn.disabled = true;
                    if (completeBtn) completeBtn.disabled = true;
                    
                    if (isCompleting && completeBtn) {
                        completeBtn.innerHTML = '<i class="fas fa-spinner fa-spin me-2"></i>Completando...';
                    } else if (saveBtn) {
                        saveBtn.innerHTML = '<i class="fas fa-spinner fa-spin me-2"></i>Actualizando...';
                    }
                    
                    return true;
                });
            }

            updateProgress();
            console.log('🎉 Editor inicializado correctamente');
        });
    </script>
</body>
</html>
