<?php
session_start();
echo "<h1>✅ Editar Inspección - Versión Simple</h1>";

// Verificar parámetros
$id = $_GET['id'] ?? null;
echo "<p><strong>ID recibido:</strong> " . ($id ? $id : 'NINGUNO') . "</p>";

if (!$id) {
    echo "<div style='color: red; border: 2px solid red; padding: 10px;'>";
    echo "❌ <strong>ERROR:</strong> No se recibió ID de inspección";
    echo "</div>";
    echo "<p><a href='inspecciones.php'>🔙 Volver</a></p>";
    exit;
}

// Verificar sesión
if (!isset($_SESSION['user_id'])) {
    echo "<div style='color: red; border: 2px solid red; padding: 10px;'>";
    echo "❌ <strong>ERROR:</strong> Usuario no logueado";
    echo "</div>";
    echo "<p><a href='login.php'>🔑 Iniciar Sesión</a></p>";
    exit;
}

echo "<div style='color: green; border: 2px solid green; padding: 10px;'>";
echo "✅ <strong>ÉXITO:</strong> Llegaste al editor de inspección";
echo "<br>• ID: {$id}";
echo "<br>• Usuario: " . ($_SESSION['user_name'] ?? $_SESSION['user_id']);
echo "<br>• Rol: " . ($_SESSION['rol'] ?? 'usuario');
echo "</div>";

// Probar conexión a BD
try {
    require_once 'config/database.php';
    $database = new Database();
    $db = $database->getConnection();
    
    $stmt = $db->prepare("SELECT * FROM inspecciones WHERE id = ?");
    $stmt->execute([$id]);
    $inspeccion = $stmt->fetch();
    
    if ($inspeccion) {
        echo "<h2>📋 Datos de la Inspección:</h2>";
        echo "<ul>";
        echo "<li><strong>ID:</strong> {$inspeccion['id']}</li>";
        echo "<li><strong>Estado:</strong> {$inspeccion['estado']}</li>";
        echo "<li><strong>Fecha:</strong> {$inspeccion['fecha_inspeccion']}</li>";
        echo "<li><strong>Inspector ID:</strong> {$inspeccion['inspector_id']}</li>";
        echo "</ul>";
        
        // Verificar permisos
        $puede_editar = false;
        if (isset($_SESSION['rol']) && $_SESSION['rol'] === 'administrador') {
            $puede_editar = true;
            echo "<p style='color: blue;'>🔑 <strong>Permisos:</strong> Administrador - Puede editar</p>";
        } elseif ($inspeccion['estado'] === 'borrador' && $inspeccion['inspector_id'] == $_SESSION['user_id']) {
            $puede_editar = true;
            echo "<p style='color: green;'>✅ <strong>Permisos:</strong> Es tu borrador - Puede editar</p>";
        } else {
            echo "<p style='color: red;'>❌ <strong>Permisos:</strong> No puedes editar esta inspección</p>";
        }
        
        if ($puede_editar) {
            echo "<div style='background: #f0f8ff; border: 2px solid blue; padding: 15px; margin: 10px 0;'>";
            echo "<h3>🎉 ¡PERFECTO!</h3>";
            echo "<p>El sistema de edición está funcionando correctamente.</p>";
            echo "<p><strong>Próximo paso:</strong> Cargar el editor completo...</p>";
            echo "<p><a href='editar_inspeccion.php?id={$id}' style='background: green; color: white; padding: 10px; text-decoration: none; border-radius: 5px;'>🚀 IR AL EDITOR COMPLETO</a></p>";
            echo "</div>";
        }
        
    } else {
        echo "<div style='color: red; border: 2px solid red; padding: 10px;'>";
        echo "❌ <strong>ERROR:</strong> Inspección no encontrada";
        echo "</div>";
    }
    
} catch (Exception $e) {
    echo "<div style='color: red; border: 2px solid red; padding: 10px;'>";
    echo "❌ <strong>ERROR BD:</strong> " . $e->getMessage();
    echo "</div>";
}

echo "<hr>";
echo "<p><a href='inspecciones.php'>🔙 Volver a Inspecciones</a></p>";
echo "<p><a href='test_editar.php'>🔧 Volver a Diagnóstico</a></p>";
?>
