<?php
// Configuración directa de la base de datos
$host = 'localhost';
$dbname = 'sistema_inspeccion';
$username = 'root';
$password = '';

echo "<h2>🔧 Reparador del Campo Estado</h2>";
echo "<style>
    body { font-family: Arial, sans-serif; margin: 20px; }
    .success { background: #d4edda; padding: 10px; border-radius: 5px; margin: 10px 0; }
    .error { background: #f8d7da; padding: 10px; border-radius: 5px; margin: 10px 0; }
    .info { background: #d1ecf1; padding: 10px; border-radius: 5px; margin: 10px 0; }
    .warning { background: #fff3cd; padding: 10px; border-radius: 5px; margin: 10px 0; }
    table { border-collapse: collapse; width: 100%; margin: 10px 0; }
    th, td { border: 1px solid #ddd; padding: 8px; text-align: left; }
    th { background-color: #f2f2f2; }
</style>";

try {
    // Conectar directamente a la base de datos
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    
    echo "<div class='success'>✅ Conexión a la base de datos exitosa</div>";
    
    // Verificar estructura actual del campo estado
    echo "<h3>🔍 Analizando Campo 'estado':</h3>";
    $stmt = $pdo->query("SHOW COLUMNS FROM inspecciones LIKE 'estado'");
    $campo_estado = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if ($campo_estado) {
        echo "<div class='info'>";
        echo "<h4>📋 Estructura Actual:</h4>";
        echo "<table>";
        echo "<tr><th>Campo</th><th>Tipo</th><th>Nulo</th><th>Default</th></tr>";
        echo "<tr>";
        echo "<td><strong>" . $campo_estado['Field'] . "</strong></td>";
        echo "<td>" . $campo_estado['Type'] . "</td>";
        echo "<td>" . $campo_estado['Null'] . "</td>";
        echo "<td>" . ($campo_estado['Default'] ?? 'NULL') . "</td>";
        echo "</tr>";
        echo "</table>";
        echo "</div>";
        
        // Verificar si es ENUM y qué valores tiene
        $tipo = $campo_estado['Type'];
        echo "<div class='warning'>";
        echo "<h4>⚠️ Problema Detectado:</h4>";
        echo "<p>El campo 'estado' tiene tipo: <strong>$tipo</strong></p>";
        
        if (strpos($tipo, 'enum') !== false) {
            echo "<p>Es un campo ENUM que probablemente no incluye 'aprobada'.</p>";
            
            // Extraer valores del ENUM
            preg_match_all("/'([^']+)'/", $tipo, $matches);
            $valores_actuales = $matches[1];
            echo "<p><strong>Valores actuales permitidos:</strong> " . implode(', ', $valores_actuales) . "</p>";
            
            if (!in_array('aprobada', $valores_actuales)) {
                echo "<p class='error'>❌ El valor 'aprobada' NO está permitido en el ENUM actual.</p>";
                
                // Agregar 'aprobada' al ENUM
                $nuevos_valores = array_merge($valores_actuales, ['aprobada']);
                $enum_string = "'" . implode("','", $nuevos_valores) . "'";
                
                echo "<div class='info'>";
                echo "<h4>🔧 Aplicando Corrección:</h4>";
                echo "<p>Agregando 'aprobada' a los valores permitidos...</p>";
                echo "</div>";
                
                try {
                    $sql = "ALTER TABLE inspecciones MODIFY COLUMN estado ENUM($enum_string) DEFAULT 'borrador'";
                    $pdo->exec($sql);
                    echo "<div class='success'>✅ Campo 'estado' actualizado exitosamente</div>";
                    echo "<p><strong>Nuevos valores permitidos:</strong> " . implode(', ', $nuevos_valores) . "</p>";
                } catch (Exception $e) {
                    echo "<div class='error'>❌ Error al actualizar ENUM: " . $e->getMessage() . "</div>";
                    
                    // Alternativa: cambiar a VARCHAR
                    echo "<div class='warning'>";
                    echo "<h4>🔄 Intentando Alternativa:</h4>";
                    echo "<p>Cambiando el campo a VARCHAR para mayor flexibilidad...</p>";
                    echo "</div>";
                    
                    try {
                        $sql = "ALTER TABLE inspecciones MODIFY COLUMN estado VARCHAR(20) DEFAULT 'borrador'";
                        $pdo->exec($sql);
                        echo "<div class='success'>✅ Campo 'estado' cambiado a VARCHAR exitosamente</div>";
                    } catch (Exception $e2) {
                        echo "<div class='error'>❌ Error al cambiar a VARCHAR: " . $e2->getMessage() . "</div>";
                    }
                }
            } else {
                echo "<div class='success'>✅ El valor 'aprobada' ya está permitido en el ENUM.</div>";
            }
        } else {
            // No es ENUM, verificar si es VARCHAR muy corto
            if (strpos($tipo, 'varchar') !== false) {
                preg_match('/varchar$$(\d+)$$/', $tipo, $matches);
                $longitud = $matches[1] ?? 0;
                echo "<p>Es un VARCHAR de longitud: <strong>$longitud</strong></p>";
                
                if ($longitud < 10) {
                    echo "<p class='error'>❌ VARCHAR muy corto para 'aprobada' (8 caracteres).</p>";
                    
                    try {
                        $sql = "ALTER TABLE inspecciones MODIFY COLUMN estado VARCHAR(20) DEFAULT 'borrador'";
                        $pdo->exec($sql);
                        echo "<div class='success'>✅ Campo 'estado' expandido a VARCHAR(20)</div>";
                    } catch (Exception $e) {
                        echo "<div class='error'>❌ Error al expandir VARCHAR: " . $e->getMessage() . "</div>";
                    }
                } else {
                    echo "<div class='success'>✅ VARCHAR tiene longitud suficiente.</div>";
                }
            }
        }
        echo "</div>";
        
    } else {
        echo "<div class='error'>❌ No se encontró el campo 'estado' en la tabla inspecciones</div>";
    }
    
    // Verificar estructura final
    echo "<h3>📊 Estructura Final:</h3>";
    $stmt = $pdo->query("SHOW COLUMNS FROM inspecciones LIKE 'estado'");
    $campo_final = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if ($campo_final) {
        echo "<div class='success'>";
        echo "<table>";
        echo "<tr><th>Campo</th><th>Tipo</th><th>Nulo</th><th>Default</th></tr>";
        echo "<tr>";
        echo "<td><strong>" . $campo_final['Field'] . "</strong></td>";
        echo "<td>" . $campo_final['Type'] . "</td>";
        echo "<td>" . $campo_final['Null'] . "</td>";
        echo "<td>" . ($campo_final['Default'] ?? 'NULL') . "</td>";
        echo "</tr>";
        echo "</table>";
        echo "</div>";
    }
    
    // Probar insertar 'aprobada'
    echo "<h3>🧪 Prueba de Funcionalidad:</h3>";
    try {
        // Buscar una inspección completada para probar
        $stmt = $pdo->query("SELECT id FROM inspecciones WHERE estado = 'completada' LIMIT 1");
        $inspeccion_prueba = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($inspeccion_prueba) {
            $id_prueba = $inspeccion_prueba['id'];
            echo "<div class='info'>🔍 Probando con inspección ID: $id_prueba</div>";
            
            // Intentar actualizar a 'aprobada'
            $stmt = $pdo->prepare("UPDATE inspecciones SET estado = 'aprobada' WHERE id = ?");
            if ($stmt->execute([$id_prueba])) {
                echo "<div class='success'>✅ Prueba exitosa: Se pudo cambiar estado a 'aprobada'</div>";
                
                // Volver a 'completada' para no afectar datos
                $stmt = $pdo->prepare("UPDATE inspecciones SET estado = 'completada' WHERE id = ?");
                $stmt->execute([$id_prueba]);
                echo "<div class='info'>🔄 Estado restaurado a 'completada' para mantener datos originales</div>";
            } else {
                echo "<div class='error'>❌ Aún no se puede cambiar a 'aprobada'</div>";
            }
        } else {
            echo "<div class='warning'>⚠️ No hay inspecciones completadas para probar</div>";
        }
    } catch (Exception $e) {
        echo "<div class='error'>❌ Error en prueba: " . $e->getMessage() . "</div>";
    }
    
    // Mostrar estados actuales
    echo "<h3>📈 Estados Actuales en la Base de Datos:</h3>";
    $stmt = $pdo->query("SELECT estado, COUNT(*) as cantidad FROM inspecciones GROUP BY estado");
    echo "<table>";
    echo "<tr><th>Estado</th><th>Cantidad</th></tr>";
    while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        echo "<tr><td><strong>" . $row['estado'] . "</strong></td><td>" . $row['cantidad'] . "</td></tr>";
    }
    echo "</table>";
    
} catch (Exception $e) {
    echo "<div class='error'>";
    echo "<h4>❌ Error de Conexión</h4>";
    echo "<p><strong>Error:</strong> " . $e->getMessage() . "</p>";
    echo "</div>";
}

echo "<hr>";
echo "<h3>🔗 Próximos Pasos:</h3>";
echo "<div class='info'>";
echo "<ol>";
echo "<li><strong>Si todo está OK:</strong> <a href='aprobar_simple.php?id=11'>Probar Aprobación Simple</a></li>";
echo "<li><strong>Ver inspecciones:</strong> <a href='inspecciones.php'>Lista de Inspecciones</a></li>";
echo "<li><strong>Dashboard:</strong> <a href='dashboard.php'>Volver al Inicio</a></li>";
echo "</ol>";
echo "</div>";
?>
