<?php
require_once 'config/database.php';

echo "<h2>🔧 Verificación y Corrección de la Columna Estado</h2>";

try {
    $database = new Database();
    $conn = $database->getConnection();
    
    echo "<h3>📋 Paso 1: Verificar estructura actual</h3>";
    
    // Verificar estructura de la tabla
    $query = "DESCRIBE inspecciones";
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $columns = $stmt->fetchAll();
    
    echo "<table border='1' style='border-collapse: collapse; margin: 10px 0;'>";
    echo "<tr><th>Campo</th><th>Tipo</th><th>Nulo</th><th>Clave</th><th>Por Defecto</th></tr>";
    
    $estado_exists = false;
    foreach ($columns as $column) {
        echo "<tr>";
        echo "<td>" . $column['Field'] . "</td>";
        echo "<td>" . $column['Type'] . "</td>";
        echo "<td>" . $column['Null'] . "</td>";
        echo "<td>" . $column['Key'] . "</td>";
        echo "<td>" . $column['Default'] . "</td>";
        echo "</tr>";
        
        if ($column['Field'] === 'estado') {
            $estado_exists = true;
        }
    }
    echo "</table>";
    
    echo "<h3>📊 Paso 2: Ver datos actuales</h3>";
    
    // Ver datos actuales
    $query = "SELECT id, numero_contrato, estado, fecha_inspeccion FROM inspecciones ORDER BY id DESC LIMIT 10";
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $inspecciones = $stmt->fetchAll();
    
    if (empty($inspecciones)) {
        echo "<p>❌ No hay inspecciones en la base de datos.</p>";
    } else {
        echo "<table border='1' style='border-collapse: collapse; margin: 10px 0;'>";
        echo "<tr><th>ID</th><th>Contrato</th><th>Estado</th><th>Fecha</th></tr>";
        foreach ($inspecciones as $insp) {
            echo "<tr>";
            echo "<td>" . $insp['id'] . "</td>";
            echo "<td>" . ($insp['numero_contrato'] ?: 'Sin contrato') . "</td>";
            echo "<td><strong>" . ($insp['estado'] ?: 'NULL') . "</strong></td>";
            echo "<td>" . $insp['fecha_inspeccion'] . "</td>";
            echo "</tr>";
        }
        echo "</table>";
    }
    
    echo "<h3>🔧 Paso 3: Aplicar correcciones</h3>";
    
    if (!$estado_exists) {
        echo "<p>⚠️ La columna 'estado' no existe. Creándola...</p>";
        $query = "ALTER TABLE inspecciones ADD COLUMN estado ENUM('borrador', 'completada', 'cancelada') DEFAULT 'borrador'";
        $stmt = $conn->prepare($query);
        if ($stmt->execute()) {
            echo "<p>✅ Columna 'estado' creada exitosamente.</p>";
        } else {
            echo "<p>❌ Error al crear la columna 'estado'.</p>";
        }
    } else {
        echo "<p>✅ La columna 'estado' ya existe.</p>";
        
        // Modificar la columna para asegurar el tipo correcto
        echo "<p>🔄 Modificando columna para asegurar tipo correcto...</p>";
        $query = "ALTER TABLE inspecciones MODIFY COLUMN estado ENUM('borrador', 'completada', 'cancelada') DEFAULT 'borrador'";
        $stmt = $conn->prepare($query);
        if ($stmt->execute()) {
            echo "<p>✅ Columna 'estado' modificada exitosamente.</p>";
        } else {
            echo "<p>❌ Error al modificar la columna 'estado'.</p>";
        }
    }
    
    // Actualizar registros con estado NULL o vacío
    echo "<p>🔄 Actualizando registros con estado NULL o vacío...</p>";
    $query = "UPDATE inspecciones SET estado = 'borrador' WHERE estado IS NULL OR estado = ''";
    $stmt = $conn->prepare($query);
    if ($stmt->execute()) {
        $affected = $stmt->rowCount();
        echo "<p>✅ Se actualizaron $affected registros.</p>";
    } else {
        echo "<p>❌ Error al actualizar registros.</p>";
    }
    
    echo "<h3>✅ Paso 4: Verificación final</h3>";
    
    // Verificar resultado final
    $query = "SELECT id, numero_contrato, estado, fecha_inspeccion FROM inspecciones ORDER BY id DESC LIMIT 10";
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $inspecciones_final = $stmt->fetchAll();
    
    if (empty($inspecciones_final)) {
        echo "<p>❌ No hay inspecciones para mostrar.</p>";
    } else {
        echo "<table border='1' style='border-collapse: collapse; margin: 10px 0;'>";
        echo "<tr><th>ID</th><th>Contrato</th><th>Estado</th><th>Fecha</th></tr>";
        foreach ($inspecciones_final as $insp) {
            $estado_color = '';
            switch ($insp['estado']) {
                case 'completada':
                    $estado_color = 'color: green; font-weight: bold;';
                    break;
                case 'borrador':
                    $estado_color = 'color: orange; font-weight: bold;';
                    break;
                case 'cancelada':
                    $estado_color = 'color: red; font-weight: bold;';
                    break;
            }
            
            echo "<tr>";
            echo "<td>" . $insp['id'] . "</td>";
            echo "<td>" . ($insp['numero_contrato'] ?: 'Sin contrato') . "</td>";
            echo "<td style='$estado_color'>" . $insp['estado'] . "</td>";
            echo "<td>" . $insp['fecha_inspeccion'] . "</td>";
            echo "</tr>";
        }
        echo "</table>";
    }
    
    echo "<h3>🎉 Proceso completado</h3>";
    echo "<p>✅ La base de datos ha sido verificada y corregida.</p>";
    echo "<p>🔗 <a href='nueva_inspeccion.php'>Crear Nueva Inspección</a> | <a href='inspecciones.php'>Ver Inspecciones</a></p>";
    
} catch (Exception $e) {
    echo "<p style='color: red;'>❌ Error: " . $e->getMessage() . "</p>";
}
?>

<style>
    body { font-family: Arial, sans-serif; margin: 20px; }
    table { width: 100%; }
    th, td { padding: 8px; text-align: left; }
    th { background-color: #f2f2f2; }
    h2, h3 { color: #333; }
</style>
