<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/FotoInspeccion.php';
require_once 'models/SeguimientoProblemas.php';

requireLogin();

// Verificar que se proporcione un ID
$id = $_GET['id'] ?? 0;
if (!$id) {
    header('Location: inspecciones.php');
    exit();
}

$inspeccion = new Inspeccion();
$fotoInspeccion = new FotoInspeccion();
$seguimiento = new SeguimientoProblemas();

// Obtener datos de la inspección
$inspeccion_data = $inspeccion->getById($id);
$respuestas = $inspeccion->getRespuestas($id);
$fotos = $fotoInspeccion->getFotosByInspeccion($id);
$problemas = $seguimiento->getProblemasByInspeccion($id);

if (!$inspeccion_data) {
    header('Location: inspecciones.php');
    exit();
}

// Agrupar respuestas por sección
$respuestas_por_seccion = [];
foreach ($respuestas as $respuesta) {
    $respuestas_por_seccion[$respuesta['seccion_nombre']][] = $respuesta;
}

// Agrupar fotos por elemento
$fotos_por_elemento = [];
foreach ($fotos as $foto) {
    $fotos_por_elemento[$foto['elemento_id']][] = $foto;
}

// Configurar TCPDF
require_once 'vendor/tcpdf/tcpdf.php';

class InspeccionPDF extends TCPDF {
    private $inspeccion_data;
    
    public function setInspeccionData($data) {
        $this->inspeccion_data = $data;
    }
    
    public function Header() {
        // Logo (si existe)
        $logo_path = 'assets/logo.png';
        if (file_exists($logo_path)) {
            $this->Image($logo_path, 15, 10, 30);
        }
        
        // Título
        $this->SetFont('helvetica', 'B', 16);
        $this->SetXY(50, 15);
        $this->Cell(0, 10, 'INFORME DE INSPECCIÓN', 0, 1, 'L');
        
        // Información básica
        $this->SetFont('helvetica', '', 10);
        $this->SetXY(50, 25);
        $this->Cell(0, 5, 'Tipo: ' . ($this->inspeccion_data['tipo_inspeccion_nombre'] ?? 'N/A'), 0, 1, 'L');
        $this->SetXY(50, 30);
        $this->Cell(0, 5, 'Fecha: ' . date('d/m/Y', strtotime($this->inspeccion_data['fecha_inspeccion'])), 0, 1, 'L');
        
        // Línea separadora
        $this->SetY(40);
        $this->Line(15, 40, 195, 40);
        $this->SetY(45);
    }
    
    public function Footer() {
        $this->SetY(-15);
        $this->SetFont('helvetica', 'I', 8);
        $this->Cell(0, 10, 'Página ' . $this->getAliasNumPage() . ' de ' . $this->getAliasNbPages() . ' - Generado el ' . date('d/m/Y H:i'), 0, 0, 'C');
    }
}

// Crear instancia del PDF
$pdf = new InspeccionPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
$pdf->setInspeccionData($inspeccion_data);

// Configuración del documento
$pdf->SetCreator('Sistema de Inspecciones');
$pdf->SetAuthor($inspeccion_data['inspector_nombre']);
$pdf->SetTitle('Inspección #' . $id . ' - ' . $inspeccion_data['inmueble_nombre']);
$pdf->SetSubject('Informe de Inspección');

// Configuración de página
$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
$pdf->SetMargins(15, 50, 15);
$pdf->SetHeaderMargin(5);
$pdf->SetFooterMargin(10);
$pdf->SetAutoPageBreak(TRUE, 25);
$pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);

// Agregar página
$pdf->AddPage();

// Información General
$pdf->SetFont('helvetica', 'B', 14);
$pdf->Cell(0, 8, 'INFORMACIÓN GENERAL', 0, 1, 'L');
$pdf->Ln(2);

$pdf->SetFont('helvetica', '', 10);
$info_general = [
    'Inmueble' => $inspeccion_data['inmueble_nombre'],
    'Dirección' => $inspeccion_data['inmueble_direccion'],
    'Teléfono' => $inspeccion_data['inmueble_telefono'] ?: 'N/A',
    'Inspector' => $inspeccion_data['inspector_nombre'],
    'Fecha de Inspección' => date('d/m/Y', strtotime($inspeccion_data['fecha_inspeccion'])),
    'Número de Contrato' => $inspeccion_data['numero_contrato'] ?: 'N/A',
    'Estado' => ucfirst($inspeccion_data['estado'])
];

foreach ($info_general as $label => $value) {
    $pdf->SetFont('helvetica', 'B', 10);
    $pdf->Cell(40, 6, $label . ':', 0, 0, 'L');
    $pdf->SetFont('helvetica', '', 10);
    $pdf->Cell(0, 6, $value, 0, 1, 'L');
}

// Información del Contratista (si existe)
if ($inspeccion_data['contratista_nombre']) {
    $pdf->Ln(5);
    $pdf->SetFont('helvetica', 'B', 14);
    $pdf->Cell(0, 8, 'INFORMACIÓN DEL CONTRATISTA', 0, 1, 'L');
    $pdf->Ln(2);
    
    $pdf->SetFont('helvetica', '', 10);
    $info_contratista = [
        'Nombre' => $inspeccion_data['contratista_nombre'],
        'Dirección' => $inspeccion_data['contratista_direccion'] ?: 'N/A',
        'Licencia' => $inspeccion_data['contratista_licencia'] ?: 'N/A'
    ];
    
    foreach ($info_contratista as $label => $value) {
        $pdf->SetFont('helvetica', 'B', 10);
        $pdf->Cell(40, 6, $label . ':', 0, 0, 'L');
        $pdf->SetFont('helvetica', '', 10);
        $pdf->Cell(0, 6, $value, 0, 1, 'L');
    }
}

$pdf->Ln(10);

// Resultados de la Inspección
$pdf->SetFont('helvetica', 'B', 14);
$pdf->Cell(0, 8, 'RESULTADOS DE LA INSPECCIÓN', 0, 1, 'L');
$pdf->Ln(5);

if (empty($respuestas_por_seccion)) {
    $pdf->SetFont('helvetica', 'I', 12);
    $pdf->Cell(0, 10, 'No hay respuestas registradas para esta inspección.', 0, 1, 'C');
} else {
    foreach ($respuestas_por_seccion as $seccion_nombre => $respuestas_seccion) {
        // Título de la sección
        $pdf->SetFont('helvetica', 'B', 12);
        $pdf->SetFillColor(240, 240, 240);
        $pdf->Cell(0, 8, strtoupper($seccion_nombre), 1, 1, 'L', true);
        $pdf->Ln(2);
        
        foreach ($respuestas_seccion as $respuesta) {
            // Descripción del elemento
            $pdf->SetFont('helvetica', 'B', 10);
            $pdf->Cell(0, 6, $respuesta['elemento_descripcion'], 0, 1, 'L');
            
            // Respuesta
            $pdf->SetFont('helvetica', '', 10);
            $respuesta_texto = '';
            $color = [0, 0, 0];
            
            switch($respuesta['respuesta']) {
                case 'si':
                    $respuesta_texto = 'SÍ - CONFORME';
                    $color = [0, 150, 0];
                    break;
                case 'no':
                    $respuesta_texto = 'NO - NO CONFORME';
                    $color = [200, 0, 0];
                    break;
                case 'nc':
                    $respuesta_texto = 'N/C - NO CORRESPONDE';
                    $color = [200, 150, 0];
                    break;
            }
            
            $pdf->SetTextColor($color[0], $color[1], $color[2]);
            $pdf->Cell(30, 5, 'Resultado:', 0, 0, 'L');
            $pdf->SetFont('helvetica', 'B', 10);
            $pdf->Cell(0, 5, $respuesta_texto, 0, 1, 'L');
            $pdf->SetTextColor(0, 0, 0);
            
            // Observaciones
            if ($respuesta['observaciones']) {
                $pdf->SetFont('helvetica', '', 9);
                $pdf->Cell(30, 5, 'Observaciones:', 0, 0, 'L');
                $pdf->MultiCell(0, 5, $respuesta['observaciones'], 0, 'L');
            }
            
            // Fotos
            if (isset($fotos_por_elemento[$respuesta['elemento_id']])) {
                $pdf->SetFont('helvetica', '', 9);
                $pdf->Cell(0, 5, 'Fotografías:', 0, 1, 'L');
                
                $x_start = 20;
                $y_current = $pdf->GetY();
                $foto_width = 40;
                $foto_height = 30;
                $fotos_por_fila = 4;
                $contador_fotos = 0;
                
                foreach ($fotos_por_elemento[$respuesta['elemento_id']] as $foto) {
                    if (file_exists($foto['ruta_archivo'])) {
                        $x_pos = $x_start + ($contador_fotos % $fotos_por_fila) * ($foto_width + 5);
                        $y_pos = $y_current + floor($contador_fotos / $fotos_por_fila) * ($foto_height + 15);
                        
                        // Verificar si necesitamos una nueva página
                        if ($y_pos + $foto_height > 250) {
                            $pdf->AddPage();
                            $y_pos = $pdf->GetY();
                            $y_current = $y_pos;
                        }
                        
                        try {
                            $pdf->Image($foto['ruta_archivo'], $x_pos, $y_pos, $foto_width, $foto_height, '', '', '', false, 300, '', false, false, 1);
                            
                            // Descripción de la foto
                            if ($foto['descripcion']) {
                                $pdf->SetXY($x_pos, $y_pos + $foto_height + 1);
                                $pdf->SetFont('helvetica', '', 7);
                                $pdf->MultiCell($foto_width, 3, $foto['descripcion'], 0, 'C');
                            }
                        } catch (Exception $e) {
                            // Si hay error con la imagen, mostrar texto
                            $pdf->SetXY($x_pos, $y_pos);
                            $pdf->SetFont('helvetica', '', 8);
                            $pdf->Cell($foto_width, $foto_height, 'Imagen no disponible', 1, 0, 'C');
                        }
                        
                        $contador_fotos++;
                    }
                }
                
                if ($contador_fotos > 0) {
                    $filas_fotos = ceil($contador_fotos / $fotos_por_fila);
                    $pdf->SetY($y_current + ($filas_fotos * ($foto_height + 15)));
                }
            }
            
            $pdf->Ln(5);
            
            // Línea separadora entre elementos
            $pdf->Line(15, $pdf->GetY(), 195, $pdf->GetY());
            $pdf->Ln(3);
        }
        
        $pdf->Ln(5);
    }
}

// Comentarios Adicionales
if ($inspeccion_data['comentarios']) {
    $pdf->AddPage();
    $pdf->SetFont('helvetica', 'B', 14);
    $pdf->Cell(0, 8, 'COMENTARIOS ADICIONALES', 0, 1, 'L');
    $pdf->Ln(5);
    
    $pdf->SetFont('helvetica', '', 10);
    $pdf->MultiCell(0, 6, $inspeccion_data['comentarios'], 0, 'L');
    $pdf->Ln(10);
}

// Problemas y Acciones Correctivas
if (!empty($problemas)) {
    $pdf->AddPage();
    $pdf->SetFont('helvetica', 'B', 14);
    $pdf->SetTextColor(200, 0, 0);
    $pdf->Cell(0, 8, 'PROBLEMAS DETECTADOS Y ACCIONES CORRECTIVAS', 0, 1, 'L');
    $pdf->SetTextColor(0, 0, 0);
    $pdf->Ln(5);
    
    $contador_problema = 1;
    foreach ($problemas as $problema) {
        // Número del problema
        $pdf->SetFont('helvetica', 'B', 12);
        $pdf->SetFillColor(255, 240, 240);
        $pdf->Cell(0, 8, 'PROBLEMA #' . $contador_problema, 1, 1, 'L', true);
        $pdf->Ln(2);
        
        // Descripción del problema
        $pdf->SetFont('helvetica', 'B', 10);
        $pdf->Cell(30, 6, 'Descripción:', 0, 0, 'L');
        $pdf->SetFont('helvetica', '', 10);
        $pdf->MultiCell(0, 6, $problema['descripcion_problema'], 0, 'L');
        
        // Observaciones del problema
        if ($problema['observaciones']) {
            $pdf->SetFont('helvetica', 'B', 10);
            $pdf->Cell(30, 6, 'Observaciones:', 0, 0, 'L');
            $pdf->SetFont('helvetica', '', 10);
            $pdf->MultiCell(0, 6, $problema['observaciones'], 0, 'L');
        }
        
        // Estado del problema
        $pdf->SetFont('helvetica', 'B', 10);
        $pdf->Cell(30, 6, 'Estado:', 0, 0, 'L');
        $pdf->SetFont('helvetica', '', 10);
        
        $estado_texto = '';
        $color_estado = [0, 0, 0];
        switch($problema['estado']) {
            case 'pendiente':
                $estado_texto = 'PENDIENTE';
                $color_estado = [200, 150, 0];
                break;
            case 'en_proceso':
                $estado_texto = 'EN PROCESO';
                $color_estado = [0, 100, 200];
                break;
            case 'resuelto':
                $estado_texto = 'RESUELTO';
                $color_estado = [0, 150, 0];
                break;
        }
        
        $pdf->SetTextColor($color_estado[0], $color_estado[1], $color_estado[2]);
        $pdf->Cell(0, 6, $estado_texto, 0, 1, 'L');
        $pdf->SetTextColor(0, 0, 0);
        
        // Notas de seguimiento
        if ($problema['notas_seguimiento']) {
            $pdf->SetFont('helvetica', 'B', 10);
            $pdf->Cell(30, 6, 'Seguimiento:', 0, 0, 'L');
            $pdf->SetFont('helvetica', '', 10);
            $pdf->MultiCell(0, 6, $problema['notas_seguimiento'], 0, 'L');
        }
        
        // Fecha de creación
        $pdf->SetFont('helvetica', 'I', 9);
        $pdf->Cell(0, 5, 'Detectado el: ' . date('d/m/Y H:i', strtotime($problema['fecha_creacion'])), 0, 1, 'L');
        
        $pdf->Ln(8);
        $contador_problema++;
    }
    
    // Resumen de problemas
    $pdf->Ln(5);
    $pdf->SetFont('helvetica', 'B', 12);
    $pdf->Cell(0, 8, 'RESUMEN DE PROBLEMAS', 0, 1, 'L');
    $pdf->Ln(2);
    
    $total_problemas = count($problemas);
    $pendientes = count(array_filter($problemas, function($p) { return $p['estado'] == 'pendiente'; }));
    $en_proceso = count(array_filter($problemas, function($p) { return $p['estado'] == 'en_proceso'; }));
    $resueltos = count(array_filter($problemas, function($p) { return $p['estado'] == 'resuelto'; }));
    
    $pdf->SetFont('helvetica', '', 10);
    $pdf->Cell(40, 6, 'Total de problemas:', 0, 0, 'L');
    $pdf->SetFont('helvetica', 'B', 10);
    $pdf->Cell(20, 6, $total_problemas, 0, 1, 'L');
    
    $pdf->SetFont('helvetica', '', 10);
    $pdf->SetTextColor(200, 150, 0);
    $pdf->Cell(40, 6, 'Pendientes:', 0, 0, 'L');
    $pdf->SetFont('helvetica', 'B', 10);
    $pdf->Cell(20, 6, $pendientes, 0, 1, 'L');
    
    $pdf->SetTextColor(0, 100, 200);
    $pdf->SetFont('helvetica', '', 10);
    $pdf->Cell(40, 6, 'En proceso:', 0, 0, 'L');
    $pdf->SetFont('helvetica', 'B', 10);
    $pdf->Cell(20, 6, $en_proceso, 0, 1, 'L');
    
    $pdf->SetTextColor(0, 150, 0);
    $pdf->SetFont('helvetica', '', 10);
    $pdf->Cell(40, 6, 'Resueltos:', 0, 0, 'L');
    $pdf->SetFont('helvetica', 'B', 10);
    $pdf->Cell(20, 6, $resueltos, 0, 1, 'L');
    
    $pdf->SetTextColor(0, 0, 0);
}

// Página de firmas
$pdf->AddPage();
$pdf->SetFont('helvetica', 'B', 14);
$pdf->Cell(0, 8, 'FIRMAS Y VALIDACIONES', 0, 1, 'L');
$pdf->Ln(10);

// Sección de firmas
$pdf->SetFont('helvetica', '', 10);

// Inspector
$pdf->Cell(0, 6, 'INSPECTOR:', 0, 1, 'L');
$pdf->Ln(15);
$pdf->Line(15, $pdf->GetY(), 95, $pdf->GetY());
$pdf->SetXY(15, $pdf->GetY() + 2);
$pdf->Cell(80, 5, 'Nombre: ' . $inspeccion_data['inspector_nombre'], 0, 1, 'L');
$pdf->Cell(80, 5, 'Fecha: ' . date('d/m/Y'), 0, 1, 'L');

// Responsable del inmueble
$pdf->SetXY(105, $pdf->GetY() - 22);
$pdf->Cell(0, 6, 'RESPONSABLE DEL INMUEBLE:', 0, 1, 'L');
$pdf->SetX(105);
$pdf->Ln(15);
$pdf->Line(105, $pdf->GetY(), 185, $pdf->GetY());
$pdf->SetXY(105, $pdf->GetY() + 2);
$pdf->Cell(80, 5, 'Nombre: ________________________', 0, 1, 'L');
$pdf->SetX(105);
$pdf->Cell(80, 5, 'Fecha: ________________________', 0, 1, 'L');

$pdf->Ln(20);

// Observaciones finales
$pdf->SetFont('helvetica', 'B', 10);
$pdf->Cell(0, 6, 'OBSERVACIONES FINALES:', 0, 1, 'L');
$pdf->Ln(2);
$pdf->SetFont('helvetica', '', 10);
for ($i = 0; $i < 5; $i++) {
    $pdf->Cell(0, 6, '________________________________________________________________', 0, 1, 'L');
    $pdf->Ln(2);
}

// Generar el PDF
$filename = 'Inspeccion_' . $id . '_' . date('Y-m-d_H-i-s') . '.pdf';
$pdf->Output($filename, 'D'); // 'D' para descargar, 'I' para mostrar en navegador
?>
