<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/FotoInspeccion.php';
require_once 'models/SeguimientoProblemas.php';

requireLogin();

// Verificar que se proporcione un ID
$id = $_GET['id'] ?? 0;
if (!$id) {
    header('Location: inspecciones.php');
    exit();
}

$inspeccion = new Inspeccion();
$fotoInspeccion = new FotoInspeccion();
$seguimiento = new SeguimientoProblemas();

// Obtener datos de la inspección
$inspeccion_data = $inspeccion->getById($id);
$respuestas = $inspeccion->getRespuestas($id);
$fotos = $fotoInspeccion->getFotosByInspeccion($id);
$problemas = $seguimiento->getProblemasByInspeccion($id);

if (!$inspeccion_data) {
    header('Location: inspecciones.php');
    exit();
}

// Agrupar respuestas por sección
$respuestas_por_seccion = [];
foreach ($respuestas as $respuesta) {
    $respuestas_por_seccion[$respuesta['seccion_nombre']][] = $respuesta;
}

// Agrupar fotos por elemento
$fotos_por_elemento = [];
foreach ($fotos as $foto) {
    $fotos_por_elemento[$foto['elemento_id']][] = $foto;
}

// Generar HTML para el PDF
ob_start();
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Inspección #<?php echo $id; ?></title>
    <style>
        body {
            font-family: Arial, sans-serif;
            font-size: 12px;
            line-height: 1.4;
            color: #333;
        }
        
        .header {
            text-align: center;
            border-bottom: 2px solid #0070f3;
            padding-bottom: 20px;
            margin-bottom: 30px;
        }
        
        .header h1 {
            color: #0070f3;
            font-size: 24px;
            margin: 0;
        }
        
        .header .subtitle {
            font-size: 16px;
            color: #666;
            margin: 5px 0;
        }
        
        .info-section {
            margin-bottom: 25px;
            background: #f8f9fa;
            padding: 15px;
            border-radius: 5px;
        }
        
        .info-section h2 {
            color: #0070f3;
            font-size: 16px;
            margin: 0 0 15px 0;
            border-bottom: 1px solid #ddd;
            padding-bottom: 5px;
        }
        
        .info-grid {
            display: table;
            width: 100%;
        }
        
        .info-row {
            display: table-row;
        }
        
        .info-label {
            display: table-cell;
            font-weight: bold;
            width: 150px;
            padding: 3px 10px 3px 0;
        }
        
        .info-value {
            display: table-cell;
            padding: 3px 0;
        }
        
        .section-header {
            background: #0070f3;
            color: white;
            padding: 10px;
            margin: 20px 0 10px 0;
            font-weight: bold;
            font-size: 14px;
        }
        
        .elemento {
            border: 1px solid #ddd;
            margin-bottom: 15px;
            padding: 15px;
            border-radius: 5px;
        }
        
        .elemento-titulo {
            font-weight: bold;
            font-size: 13px;
            margin-bottom: 8px;
            color: #333;
        }
        
        .respuesta {
            margin: 8px 0;
            padding: 5px 10px;
            border-radius: 3px;
            font-weight: bold;
        }
        
        .respuesta.si {
            background: #d4edda;
            color: #155724;
        }
        
        .respuesta.no {
            background: #f8d7da;
            color: #721c24;
        }
        
        .respuesta.nc {
            background: #fff3cd;
            color: #856404;
        }
        
        .observaciones {
            margin: 8px 0;
            padding: 8px;
            background: #f1f3f4;
            border-left: 3px solid #0070f3;
            font-style: italic;
        }
        
        .fotos {
            margin: 10px 0;
        }
        
        .foto {
            display: inline-block;
            margin: 5px;
            text-align: center;
            vertical-align: top;
        }
        
        .foto img {
            max-width: 120px;
            max-height: 90px;
            border: 1px solid #ddd;
            border-radius: 3px;
        }
        
        .foto-desc {
            font-size: 10px;
            color: #666;
            margin-top: 3px;
            width: 120px;
            word-wrap: break-word;
        }
        
        .problemas-section {
            margin-top: 30px;
            page-break-before: always;
        }
        
        .problema {
            border: 2px solid #dc3545;
            margin-bottom: 20px;
            padding: 15px;
            border-radius: 5px;
            background: #fff5f5;
        }
        
        .problema-titulo {
            background: #dc3545;
            color: white;
            padding: 8px;
            margin: -15px -15px 10px -15px;
            font-weight: bold;
        }
        
        .estado-badge {
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 11px;
            font-weight: bold;
        }
        
        .estado-pendiente {
            background: #fff3cd;
            color: #856404;
        }
        
        .estado-en_proceso {
            background: #cce5ff;
            color: #004085;
        }
        
        .estado-resuelto {
            background: #d4edda;
            color: #155724;
        }
        
        .firmas-section {
            margin-top: 40px;
            page-break-before: always;
        }
        
        .firma-box {
            border: 1px solid #ddd;
            padding: 20px;
            margin: 20px 0;
            height: 80px;
        }
        
        .firma-label {
            font-weight: bold;
            margin-bottom: 10px;
        }
        
        .page-break {
            page-break-before: always;
        }
        
        @media print {
            .page-break {
                page-break-before: always;
            }
        }
    </style>
</head>
<body>
    <!-- Header -->
    <div class="header">
        <h1>INFORME DE INSPECCIÓN</h1>
        <div class="subtitle"><?php echo htmlspecialchars($inspeccion_data['tipo_inspeccion_nombre'] ?? 'Inspección General'); ?></div>
        <div class="subtitle">Inspección #<?php echo $id; ?> - <?php echo date('d/m/Y', strtotime($inspeccion_data['fecha_inspeccion'])); ?></div>
    </div>

    <!-- Información General -->
    <div class="info-section">
        <h2>INFORMACIÓN GENERAL</h2>
        <div class="info-grid">
            <div class="info-row">
                <div class="info-label">Inmueble:</div>
                <div class="info-value"><?php echo htmlspecialchars($inspeccion_data['inmueble_nombre']); ?></div>
            </div>
            <div class="info-row">
                <div class="info-label">Dirección:</div>
                <div class="info-value"><?php echo htmlspecialchars($inspeccion_data['inmueble_direccion']); ?></div>
            </div>
            <?php if ($inspeccion_data['inmueble_telefono']): ?>
            <div class="info-row">
                <div class="info-label">Teléfono:</div>
                <div class="info-value"><?php echo htmlspecialchars($inspeccion_data['inmueble_telefono']); ?></div>
            </div>
            <?php endif; ?>
            <div class="info-row">
                <div class="info-label">Inspector:</div>
                <div class="info-value"><?php echo htmlspecialchars($inspeccion_data['inspector_nombre']); ?></div>
            </div>
            <div class="info-row">
                <div class="info-label">Fecha de Inspección:</div>
                <div class="info-value"><?php echo date('d/m/Y', strtotime($inspeccion_data['fecha_inspeccion'])); ?></div>
            </div>
            <?php if ($inspeccion_data['numero_contrato']): ?>
            <div class="info-row">
                <div class="info-label">N.º de Contrato:</div>
                <div class="info-value"><?php echo htmlspecialchars($inspeccion_data['numero_contrato']); ?></div>
            </div>
            <?php endif; ?>
            <div class="info-row">
                <div class="info-label">Estado:</div>
                <div class="info-value"><?php echo ucfirst($inspeccion_data['estado']); ?></div>
            </div>
        </div>
    </div>

    <!-- Información del Contratista -->
    <?php if ($inspeccion_data['contratista_nombre']): ?>
    <div class="info-section">
        <h2>INFORMACIÓN DEL CONTRATISTA</h2>
        <div class="info-grid">
            <div class="info-row">
                <div class="info-label">Nombre:</div>
                <div class="info-value"><?php echo htmlspecialchars($inspeccion_data['contratista_nombre']); ?></div>
            </div>
            <?php if ($inspeccion_data['contratista_direccion']): ?>
            <div class="info-row">
                <div class="info-label">Dirección:</div>
                <div class="info-value"><?php echo htmlspecialchars($inspeccion_data['contratista_direccion']); ?></div>
            </div>
            <?php endif; ?>
            <?php if ($inspeccion_data['contratista_licencia']): ?>
            <div class="info-row">
                <div class="info-label">Licencia:</div>
                <div class="info-value"><?php echo htmlspecialchars($inspeccion_data['contratista_licencia']); ?></div>
            </div>
            <?php endif; ?>
        </div>
    </div>
    <?php endif; ?>

    <!-- Resultados de la Inspección -->
    <div class="page-break">
        <h2 style="color: #0070f3; font-size: 18px; margin-bottom: 20px;">RESULTADOS DE LA INSPECCIÓN</h2>
        
        <?php if (empty($respuestas_por_seccion)): ?>
            <p style="text-align: center; font-style: italic; color: #666;">No hay respuestas registradas para esta inspección.</p>
        <?php else: ?>
            <?php foreach ($respuestas_por_seccion as $seccion_nombre => $respuestas_seccion): ?>
                <div class="section-header">
                    <?php echo strtoupper(htmlspecialchars($seccion_nombre)); ?>
                </div>
                
                <?php foreach ($respuestas_seccion as $respuesta): ?>
                    <div class="elemento">
                        <div class="elemento-titulo">
                            <?php echo htmlspecialchars($respuesta['elemento_descripcion']); ?>
                        </div>
                        
                        <div class="respuesta <?php echo $respuesta['respuesta']; ?>">
                            <?php
                            switch($respuesta['respuesta']) {
                                case 'si':
                                    echo '✓ SÍ - CONFORME';
                                    break;
                                case 'no':
                                    echo '✗ NO - NO CONFORME';
                                    break;
                                case 'nc':
                                    echo '— N/C - NO CORRESPONDE';
                                    break;
                            }
                            ?>
                        </div>
                        
                        <?php if ($respuesta['observaciones']): ?>
                            <div class="observaciones">
                                <strong>Observaciones:</strong> <?php echo htmlspecialchars($respuesta['observaciones']); ?>
                            </div>
                        <?php endif; ?>
                        
                        <?php if (isset($fotos_por_elemento[$respuesta['elemento_id']])): ?>
                            <div class="fotos">
                                <strong>Fotografías:</strong><br>
                                <?php foreach ($fotos_por_elemento[$respuesta['elemento_id']] as $foto): ?>
                                    <?php if (file_exists($foto['ruta_archivo'])): ?>
                                        <div class="foto">
                                            <img src="<?php echo $foto['ruta_archivo']; ?>" alt="Foto de inspección">
                                            <?php if ($foto['descripcion']): ?>
                                                <div class="foto-desc"><?php echo htmlspecialchars($foto['descripcion']); ?></div>
                                            <?php endif; ?>
                                        </div>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                <?php endforeach; ?>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>

    <!-- Comentarios Adicionales -->
    <?php if ($inspeccion_data['comentarios']): ?>
    <div class="info-section">
        <h2>COMENTARIOS ADICIONALES</h2>
        <p><?php echo nl2br(htmlspecialchars($inspeccion_data['comentarios'])); ?></p>
    </div>
    <?php endif; ?>

    <!-- Problemas y Acciones Correctivas -->
    <?php if (!empty($problemas)): ?>
    <div class="problemas-section">
        <h2 style="color: #dc3545; font-size: 18px; margin-bottom: 20px;">PROBLEMAS DETECTADOS Y ACCIONES CORRECTIVAS</h2>
        
        <?php $contador = 1; ?>
        <?php foreach ($problemas as $problema): ?>
            <div class="problema">
                <div class="problema-titulo">
                    PROBLEMA #<?php echo $contador; ?>
                </div>
                
                <div style="margin-bottom: 10px;">
                    <strong>Descripción:</strong><br>
                    <?php echo htmlspecialchars($problema['descripcion_problema']); ?>
                </div>
                
                <?php if ($problema['observaciones']): ?>
                <div style="margin-bottom: 10px;">
                    <strong>Observaciones:</strong><br>
                    <?php echo htmlspecialchars($problema['observaciones']); ?>
                </div>
                <?php endif; ?>
                
                <div style="margin-bottom: 10px;">
                    <strong>Estado:</strong>
                    <span class="estado-badge estado-<?php echo $problema['estado']; ?>">
                        <?php
                        switch($problema['estado']) {
                            case 'pendiente':
                                echo 'PENDIENTE';
                                break;
                            case 'en_proceso':
                                echo 'EN PROCESO';
                                break;
                            case 'resuelto':
                                echo 'RESUELTO';
                                break;
                        }
                        ?>
                    </span>
                </div>
                
                <?php if ($problema['notas_seguimiento']): ?>
                <div style="margin-bottom: 10px;">
                    <strong>Notas de Seguimiento:</strong><br>
                    <?php echo nl2br(htmlspecialchars($problema['notas_seguimiento'])); ?>
                </div>
                <?php endif; ?>
                
                <div style="font-size: 11px; color: #666; font-style: italic;">
                    Detectado el: <?php echo date('d/m/Y H:i', strtotime($problema['fecha_creacion'])); ?>
                </div>
            </div>
            <?php $contador++; ?>
        <?php endforeach; ?>
        
        <!-- Resumen de problemas -->
        <div class="info-section">
            <h2>RESUMEN DE PROBLEMAS</h2>
            <div class="info-grid">
                <div class="info-row">
                    <div class="info-label">Total de problemas:</div>
                    <div class="info-value"><strong><?php echo count($problemas); ?></strong></div>
                </div>
                <div class="info-row">
                    <div class="info-label">Pendientes:</div>
                    <div class="info-value"><strong><?php echo count(array_filter($problemas, function($p) { return $p['estado'] == 'pendiente'; })); ?></strong></div>
                </div>
                <div class="info-row">
                    <div class="info-label">En proceso:</div>
                    <div class="info-value"><strong><?php echo count(array_filter($problemas, function($p) { return $p['estado'] == 'en_proceso'; })); ?></strong></div>
                </div>
                <div class="info-row">
                    <div class="info-label">Resueltos:</div>
                    <div class="info-value"><strong><?php echo count(array_filter($problemas, function($p) { return $p['estado'] == 'resuelto'; })); ?></strong></div>
                </div>
            </div>
        </div>
    <?php endif; ?>

    <!-- Firmas -->
    <div class="firmas-section">
        <h2 style="color: #0070f3; font-size: 18px; margin-bottom: 20px;">FIRMAS Y VALIDACIONES</h2>
        
        <div style="display: table; width: 100%;">
            <div style="display: table-cell; width: 48%; vertical-align: top;">
                <div class="firma-label">INSPECTOR:</div>
                <div class="firma-box">
                    <div style="margin-top: 50px; border-top: 1px solid #333; padding-top: 5px;">
                        <strong><?php echo htmlspecialchars($inspeccion_data['inspector_nombre']); ?></strong><br>
                        Fecha: <?php echo date('d/m/Y'); ?>
                    </div>
                </div>
            </div>
            
            <div style="display: table-cell; width: 4%;"></div>
            
            <div style="display: table-cell; width: 48%; vertical-align: top;">
                <div class="firma-label">RESPONSABLE DEL INMUEBLE:</div>
                <div class="firma-box">
                    <div style="margin-top: 50px; border-top: 1px solid #333; padding-top: 5px;">
                        Nombre: _________________________<br>
                        Fecha: __________________________
                    </div>
                </div>
            </div>
        </div>
        
        <div style="margin-top: 30px;">
            <div class="firma-label">OBSERVACIONES FINALES:</div>
            <div style="border: 1px solid #ddd; padding: 15px; height: 100px; margin-top: 10px;">
                <!-- Espacio para observaciones finales -->
            </div>
        </div>
    </div>
</body>
</html>
<?php
$html = ob_get_clean();

// Usar mPDF (más fácil de instalar)
require_once 'vendor/mpdf/mpdf.php';

try {
    $mpdf = new \Mpdf\Mpdf([
        'mode' => 'utf-8',
        'format' => 'A4',
        'margin_left' => 15,
        'margin_right' => 15,
        'margin_top' => 20,
        'margin_bottom' => 20,
        'margin_header' => 10,
        'margin_footer' => 10
    ]);
    
    $mpdf->SetDisplayMode('fullpage');
    $mpdf->WriteHTML($html);
    
    $filename = 'Inspeccion_' . $id . '_' . date('Y-m-d_H-i-s') . '.pdf';
    $mpdf->Output($filename, 'D');
    
} catch (Exception $e) {
    echo "Error al generar PDF: " . $e->getMessage();
    echo "<br><br>Mostrando HTML en su lugar:<br><hr>";
    echo $html;
}
?>
