<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/FotoInspeccion.php';
require_once 'models/SeguimientoProblemas.php';

requireLogin();

// Verificar que se proporcione un ID
$id = $_GET['id'] ?? 0;
if (!$id) {
  header('Location: inspecciones.php');
  exit();
}

$inspeccion = new Inspeccion();
$fotoInspeccion = new FotoInspeccion();
$seguimiento = new SeguimientoProblemas();

// Obtener datos de la inspección
$inspeccion_data = $inspeccion->getById($id);
$respuestas = $inspeccion->getRespuestas($id);
$fotos = $fotoInspeccion->getFotosByInspeccion($id);
$problemas = $seguimiento->getProblemasByInspeccion($id);

if (!$inspeccion_data) {
  header('Location: inspecciones.php');
  exit();
}

// Agrupar respuestas por sección
$respuestas_por_seccion = [];
foreach ($respuestas as $respuesta) {
  $respuestas_por_seccion[$respuesta['seccion_nombre']][] = $respuesta;
}

// Agrupar fotos por elemento
$fotos_por_elemento = [];
foreach ($fotos as $foto) {
  $fotos_por_elemento[$foto['elemento_id']][] = $foto;
}

// Obtener firmas si existen
$firmas = [];
try {
    require_once 'models/FirmaInspeccion.php';
    $firmaModel = new FirmaInspeccion();
    $firmas = $firmaModel->getFirmasByInspeccion($id);
} catch (Exception $e) {
    // Si no existe el modelo de firmas, continuar sin firmas
    $firmas = [];
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Informe de Inspección #<?php echo $id; ?></title>
  <style>
      @media print {
          body { margin: 0; }
          .no-print { display: none !important; }
          .page-break { page-break-before: always; }
          .avoid-break { page-break-inside: avoid; }
      }
      
      body {
          font-family: Arial, sans-serif;
          font-size: 12px;
          line-height: 1.4;
          margin: 20px;
          color: #333;
      }
      
      .header {
          text-align: center;
          border-bottom: 3px solid #2c5aa0;
          padding-bottom: 20px;
          margin-bottom: 30px;
      }
      
      .header h1 {
          color: #2c5aa0;
          font-size: 24px;
          margin: 0;
      }
      
      .header .subtitle {
          color: #666;
          font-size: 14px;
          margin-top: 5px;
      }
      
      .info-section {
          background: #f8f9fa;
          padding: 15px;
          border-radius: 5px;
          margin-bottom: 20px;
      }
      
      .info-section h2 {
          color: #2c5aa0;
          font-size: 16px;
          margin: 0 0 15px 0;
          border-bottom: 2px solid #2c5aa0;
          padding-bottom: 5px;
      }
      
      .info-grid {
          display: grid;
          grid-template-columns: 1fr 1fr;
          gap: 10px;
      }
      
      .info-item {
          margin-bottom: 8px;
      }
      
      .info-label {
          font-weight: bold;
          color: #555;
      }
      
      .section-title {
          background: #2c5aa0;
          color: white;
          padding: 10px;
          font-size: 14px;
          font-weight: bold;
          margin: 20px 0 10px 0;
          text-transform: uppercase;
      }
      
      .elemento {
          border: 1px solid #ddd;
          margin-bottom: 15px;
          border-radius: 5px;
          overflow: hidden;
      }
      
      .elemento-header {
          background: #f1f3f4;
          padding: 10px;
          font-weight: bold;
          border-bottom: 1px solid #ddd;
      }
      
      .elemento-content {
          padding: 15px;
      }
      
      .respuesta {
          display: inline-block;
          padding: 5px 15px;
          border-radius: 20px;
          font-weight: bold;
          font-size: 11px;
          margin-bottom: 10px;
      }
      
      .respuesta.si {
          background: #d4edda;
          color: #155724;
          border: 1px solid #c3e6cb;
      }
      
      .respuesta.no {
          background: #f8d7da;
          color: #721c24;
          border: 1px solid #f5c6cb;
      }
      
      .respuesta.nc {
          background: #fff3cd;
          color: #856404;
          border: 1px solid #ffeaa7;
      }
      
      .observaciones {
          background: #f8f9fa;
          padding: 10px;
          border-left: 4px solid #2c5aa0;
          margin: 10px 0;
          font-style: italic;
      }
      
      .equipo-info {
          background: #e3f2fd;
          padding: 8px;
          margin: 5px 0;
          border-radius: 4px;
          font-size: 11px;
          border-left: 4px solid #1976d2;
      }
      
      .fotos-container {
          margin-top: 15px;
      }
      
      .fotos-grid {
          display: grid;
          grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
          gap: 15px;
          margin-top: 10px;
      }
      
      .foto-item {
          text-align: center;
          border: 1px solid #ddd;
          border-radius: 5px;
          overflow: hidden;
      }
      
      .foto-item img {
          width: 100%;
          height: 150px;
          object-fit: cover;
      }
      
      .foto-descripcion {
          padding: 8px;
          background: #f8f9fa;
          font-size: 10px;
          color: #666;
      }
      
      .firmas-section {
          margin-top: 40px;
          page-break-before: always;
      }
      
      .firmas-grid {
          display: grid;
          grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
          gap: 20px;
          margin-top: 20px;
      }
      
      .firma-box {
          border: 1px solid #ddd;
          padding: 15px;
          border-radius: 8px;
          text-align: center;
      }
      
      .firma-imagen {
          max-width: 200px;
          max-height: 80px;
          border: none !important;
          box-shadow: none !important;
          outline: none !important;
          margin: 10px 0;
      }
      
      .print-button {
          position: fixed;
          top: 20px;
          right: 20px;
          background: #2c5aa0;
          color: white;
          border: none;
          padding: 10px 20px;
          border-radius: 5px;
          cursor: pointer;
          font-size: 14px;
          z-index: 1000;
      }
      
      .print-button:hover {
          background: #1e3d6f;
      }
      
      @media print {
          .print-button { display: none; }
      }
  </style>
</head>
<body>
  <button class="print-button no-print" onclick="window.print()">🖨️ Imprimir PDF</button>
  
  <!-- Header -->
  <div class="header">
      <h1>INFORME DE INSPECCIÓN</h1>
      <div class="subtitle">
          Sistema de Inspecciones - Reporte #<?php echo $id; ?>
      </div>
  </div>
  
  <!-- Información General -->
  <div class="info-section avoid-break">
      <h2>INFORMACIÓN GENERAL</h2>
      <div class="info-grid">
          <div>
              <div class="info-item">
                  <span class="info-label">Inmueble:</span> <?php echo htmlspecialchars($inspeccion_data['inmueble_nombre']); ?>
              </div>
              <div class="info-item">
                  <span class="info-label">Dirección:</span> <?php echo htmlspecialchars($inspeccion_data['inmueble_direccion']); ?>
              </div>
              <div class="info-item">
                  <span class="info-label">Teléfono:</span> <?php echo htmlspecialchars($inspeccion_data['inmueble_telefono'] ?: 'N/A'); ?>
              </div>
              <div class="info-item">
                  <span class="info-label">Tipo de Inspección:</span> <?php echo htmlspecialchars($inspeccion_data['tipo_inspeccion_nombre'] ?? 'N/A'); ?>
              </div>
          </div>
          <div>
              <div class="info-item">
                  <span class="info-label">Inspector:</span> <?php echo htmlspecialchars($inspeccion_data['inspector_nombre']); ?>
              </div>
              <div class="info-item">
                  <span class="info-label">Fecha de Inspección:</span> <?php echo date('d/m/Y', strtotime($inspeccion_data['fecha_inspeccion'])); ?>
              </div>
              <div class="info-item">
                  <span class="info-label">Número de Contrato:</span> <?php echo htmlspecialchars($inspeccion_data['numero_contrato'] ?: 'N/A'); ?>
              </div>
              <div class="info-item">
                  <span class="info-label">Estado:</span> <?php echo ucfirst($inspeccion_data['estado']); ?>
              </div>
          </div>
      </div>
  </div>
  
  <!-- Información del Contratista -->
  <?php if ($inspeccion_data['contratista_nombre']): ?>
  <div class="info-section avoid-break">
      <h2>INFORMACIÓN DEL CONTRATISTA</h2>
      <div class="info-grid">
          <div>
              <div class="info-item">
                  <span class="info-label">Nombre:</span> <?php echo htmlspecialchars($inspeccion_data['contratista_nombre']); ?>
              </div>
              <div class="info-item">
                  <span class="info-label">Dirección:</span> <?php echo htmlspecialchars($inspeccion_data['contratista_direccion'] ?: 'N/A'); ?>
              </div>
          </div>
          <div>
              <div class="info-item">
                  <span class="info-label">Licencia:</span> <?php echo htmlspecialchars($inspeccion_data['contratista_licencia'] ?: 'N/A'); ?>
              </div>
          </div>
      </div>
  </div>
  <?php endif; ?>
  
  <!-- Resultados de la Inspección -->
  <div class="section-title">RESULTADOS DE LA INSPECCIÓN</div>
  
  <?php if (empty($respuestas_por_seccion)): ?>
      <div style="text-align: center; padding: 40px; color: #666; font-style: italic;">
          No hay respuestas registradas para esta inspección.
      </div>
  <?php else: ?>
      <?php foreach ($respuestas_por_seccion as $seccion_nombre => $respuestas_seccion): ?>
          <div class="section-title"><?php echo strtoupper(htmlspecialchars($seccion_nombre)); ?></div>
          
          <?php foreach ($respuestas_seccion as $respuesta): ?>
              <div class="elemento avoid-break">
                  <div class="elemento-header">
                      <?php echo htmlspecialchars($respuesta['elemento_descripcion']); ?>
                  </div>
                  <div class="elemento-content">
                      <!-- Información del Equipo -->
                      <?php if (isset($respuesta['equipo_codigo']) && $respuesta['equipo_codigo']): ?>
                          <div class="equipo-info">
                              <strong>🔧 Equipo:</strong> <?php echo htmlspecialchars($respuesta['equipo_codigo']); ?>
                              <?php if (isset($respuesta['numero_serie']) && $respuesta['numero_serie']): ?>
                                  | <strong>S/N:</strong> <?php echo htmlspecialchars($respuesta['numero_serie']); ?>
                              <?php endif; ?>
                              <?php if (isset($respuesta['equipo_ubicacion']) && $respuesta['equipo_ubicacion']): ?>
                                  | <strong>Ubicación:</strong> <?php echo htmlspecialchars($respuesta['equipo_ubicacion']); ?>
                              <?php endif; ?>
                          </div>
                      <?php endif; ?>
                      
                      <!-- Respuesta -->
                      <?php
                      $respuesta_texto = '';
                      $respuesta_class = '';
                      switch($respuesta['respuesta']) {
                          case 'si':
                              $respuesta_texto = 'SÍ - CONFORME';
                              $respuesta_class = 'si';
                              break;
                          case 'no':
                              $respuesta_texto = 'NO - NO CONFORME';
                              $respuesta_class = 'no';
                              break;
                          case 'nc':
                              $respuesta_texto = 'N/C - NO CORRESPONDE';
                              $respuesta_class = 'nc';
                              break;
                      }
                      ?>
                      <div class="respuesta <?php echo $respuesta_class; ?>">
                          <?php echo $respuesta_texto; ?>
                      </div>
                      
                      <!-- Observaciones -->
                      <?php if ($respuesta['observaciones']): ?>
                          <div class="observaciones">
                              <strong>Observaciones:</strong><br>
                              <?php echo nl2br(htmlspecialchars($respuesta['observaciones'])); ?>
                          </div>
                      <?php endif; ?>
                      
                      <!-- Fotos -->
                      <?php if (isset($fotos_por_elemento[$respuesta['elemento_id']])): ?>
                          <div class="fotos-container">
                              <strong>Fotografías:</strong>
                              <div class="fotos-grid">
                                  <?php foreach ($fotos_por_elemento[$respuesta['elemento_id']] as $foto): ?>
                                      <?php if (file_exists($foto['ruta_archivo'])): ?>
                                          <div class="foto-item">
                                              <img src="<?php echo htmlspecialchars($foto['ruta_archivo']); ?>" 
                                                   alt="Foto de inspección">
                                              <?php if ($foto['descripcion']): ?>
                                                  <div class="foto-descripcion">
                                                      <?php echo htmlspecialchars($foto['descripcion']); ?>
                                                  </div>
                                              <?php endif; ?>
                                          </div>
                                      <?php endif; ?>
                                  <?php endforeach; ?>
                              </div>
                          </div>
                      <?php endif; ?>
                  </div>
              </div>
          <?php endforeach; ?>
      <?php endforeach; ?>
  <?php endif; ?>
  
  <!-- Comentarios Adicionales -->
  <?php if ($inspeccion_data['comentarios']): ?>
      <div class="info-section page-break">
          <h2>COMENTARIOS ADICIONALES</h2>
          <div style="padding: 10px; background: white; border-radius: 3px;">
              <?php echo nl2br(htmlspecialchars($inspeccion_data['comentarios'])); ?>
          </div>
      </div>
  <?php endif; ?>
  
  <!-- Firmas Digitales -->
  <?php if (!empty($firmas)): ?>
      <div class="firmas-section">
          <div class="section-title" style="background: #28a745;">
              ✍️ FIRMAS DIGITALES
          </div>
          
          <div class="firmas-grid">
              <?php foreach ($firmas as $firma): ?>
                  <div class="firma-box">
                      <h4 style="color: #2c5aa0; margin-bottom: 10px;">
                          <?php echo strtoupper($firma['tipo_firma']); ?>
                      </h4>
                      
                      <img src="<?php echo $firma['firma_base64']; ?>" 
                           class="firma-imagen" 
                           alt="Firma">
                      
                      <div style="font-size: 12px; margin-top: 10px;">
                          <strong>Nombre:</strong> <?php echo htmlspecialchars($firma['nombre_firmante']); ?><br>
                          <?php if ($firma['cargo_firmante']): ?>
                              <strong>Cargo:</strong> <?php echo htmlspecialchars($firma['cargo_firmante']); ?><br>
                          <?php endif; ?>
                          <strong>Fecha:</strong> <?php echo date('d/m/Y H:i', strtotime($firma['fecha_firma'])); ?>
                      </div>
                  </div>
              <?php endforeach; ?>
          </div>
          
          <div style="margin-top: 20px; padding: 10px; background: #f8f9fa; border-radius: 5px; font-size: 10px; color: #666;">
              <strong>Validación Digital:</strong> Las firmas han sido registradas digitalmente con fecha, hora e IP.
              Documento generado el <?php echo date('d/m/Y H:i:s'); ?>
          </div>
      </div>
  <?php endif; ?>
  
  <script>
      // Auto-print cuando se carga la página si viene de un enlace directo
      if (window.location.search.includes('print=1')) {
          window.onload = function() {
              setTimeout(function() {
                  window.print();
              }, 1000);
          };
      }
  </script>
</body>
</html>
