<?php
require_once 'config/config.php';
require_once 'models/SeguimientoProblemas.php';
require_once 'models/Inspeccion.php';
require_once 'models/Inmueble.php';

requireLogin();

$seguimiento = new SeguimientoProblemas();
$inspeccion = new Inspeccion();
$inmueble = new Inmueble();

// Obtener estadísticas
$estadisticas = $seguimiento->getEstadisticas();

// Procesar filtros
$filtro_estado = isset($_GET['estado']) ? $_GET['estado'] : '';
$filtro_inmueble = isset($_GET['inmueble']) ? $_GET['inmueble'] : '';
$items_por_pagina = isset($_GET['per_page']) ? (int)$_GET['per_page'] : 10;
$pagina_actual = isset($_GET['page']) ? (int)$_GET['page'] : 1;

// Obtener problemas agrupados por inspección
$problemas_agrupados = $seguimiento->getProblemasAgrupadosPorInspeccion($filtro_estado, $filtro_inmueble);

// Paginación
$total_inspecciones = count($problemas_agrupados);
$total_paginas = ceil($total_inspecciones / $items_por_pagina);
$offset = ($pagina_actual - 1) * $items_por_pagina;
$problemas_paginados = array_slice($problemas_agrupados, $offset, $items_por_pagina);

// Obtener lista de inmuebles para el filtro
$inmuebles = $inmueble->getAll();

// Procesar actualización de estado
if ($_POST && isset($_POST['actualizar_estado'])) {
    $problema_id = $_POST['problema_id'];
    $nuevo_estado = $_POST['estado'];
    $notas = $_POST['notas'] ?? '';
    
    if ($seguimiento->updateEstado($problema_id, $nuevo_estado, $notas, $_SESSION['user_id'])) {
        $mensaje_exito = "Estado actualizado correctamente";
        // Recargar datos
        $problemas_agrupados = $seguimiento->getProblemasAgrupadosPorInspeccion($filtro_estado, $filtro_inmueble);
        $estadisticas = $seguimiento->getEstadisticas();
    } else {
        $mensaje_error = "Error al actualizar el estado";
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Informes y Seguimiento - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary: #0070f3;
            --success: #00d084;
            --warning: #f5a623;
            --danger: #e00;
            --gray-50: #fafafa;
            --gray-100: #f4f4f5;
            --gray-200: #e4e4e7;
            --gray-300: #d4d4d8;
            --gray-400: #a1a1aa;
            --gray-500: #71717a;
            --gray-600: #52525b;
            --gray-700: #3f3f46;
            --gray-800: #27272a;
            --gray-900: #18181b;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', sans-serif;
            background-color: var(--gray-50);
            color: var(--gray-900);
            line-height: 1.6;
        }

        .header {
            background: white;
            border-bottom: 1px solid var(--gray-200);
            padding: 1rem 0;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
            margin-bottom: 2rem;
            position: sticky;
            top: 0;
            z-index: 100;
        }

        .header-content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 0 1rem;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .logo {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            font-weight: 600;
            font-size: 1.25rem;
            color: var(--gray-900);
            text-decoration: none;
        }

        .main-container {
            max-width: 1400px;
            margin: 0 auto;
            padding: 0 1rem;
        }

        .page-header {
            background: linear-gradient(135deg, var(--primary), #0051cc);
            color: white;
            border-radius: 12px;
            padding: 2rem;
            margin-bottom: 2rem;
            text-align: center;
        }

        .stats-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(180px, 1fr));
            gap: 1rem;
            margin-bottom: 2rem;
        }

        .stat-card {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1.25rem;
            text-align: center;
            box-shadow: 0 1px 3px rgba(0,0,0,0.05);
            transition: transform 0.2s, box-shadow 0.2s;
        }

        .stat-card:hover {
            transform: translateY(-2px);
            box-shadow: 0 4px 12px rgba(0,0,0,0.1);
        }

        .stat-number {
            font-size: 2rem;
            font-weight: 700;
            margin-bottom: 0.25rem;
        }

        .stat-label {
            color: var(--gray-600);
            font-size: 0.8125rem;
            font-weight: 500;
        }

        .filters-section {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1.25rem;
            margin-bottom: 1.5rem;
            box-shadow: 0 1px 3px rgba(0,0,0,0.05);
        }

        .inspection-card {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            margin-bottom: 1rem;
            box-shadow: 0 1px 3px rgba(0,0,0,0.05);
            overflow: hidden;
            transition: all 0.2s;
        }

        .inspection-card:hover {
            box-shadow: 0 4px 12px rgba(0,0,0,0.1);
        }

        .inspection-header {
            padding: 1rem 1.25rem;
            cursor: pointer;
            transition: background-color 0.2s;
            border-bottom: 1px solid transparent;
        }

        .inspection-header:hover {
            background: var(--gray-50);
        }

        .inspection-header.has-problems {
            border-left: 4px solid var(--warning);
        }

        .inspection-header.all-resolved {
            border-left: 4px solid var(--success);
        }

        .inspection-title {
            font-size: 1rem;
            font-weight: 600;
            margin: 0 0 0.5rem 0;
            color: var(--gray-900);
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        .inspection-id {
            background: var(--gray-100);
            color: var(--gray-700);
            padding: 0.125rem 0.5rem;
            border-radius: 4px;
            font-size: 0.75rem;
            font-weight: 500;
        }

        .inspection-meta {
            color: var(--gray-600);
            font-size: 0.8125rem;
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 0.5rem;
            margin-bottom: 0.75rem;
        }

        .meta-item {
            display: flex;
            align-items: center;
            gap: 0.375rem;
        }

        .inspection-summary {
            display: flex;
            align-items: center;
            justify-content: space-between;
            flex-wrap: wrap;
            gap: 0.75rem;
        }

        .summary-badges {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            flex-wrap: wrap;
        }

        .summary-badge {
            padding: 0.25rem 0.625rem;
            border-radius: 12px;
            font-size: 0.6875rem;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.025em;
        }

        .badge-total {
            background: var(--gray-100);
            color: var(--gray-700);
        }

        .badge-pendiente {
            background: rgba(245, 166, 35, 0.15);
            color: var(--warning);
        }

        .badge-proceso {
            background: rgba(0, 112, 243, 0.15);
            color: var(--primary);
        }

        .badge-resuelto {
            background: rgba(0, 208, 132, 0.15);
            color: var(--success);
        }

        .inspection-actions {
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        .collapse-icon {
            transition: transform 0.2s;
            color: var(--gray-400);
        }

        .inspection-header[aria-expanded="true"] .collapse-icon {
            transform: rotate(90deg);
        }

        .problems-container {
            border-top: 1px solid var(--gray-100);
            background: var(--gray-50);
        }

        .problems-list {
            padding: 0;
            margin: 0;
            list-style: none;
        }

        .problem-item {
            background: white;
            border-bottom: 1px solid var(--gray-100);
            padding: 1rem 1.25rem;
            transition: background-color 0.2s;
        }

        .problem-item:last-child {
            border-bottom: none;
        }

        .problem-item:hover {
            background: var(--gray-50);
        }

        .problem-header {
            display: flex;
            justify-content: space-between;
            align-items: flex-start;
            gap: 1rem;
            margin-bottom: 0.75rem;
        }

        .problem-info {
            flex: 1;
            min-width: 0;
        }

        .problem-title {
            font-weight: 600;
            color: var(--gray-900);
            margin: 0 0 0.375rem 0;
            font-size: 0.9375rem;
        }

        .problem-description {
            color: var(--gray-600);
            font-size: 0.8125rem;
            margin: 0 0 0.375rem 0;
            line-height: 1.4;
        }

        .problem-meta {
            color: var(--gray-500);
            font-size: 0.75rem;
            display: flex;
            align-items: center;
            gap: 1rem;
            flex-wrap: wrap;
        }

        .problem-actions {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            flex-shrink: 0;
        }

        .status-badge {
            padding: 0.25rem 0.625rem;
            border-radius: 12px;
            font-size: 0.6875rem;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.025em;
        }

        .status-pendiente {
            background: rgba(245, 166, 35, 0.15);
            color: var(--warning);
        }

        .status-en_proceso {
            background: rgba(0, 112, 243, 0.15);
            color: var(--primary);
        }

        .status-resuelto {
            background: rgba(0, 208, 132, 0.15);
            color: var(--success);
        }

        .btn {
            display: inline-flex;
            align-items: center;
            gap: 0.375rem;
            padding: 0.5rem 0.875rem;
            border: 1px solid transparent;
            border-radius: 6px;
            font-size: 0.8125rem;
            font-weight: 500;
            text-decoration: none;
            cursor: pointer;
            transition: all 0.2s;
        }

        .btn-sm {
            padding: 0.375rem 0.625rem;
            font-size: 0.75rem;
        }

        .btn-xs {
            padding: 0.25rem 0.5rem;
            font-size: 0.6875rem;
        }

        .btn-primary {
            background: var(--primary);
            color: white;
        }

        .btn-outline-primary {
            border-color: var(--primary);
            color: var(--primary);
        }

        .btn-outline-secondary {
            border-color: var(--gray-300);
            color: var(--gray-700);
        }

        .pagination-container {
            display: flex;
            justify-content: between;
            align-items: center;
            margin-top: 2rem;
            padding: 1rem;
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 8px;
        }

        .pagination-info {
            color: var(--gray-600);
            font-size: 0.875rem;
        }

        .pagination {
            margin: 0;
        }

        .page-link {
            color: var(--gray-600);
            border-color: var(--gray-300);
        }

        .page-link:hover {
            color: var(--primary);
            border-color: var(--primary);
        }

        .page-item.active .page-link {
            background-color: var(--primary);
            border-color: var(--primary);
        }

        .empty-state {
            text-align: center;
            padding: 4rem 2rem;
            color: var(--gray-500);
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 8px;
        }

        .empty-icon {
            font-size: 3rem;
            margin-bottom: 1rem;
            color: var(--gray-400);
        }

        .modal-content {
            border: none;
            border-radius: 8px;
        }

        .modal-header {
            border-bottom: 1px solid var(--gray-200);
        }

        .modal-footer {
            border-top: 1px solid var(--gray-200);
        }

        .quick-actions {
            position: fixed;
            bottom: 2rem;
            right: 2rem;
            z-index: 1000;
        }

        .fab {
            width: 56px;
            height: 56px;
            border-radius: 50%;
            background: var(--primary);
            color: white;
            border: none;
            box-shadow: 0 4px 12px rgba(0,0,0,0.15);
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 1.25rem;
            transition: all 0.2s;
        }

        .fab:hover {
            transform: scale(1.1);
            box-shadow: 0 6px 20px rgba(0,0,0,0.2);
        }

        @media (max-width: 768px) {
            .inspection-meta {
                grid-template-columns: 1fr;
            }

            .inspection-summary {
                flex-direction: column;
                align-items: flex-start;
            }

            .problem-header {
                flex-direction: column;
                align-items: flex-start;
            }

            .problem-actions {
                width: 100%;
                justify-content: flex-end;
            }

            .pagination-container {
                flex-direction: column;
                gap: 1rem;
            }
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="header">
        <div class="header-content">
            <a href="dashboard.php" class="logo">
                <i class="fas fa-fire-extinguisher"></i>
                <?php echo APP_NAME; ?>
            </a>
            <div>
                <a href="dashboard.php" class="btn btn-outline-secondary btn-sm">
                    <i class="fas fa-arrow-left"></i>
                    Dashboard
                </a>
            </div>
        </div>
    </header>

    <div class="main-container">
        <!-- Page Header -->
        <div class="page-header">
            <h1 class="mb-2">
                <i class="fas fa-chart-line me-2"></i>
                Seguimiento de Problemas
            </h1>
            <p class="mb-0">Gestión y seguimiento de problemas detectados en inspecciones</p>
        </div>

        <!-- Mensajes -->
        <?php if (isset($mensaje_exito)): ?>
            <div class="alert alert-success alert-dismissible fade show">
                <i class="fas fa-check-circle me-2"></i>
                <?php echo htmlspecialchars($mensaje_exito); ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
            </div>
        <?php endif; ?>

        <?php if (isset($mensaje_error)): ?>
            <div class="alert alert-danger alert-dismissible fade show">
                <i class="fas fa-exclamation-circle me-2"></i>
                <?php echo htmlspecialchars($mensaje_error); ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
            </div>
        <?php endif; ?>

        <!-- Estadísticas -->
        <div class="stats-grid">
            <div class="stat-card">
                <div class="stat-number text-primary"><?php echo $estadisticas['total'] ?? 0; ?></div>
                <div class="stat-label">Total Problemas</div>
            </div>
            <div class="stat-card">
                <div class="stat-number text-warning"><?php echo $estadisticas['pendientes'] ?? 0; ?></div>
                <div class="stat-label">Pendientes</div>
            </div>
            <div class="stat-card">
                <div class="stat-number text-primary"><?php echo $estadisticas['en_proceso'] ?? 0; ?></div>
                <div class="stat-label">En Proceso</div>
            </div>
            <div class="stat-card">
                <div class="stat-number text-success"><?php echo $estadisticas['resueltos'] ?? 0; ?></div>
                <div class="stat-label">Resueltos</div>
            </div>
        </div>

        <!-- Filtros y Controles -->
        <div class="filters-section">
            <div class="row align-items-end">
                <div class="col-md-3">
                    <label class="form-label">Estado</label>
                    <select id="filtro-estado" class="form-select form-select-sm">
                        <option value="">Todos</option>
                        <option value="pendiente" <?php echo $filtro_estado === 'pendiente' ? 'selected' : ''; ?>>Pendientes</option>
                        <option value="en_proceso" <?php echo $filtro_estado === 'en_proceso' ? 'selected' : ''; ?>>En Proceso</option>
                        <option value="resuelto" <?php echo $filtro_estado === 'resuelto' ? 'selected' : ''; ?>>Resueltos</option>
                    </select>
                </div>
                <div class="col-md-3">
                    <label class="form-label">Inmueble</label>
                    <select id="filtro-inmueble" class="form-select form-select-sm">
                        <option value="">Todos</option>
                        <?php foreach ($inmuebles as $inm): ?>
                            <option value="<?php echo $inm['id']; ?>" <?php echo $filtro_inmueble == $inm['id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($inm['nombre']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-2">
                    <label class="form-label">Por página</label>
                    <select id="items-por-pagina" class="form-select form-select-sm">
                        <option value="10" <?php echo $items_por_pagina == 10 ? 'selected' : ''; ?>>10</option>
                        <option value="25" <?php echo $items_por_pagina == 25 ? 'selected' : ''; ?>>25</option>
                        <option value="50" <?php echo $items_por_pagina == 50 ? 'selected' : ''; ?>>50</option>
                    </select>
                </div>
                <div class="col-md-4 d-flex gap-2">
                    <button onclick="aplicarFiltros()" class="btn btn-primary btn-sm">
                        <i class="fas fa-search"></i>
                        Filtrar
                    </button>
                    <button onclick="limpiarFiltros()" class="btn btn-outline-secondary btn-sm">
                        <i class="fas fa-times"></i>
                        Limpiar
                    </button>
                    <button onclick="expandirTodo()" class="btn btn-outline-secondary btn-sm">
                        <i class="fas fa-expand-alt"></i>
                        Expandir Todo
                    </button>
                    <button onclick="contraerTodo()" class="btn btn-outline-secondary btn-sm">
                        <i class="fas fa-compress-alt"></i>
                        Contraer Todo
                    </button>
                </div>
            </div>
        </div>

        <!-- Lista de Inspecciones con Problemas -->
        <?php if (empty($problemas_paginados)): ?>
            <div class="empty-state">
                <div class="empty-icon">
                    <i class="fas fa-clipboard-check"></i>
                </div>
                <h3>¡Excelente! No hay problemas</h3>
                <p>
                    <?php if ($filtro_estado || $filtro_inmueble): ?>
                        No se encontraron problemas con los filtros aplicados.
                    <?php else: ?>
                        Todas las inspecciones están en perfecto estado.
                    <?php endif; ?>
                </p>
                <?php if (isAdmin() && !$filtro_estado && !$filtro_inmueble): ?>
                    <a href="procesar_problemas_existentes.php" class="btn btn-primary">
                        <i class="fas fa-cogs"></i>
                        Procesar Inspecciones
                    </a>
                <?php endif; ?>
            </div>
        <?php else: ?>
            <?php foreach ($problemas_paginados as $grupo): ?>
                <div class="inspection-card">
                    <div class="inspection-header <?php echo $grupo['pendientes'] > 0 ? 'has-problems' : 'all-resolved'; ?>" 
                         data-bs-toggle="collapse" 
                         data-bs-target="#inspeccion-<?php echo $grupo['inspeccion_id']; ?>"
                         aria-expanded="false">
                        
                        <div class="inspection-title">
                            <i class="fas fa-chevron-right collapse-icon"></i>
                            <span class="inspection-id">#<?php echo $grupo['inspeccion_id']; ?></span>
                            <?php echo htmlspecialchars($grupo['inmueble_nombre']); ?>
                        </div>
                        
                        <div class="inspection-meta">
                            <div class="meta-item">
                                <i class="fas fa-calendar"></i>
                                <?php echo date('d/m/Y', strtotime($grupo['fecha_inspeccion'])); ?>
                            </div>
                            <div class="meta-item">
                                <i class="fas fa-user"></i>
                                <?php echo htmlspecialchars($grupo['inspector_nombre']); ?>
                            </div>
                            <div class="meta-item">
                                <i class="fas fa-map-marker-alt"></i>
                                <?php echo htmlspecialchars($grupo['inmueble_direccion']); ?>
                            </div>
                        </div>
                        
                        <div class="inspection-summary">
                            <div class="summary-badges">
                                <span class="summary-badge badge-total">
                                    <?php echo $grupo['total_problemas']; ?> problemas
                                </span>
                                <?php if ($grupo['pendientes'] > 0): ?>
                                    <span class="summary-badge badge-pendiente">
                                        <?php echo $grupo['pendientes']; ?> pendientes
                                    </span>
                                <?php endif; ?>
                                <?php if ($grupo['en_proceso'] > 0): ?>
                                    <span class="summary-badge badge-proceso">
                                        <?php echo $grupo['en_proceso']; ?> en proceso
                                    </span>
                                <?php endif; ?>
                                <?php if ($grupo['resueltos'] > 0): ?>
                                    <span class="summary-badge badge-resuelto">
                                        <?php echo $grupo['resueltos']; ?> resueltos
                                    </span>
                                <?php endif; ?>
                            </div>
                            
                            <div class="inspection-actions">
                                <a href="ver_inspeccion.php?id=<?php echo $grupo['inspeccion_id']; ?>" 
                                   class="btn btn-outline-primary btn-xs"
                                   onclick="event.stopPropagation();">
                                    <i class="fas fa-eye"></i>
                                    Ver
                                </a>
                            </div>
                        </div>
                    </div>
                    
                    <div class="collapse" id="inspeccion-<?php echo $grupo['inspeccion_id']; ?>">
                        <div class="problems-container">
                            <ul class="problems-list">
                                <?php foreach ($grupo['problemas'] as $problema): ?>
                                    <li class="problem-item">
                                        <div class="problem-header">
                                            <div class="problem-info">
                                                <h6 class="problem-title">
                                                    <?php echo htmlspecialchars($problema['descripcion_problema']); ?>
                                                </h6>
                                                <?php if ($problema['observaciones']): ?>
                                                    <p class="problem-description">
                                                        <strong>Observaciones:</strong> 
                                                        <?php echo htmlspecialchars($problema['observaciones']); ?>
                                                    </p>
                                                <?php endif; ?>
                                                <div class="problem-meta">
                                                    <span>
                                                        <i class="fas fa-clock"></i>
                                                        <?php echo date('d/m/Y H:i', strtotime($problema['fecha_creacion'])); ?>
                                                    </span>
                                                    <?php if ($problema['notas_seguimiento']): ?>
                                                        <span>
                                                            <i class="fas fa-sticky-note"></i>
                                                            <?php echo htmlspecialchars(substr($problema['notas_seguimiento'], 0, 50)); ?>
                                                            <?php echo strlen($problema['notas_seguimiento']) > 50 ? '...' : ''; ?>
                                                        </span>
                                                    <?php endif; ?>
                                                </div>
                                            </div>
                                            <div class="problem-actions">
                                                <span class="status-badge status-<?php echo $problema['estado']; ?>">
                                                    <?php 
                                                    $estados = [
                                                        'pendiente' => 'Pendiente',
                                                        'en_proceso' => 'En Proceso',
                                                        'resuelto' => 'Resuelto'
                                                    ];
                                                    echo $estados[$problema['estado']] ?? ucfirst($problema['estado']);
                                                    ?>
                                                </span>
                                                <button class="btn btn-outline-primary btn-xs" 
                                                        data-bs-toggle="modal" 
                                                        data-bs-target="#modalEstado"
                                                        onclick="abrirModalEstado(<?php echo $problema['id']; ?>, '<?php echo $problema['estado']; ?>', '<?php echo htmlspecialchars($problema['notas_seguimiento'] ?? '', ENT_QUOTES); ?>')">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>

            <!-- Paginación -->
            <?php if ($total_paginas > 1): ?>
                <div class="pagination-container">
                    <div class="pagination-info">
                        Mostrando <?php echo $offset + 1; ?>-<?php echo min($offset + $items_por_pagina, $total_inspecciones); ?> 
                        de <?php echo $total_inspecciones; ?> inspecciones
                    </div>
                    
                    <nav>
                        <ul class="pagination pagination-sm mb-0">
                            <?php if ($pagina_actual > 1): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $pagina_actual - 1; ?>&per_page=<?php echo $items_por_pagina; ?>&estado=<?php echo $filtro_estado; ?>&inmueble=<?php echo $filtro_inmueble; ?>">
                                        <i class="fas fa-chevron-left"></i>
                                    </a>
                                </li>
                            <?php endif; ?>
                            
                            <?php for ($i = max(1, $pagina_actual - 2); $i <= min($total_paginas, $pagina_actual + 2); $i++): ?>
                                <li class="page-item <?php echo $i == $pagina_actual ? 'active' : ''; ?>">
                                    <a class="page-link" href="?page=<?php echo $i; ?>&per_page=<?php echo $items_por_pagina; ?>&estado=<?php echo $filtro_estado; ?>&inmueble=<?php echo $filtro_inmueble; ?>">
                                        <?php echo $i; ?>
                                    </a>
                                </li>
                            <?php endfor; ?>
                            
                            <?php if ($pagina_actual < $total_paginas): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $pagina_actual + 1; ?>&per_page=<?php echo $items_por_pagina; ?>&estado=<?php echo $filtro_estado; ?>&inmueble=<?php echo $filtro_inmueble; ?>">
                                        <i class="fas fa-chevron-right"></i>
                                    </a>
                                </li>
                            <?php endif; ?>
                        </ul>
                    </nav>
                </div>
            <?php endif; ?>
        <?php endif; ?>
    </div>

    <!-- Botón flotante para acciones rápidas -->
    <div class="quick-actions">
        <button class="fab" onclick="scrollToTop()" title="Ir arriba">
            <i class="fas fa-arrow-up"></i>
        </button>
    </div>

    <!-- Modal para actualizar estado -->
    <div class="modal fade" id="modalEstado" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="POST">
                    <div class="modal-header">
                        <h5 class="modal-title">Actualizar Estado del Problema</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="problema_id" id="problema_id">
                        <input type="hidden" name="actualizar_estado" value="1">
                        
                        <div class="mb-3">
                            <label class="form-label">Estado</label>
                            <select name="estado" id="estado" class="form-select" required>
                                <option value="pendiente">Pendiente</option>
                                <option value="en_proceso">En Proceso</option>
                                <option value="resuelto">Resuelto</option>
                            </select>
                        </div>
                        
                        <div class="mb-3">
                            <label class="form-label">Notas de Seguimiento</label>
                            <textarea name="notas" id="notas" class="form-control" rows="3" 
                                      placeholder="Agregar notas sobre el seguimiento del problema..."></textarea>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-outline-secondary" data-bs-dismiss="modal">
                            Cancelar
                        </button>
                        <button type="submit" class="btn btn-primary">
                            <i class="fas fa-save"></i>
                            Actualizar
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function abrirModalEstado(problemaId, estadoActual, notasActuales) {
            document.getElementById('problema_id').value = problemaId;
            document.getElementById('estado').value = estadoActual;
            document.getElementById('notas').value = notasActuales;
        }

        function aplicarFiltros() {
            const estado = document.getElementById('filtro-estado').value;
            const inmueble = document.getElementById('filtro-inmueble').value;
            const perPage = document.getElementById('items-por-pagina').value;
            
            const params = new URLSearchParams();
            if (estado) params.set('estado', estado);
            if (inmueble) params.set('inmueble', inmueble);
            params.set('per_page', perPage);
            params.set('page', '1');
            
            window.location.href = 'informes.php?' + params.toString();
        }

        function limpiarFiltros() {
            window.location.href = 'informes.php';
        }

        function expandirTodo() {
            document.querySelectorAll('.collapse').forEach(collapse => {
                new bootstrap.Collapse(collapse, { show: true });
            });
        }

        function contraerTodo() {
            document.querySelectorAll('.collapse.show').forEach(collapse => {
                new bootstrap.Collapse(collapse, { hide: true });
            });
        }

        function scrollToTop() {
            window.scrollTo({ top: 0, behavior: 'smooth' });
        }

        // Manejar iconos de colapso
        document.addEventListener('DOMContentLoaded', function() {
            document.querySelectorAll('[data-bs-toggle="collapse"]').forEach(trigger => {
                const target = document.querySelector(trigger.getAttribute('data-bs-target'));
                
                target.addEventListener('show.bs.collapse', function() {
                    trigger.setAttribute('aria-expanded', 'true');
                });
                
                target.addEventListener('hide.bs.collapse', function() {
                    trigger.setAttribute('aria-expanded', 'false');
                });
            });
        });

        // Cambio automático de filtros
        document.getElementById('items-por-pagina').addEventListener('change', aplicarFiltros);
    </script>
</body>
</html>
