<?php
require_once 'config/config.php';
require_once 'models/Inmueble.php';

requireLogin();

$inmueble = new Inmueble();
$message = '';
$message_type = '';

// Procesar formulario
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'create':
                $nombre = cleanInput($_POST['nombre']);
                $direccion = cleanInput($_POST['direccion']);
                $telefono = cleanInput($_POST['telefono']);
                
                if ($inmueble->create($nombre, $direccion, $telefono)) {
                    $message = 'Inmueble creado exitosamente';
                    $message_type = 'success';
                } else {
                    $message = 'Error al crear el inmueble';
                    $message_type = 'danger';
                }
                break;
                
            case 'update':
                $id = $_POST['id'];
                $nombre = cleanInput($_POST['nombre']);
                $direccion = cleanInput($_POST['direccion']);
                $telefono = cleanInput($_POST['telefono']);
                
                if ($inmueble->update($id, $nombre, $direccion, $telefono)) {
                    $message = 'Inmueble actualizado exitosamente';
                    $message_type = 'success';
                } else {
                    $message = 'Error al actualizar el inmueble';
                    $message_type = 'danger';
                }
                break;
                
            case 'delete':
                $id = $_POST['id'];
                if ($inmueble->delete($id)) {
                    $message = 'Inmueble eliminado exitosamente';
                    $message_type = 'success';
                } else {
                    $message = 'Error al eliminar el inmueble';
                    $message_type = 'danger';
                }
                break;
        }
    }
}

$inmuebles = $inmueble->getAll();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestión de Inmuebles - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { background-color: #f8f9fa; }
        .navbar { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); }
        .card { border: none; border-radius: 15px; box-shadow: 0 5px 15px rgba(0,0,0,0.08); }
        .btn-primary { background: linear-gradient(135deg, #667eea, #764ba2); border: none; }
        .btn-success { background: linear-gradient(135deg, #43e97b, #38f9d7); border: none; }
        .table-hover tbody tr:hover { background-color: rgba(102, 126, 234, 0.1); }
        .modal-header { background: linear-gradient(135deg, #667eea, #764ba2); color: white; }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <div class="container-fluid">
            <a class="navbar-brand" href="dashboard.php">
                <i class="fas fa-fire-extinguisher me-2"></i><?php echo APP_NAME; ?>
            </a>
            <div class="navbar-nav ms-auto">
                <a class="nav-link" href="dashboard.php">
                    <i class="fas fa-arrow-left me-2"></i>Volver al Dashboard
                </a>
            </div>
        </div>
    </nav>

    <div class="container-fluid py-4">
        <?php if ($message): ?>
            <?php echo showAlert($message, $message_type); ?>
        <?php endif; ?>

        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        <h4 class="mb-0">
                            <i class="fas fa-building me-2"></i>Gestión de Inmuebles
                        </h4>
                        <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#inmuebleModal">
                            <i class="fas fa-plus me-2"></i>Nuevo Inmueble
                        </button>
                    </div>
                    <div class="card-body">
                        <?php if (empty($inmuebles)): ?>
                            <div class="text-center py-5">
                                <i class="fas fa-building fa-4x text-muted mb-3"></i>
                                <h5 class="text-muted">No hay inmuebles registrados</h5>
                                <p class="text-muted">Crea tu primer inmueble para comenzar a realizar inspecciones</p>
                                <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#inmuebleModal">
                                    <i class="fas fa-plus me-2"></i>Crear Primer Inmueble
                                </button>
                            </div>
                        <?php else: ?>
                            <div class="table-responsive">
                                <table class="table table-hover">
                                    <thead class="table-light">
                                        <tr>
                                            <th>ID</th>
                                            <th>Nombre</th>
                                            <th>Dirección</th>
                                            <th>Teléfono</th>
                                            <th>Fecha Creación</th>
                                            <th>Acciones</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($inmuebles as $inm): ?>
                                        <tr>
                                            <td><?php echo $inm['id']; ?></td>
                                            <td><strong><?php echo htmlspecialchars($inm['nombre']); ?></strong></td>
                                            <td><?php echo htmlspecialchars($inm['direccion']); ?></td>
                                            <td><?php echo htmlspecialchars($inm['telefono']); ?></td>
                                            <td><?php echo date('d/m/Y', strtotime($inm['fecha_creacion'])); ?></td>
                                            <td>
                                                <button type="button" class="btn btn-sm btn-outline-primary" 
                                                        onclick="editInmueble(<?php echo htmlspecialchars(json_encode($inm)); ?>)">
                                                    <i class="fas fa-edit"></i>
                                                </button>
                                                <button type="button" class="btn btn-sm btn-outline-danger" 
                                                        onclick="deleteInmueble(<?php echo $inm['id']; ?>, '<?php echo htmlspecialchars($inm['nombre']); ?>')">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </td>
                                        </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal para Crear/Editar Inmueble -->
    <div class="modal fade" id="inmuebleModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="modalTitle">
                        <i class="fas fa-building me-2"></i>Nuevo Inmueble
                    </h5>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal"></button>
                </div>
                <form method="POST" id="inmuebleForm">
                    <div class="modal-body">
                        <input type="hidden" name="action" id="formAction" value="create">
                        <input type="hidden" name="id" id="inmuebleId">
                        
                        <div class="mb-3">
                            <label for="nombre" class="form-label">Nombre del Inmueble *</label>
                            <input type="text" class="form-control" id="nombre" name="nombre" required>
                        </div>
                        
                        <div class="mb-3">
                            <label for="direccion" class="form-label">Dirección *</label>
                            <textarea class="form-control" id="direccion" name="direccion" rows="3" required></textarea>
                        </div>
                        
                        <div class="mb-3">
                            <label for="telefono" class="form-label">Teléfono</label>
                            <input type="text" class="form-control" id="telefono" name="telefono">
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                        <button type="submit" class="btn btn-primary" id="submitBtn">
                            <i class="fas fa-save me-2"></i>Guardar
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Modal de Confirmación para Eliminar -->
    <div class="modal fade" id="deleteModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header bg-danger text-white">
                    <h5 class="modal-title">
                        <i class="fas fa-exclamation-triangle me-2"></i>Confirmar Eliminación
                    </h5>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <p>¿Está seguro de que desea eliminar el inmueble <strong id="deleteInmuebleName"></strong>?</p>
                    <p class="text-muted">Esta acción no se puede deshacer.</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                    <form method="POST" style="display: inline;">
                        <input type="hidden" name="action" value="delete">
                        <input type="hidden" name="id" id="deleteInmuebleId">
                        <button type="submit" class="btn btn-danger">
                            <i class="fas fa-trash me-2"></i>Eliminar
                        </button>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function editInmueble(inmueble) {
            document.getElementById('modalTitle').innerHTML = '<i class="fas fa-edit me-2"></i>Editar Inmueble';
            document.getElementById('formAction').value = 'update';
            document.getElementById('inmuebleId').value = inmueble.id;
            document.getElementById('nombre').value = inmueble.nombre;
            document.getElementById('direccion').value = inmueble.direccion;
            document.getElementById('telefono').value = inmueble.telefono;
            document.getElementById('submitBtn').innerHTML = '<i class="fas fa-save me-2"></i>Actualizar';
            
            new bootstrap.Modal(document.getElementById('inmuebleModal')).show();
        }

        function deleteInmueble(id, nombre) {
            document.getElementById('deleteInmuebleId').value = id;
            document.getElementById('deleteInmuebleName').textContent = nombre;
            new bootstrap.Modal(document.getElementById('deleteModal')).show();
        }

        // Limpiar formulario al cerrar modal
        document.getElementById('inmuebleModal').addEventListener('hidden.bs.modal', function () {
            document.getElementById('inmuebleForm').reset();
            document.getElementById('modalTitle').innerHTML = '<i class="fas fa-building me-2"></i>Nuevo Inmueble';
            document.getElementById('formAction').value = 'create';
            document.getElementById('submitBtn').innerHTML = '<i class="fas fa-save me-2"></i>Guardar';
        });
    </script>
</body>
</html>
