<?php
session_start();
require_once 'config/database.php';
require_once 'config/config.php';
require_once 'models/Inspeccion.php';

requireLogin();

// Variables
$database = new Database();
$db = $database->getConnection();
$inspeccion = new Inspeccion();

$paso = $_GET['paso'] ?? 1;
$inmueble_id = $_GET['inmueble'] ?? null;
$tipo_id = $_GET['tipo'] ?? null;

// Procesar guardado
if ($_POST && isset($_POST['guardar_inspeccion'])) {
    try {
        // Crear inspección
        $data_inspeccion = [
            'inmueble_id' => $_POST['inmueble_id'],
            'inspector_id' => $_SESSION['user_id'] ?? 1,
            'tipo_inspeccion_id' => $_POST['tipo_inspeccion_id'],
            'numero_contrato' => $_POST['numero_contrato'] ?? '',
            'fecha_inspeccion' => date('Y-m-d'),
            'comentarios' => $_POST['comentarios_generales'] ?? '',
            'contratista_nombre' => $_POST['contratista_nombre'] ?? '',
            'contratista_direccion' => $_POST['contratista_direccion'] ?? '',
            'contratista_licencia' => $_POST['contratista_licencia'] ?? '',
            'estado' => $_POST['estado'] ?? 'borrador'
        ];
        
        $inspeccion_id = $inspeccion->create($data_inspeccion);
        
        if ($inspeccion_id) {
            // Procesar respuestas por equipo
            $respuestas_equipos = [];
            
            foreach ($_POST as $key => $value) {
                if (strpos($key, 'eq_') === 0 && strpos($key, '_elem_') !== false) {
                    // Extraer equipo_id y elemento_id
                    preg_match('/eq_(\d+)_elem_(\d+)/', $key, $matches);
                    if (count($matches) === 3) {
                        $equipo_id = $matches[1];
                        $elemento_id = $matches[2];
                        
                        $respuestas_equipos[$equipo_id][$elemento_id] = [
                            'respuesta' => $value,
                            'observaciones' => $_POST["obs_eq_{$equipo_id}_elem_{$elemento_id}"] ?? ''
                        ];
                    }
                }
            }
            
            // Guardar respuestas
            if ($inspeccion->saveRespuestasConEquipos($inspeccion_id, $respuestas_equipos)) {
                // Procesar fotos
                if (!empty($_FILES)) {
                    require_once 'models/FotoInspeccion.php';
                    $fotoModel = new FotoInspeccion();
                    
                    foreach ($_FILES as $key => $file) {
                        if (strpos($key, 'foto_eq_') === 0 && $file['error'] === 0) {
                            preg_match('/foto_eq_(\d+)_elem_(\d+)/', $key, $matches);
                            if (count($matches) === 3) {
                                $equipo_id = $matches[1];
                                $elemento_id = $matches[2];
                                $fotoModel->uploadFoto($inspeccion_id, $elemento_id, $file, "Equipo ID: $equipo_id");
                            }
                        }
                    }
                }
                
                $mensaje_exito = "✅ Inspección guardada exitosamente (ID: $inspeccion_id)";
            }
        }
    } catch (Exception $e) {
        $mensaje_error = "❌ Error al guardar: " . $e->getMessage();
    }
}

// Obtener datos
$inmuebles = [];
$tipos = [];
$equipos = [];
$elementos = [];

try {
    // Inmuebles
    $query = "SELECT * FROM inmuebles ORDER BY nombre";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $inmuebles = $stmt->fetchAll();
    
    // Tipos
    $query = "SELECT * FROM tipos_inspeccion WHERE activo = 1 ORDER BY nombre";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $tipos = $stmt->fetchAll();
    
    // Si hay inmueble y tipo seleccionados
    if ($inmueble_id && $tipo_id) {
        $query = "SELECT * FROM equipos WHERE inmueble_id = ? AND tipo_inspeccion_id = ? AND estado_equipo = 'activo'";
        $stmt = $db->prepare($query);
        $stmt->execute([$inmueble_id, $tipo_id]);
        $equipos = $stmt->fetchAll();
        
        $query = "SELECT e.*, s.nombre as seccion_nombre 
                  FROM elementos_inspeccion e 
                  LEFT JOIN secciones_inspeccion s ON e.seccion_id = s.id 
                  WHERE s.tipo_inspeccion_id = ? 
                  ORDER BY s.orden, e.orden";
        $stmt = $db->prepare($query);
        $stmt->execute([$tipo_id]);
        $elementos = $stmt->fetchAll();
    }
} catch (Exception $e) {
    $error = "Error: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Inspección por Equipos - <?php echo APP_NAME; ?></title>
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700;800&display=swap" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary: #3b82f6;
            --primary-dark: #2563eb;
            --primary-light: #dbeafe;
            --success: #10b981;
            --success-light: #d1fae5;
            --warning: #f59e0b;
            --warning-light: #fef3c7;
            --danger: #ef4444;
            --danger-light: #fee2e2;
            --purple: #8b5cf6;
            --purple-light: #ede9fe;
            --gray-50: #f9fafb;
            --gray-100: #f3f4f6;
            --gray-200: #e5e7eb;
            --gray-300: #d1d5db;
            --gray-400: #9ca3af;
            --gray-500: #6b7280;
            --gray-600: #4b5563;
            --gray-700: #374151;
            --gray-800: #1f2937;
            --gray-900: #111827;
            --white: #ffffff;
            --shadow-sm: 0 1px 2px 0 rgb(0 0 0 / 0.05);
            --shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);
            --shadow-md: 0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);
            --shadow-lg: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);
            --shadow-xl: 0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1);
        }

        * {
            box-sizing: border-box;
            margin: 0;
            padding: 0;
        }

        body {
            font-family: 'Inter', -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            min-height: 100vh;
            color: var(--gray-900);
            line-height: 1.6;
            padding-bottom: 120px;
        }

        /* Header */
        .header {
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border-bottom: 1px solid rgba(255, 255, 255, 0.2);
            padding: 1rem 0;
            position: sticky;
            top: 0;
            z-index: 50;
            box-shadow: var(--shadow-sm);
        }

        .header-content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 0 1.5rem;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .logo {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            font-weight: 700;
            font-size: 1.25rem;
            color: var(--gray-900);
            text-decoration: none;
            transition: all 0.2s ease;
        }

        .logo:hover {
            color: var(--primary);
            transform: translateY(-1px);
        }

        .logo i {
            font-size: 1.5rem;
            color: var(--primary);
        }

        .nav-links {
            display: flex;
            align-items: center;
            gap: 1rem;
        }

        .nav-link {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.5rem 1rem;
            border: 1px solid var(--gray-300);
            border-radius: 8px;
            font-size: 0.875rem;
            font-weight: 500;
            text-decoration: none;
            color: var(--gray-700);
            background: white;
            transition: all 0.2s ease;
        }

        .nav-link:hover {
            background: var(--gray-50);
            color: var(--gray-900);
            border-color: var(--gray-400);
            transform: translateY(-1px);
        }

        .nav-link.primary {
            background: linear-gradient(135deg, var(--primary), var(--primary-dark));
            color: white;
            border-color: transparent;
        }

        .nav-link.primary:hover {
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
            color: white;
        }

        /* Main Container */
        .main-container {
            max-width: 1400px;
            margin: 0 auto;
            padding: 2rem 1.5rem;
        }

        /* Hero Section */
        .hero-section {
            background: linear-gradient(135deg, rgba(255, 255, 255, 0.95), rgba(255, 255, 255, 0.8));
            backdrop-filter: blur(20px);
            border: 1px solid rgba(255, 255, 255, 0.2);
            border-radius: 24px;
            padding: 3rem 2rem;
            margin-bottom: 2rem;
            text-align: center;
            box-shadow: var(--shadow-xl);
            position: relative;
            overflow: hidden;
        }

        .hero-section::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: linear-gradient(135deg, var(--primary-light), var(--purple-light));
            opacity: 0.1;
            z-index: -1;
        }

        .hero-title {
            font-size: 2.5rem;
            font-weight: 800;
            margin: 0 0 0.5rem 0;
            background: linear-gradient(135deg, var(--gray-900), var(--gray-700));
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
            background-clip: text;
        }

        .hero-subtitle {
            font-size: 1.125rem;
            color: var(--gray-600);
            margin: 0 0 2rem 0;
            font-weight: 400;
        }

        .breadcrumb {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            justify-content: center;
            margin-bottom: 1rem;
            font-size: 0.875rem;
            color: var(--gray-500);
        }

        .breadcrumb a {
            color: var(--primary);
            text-decoration: none;
            font-weight: 500;
        }

        .breadcrumb a:hover {
            text-decoration: underline;
        }

        /* Cards */
        .card {
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border: 1px solid rgba(255, 255, 255, 0.2);
            border-radius: 20px;
            box-shadow: var(--shadow-lg);
            transition: all 0.3s ease;
            overflow: hidden;
        }

        .card:hover {
            transform: translateY(-2px);
            box-shadow: var(--shadow-xl);
        }

        .card-header {
            background: linear-gradient(135deg, var(--gray-50), var(--gray-100));
            border-bottom: 1px solid var(--gray-200);
            padding: 1.5rem 2rem;
        }

        .card-title {
            font-size: 1.25rem;
            font-weight: 700;
            color: var(--gray-900);
            margin: 0;
            display: flex;
            align-items: center;
            gap: 0.75rem;
        }

        .card-body {
            padding: 2rem;
        }

        /* Equipment Cards */
        .equipment-card {
            background: rgba(255, 255, 255, 0.9);
            border: 2px solid var(--gray-200);
            border-radius: 16px;
            padding: 1.5rem;
            margin: 1rem 0;
            cursor: pointer;
            transition: all 0.3s ease;
            position: relative;
            overflow: hidden;
        }

        .equipment-card::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: linear-gradient(135deg, var(--primary-light), var(--purple-light));
            opacity: 0;
            transition: opacity 0.3s ease;
        }

        .equipment-card:hover {
            border-color: var(--primary);
            transform: translateY(-4px);
            box-shadow: var(--shadow-lg);
        }

        .equipment-card:hover::before {
            opacity: 0.1;
        }

        .equipment-card.selected {
            border-color: var(--success);
            background: var(--success-light);
            transform: translateY(-4px);
            box-shadow: var(--shadow-lg);
        }

        .equipment-card.selected::before {
            background: linear-gradient(135deg, var(--success-light), var(--success));
            opacity: 0.2;
        }

        .equipment-info {
            position: relative;
            z-index: 1;
        }

        .equipment-title {
            font-weight: 700;
            font-size: 1.125rem;
            color: var(--primary);
            margin-bottom: 0.5rem;
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        .equipment-location {
            color: var(--gray-600);
            font-size: 0.875rem;
            margin-bottom: 0.5rem;
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        .equipment-serial {
            font-size: 0.75rem;
            color: var(--gray-500);
            background: var(--gray-100);
            padding: 0.25rem 0.75rem;
            border-radius: 50px;
            display: inline-block;
        }

        /* Inspection Section */
        .inspection-section {
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border: 1px solid rgba(255, 255, 255, 0.2);
            border-radius: 20px;
            padding: 2rem;
            margin: 2rem 0;
            box-shadow: var(--shadow-lg);
        }

        .inspection-header {
            display: flex;
            justify-content: between;
            align-items: center;
            margin-bottom: 2rem;
            padding-bottom: 1rem;
            border-bottom: 1px solid var(--gray-200);
        }

        .inspection-title {
            font-size: 1.5rem;
            font-weight: 700;
            color: var(--primary);
            margin: 0;
            display: flex;
            align-items: center;
            gap: 0.75rem;
        }

        .inspection-badge {
            background: linear-gradient(135deg, var(--success), #059669);
            color: white;
            padding: 0.5rem 1rem;
            border-radius: 50px;
            font-size: 0.875rem;
            font-weight: 600;
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        /* Element Cards */
        .elemento-card {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 16px;
            padding: 1.5rem;
            margin: 1rem 0;
            box-shadow: var(--shadow-sm);
            transition: all 0.3s ease;
        }

        .elemento-card:hover {
            box-shadow: var(--shadow-md);
            transform: translateY(-2px);
        }

        .elemento-header {
            display: flex;
            justify-content: space-between;
            align-items: flex-start;
            margin-bottom: 1rem;
        }

        .elemento-title {
            font-weight: 600;
            color: var(--gray-900);
            font-size: 1rem;
            line-height: 1.4;
        }

        .required-badge {
            background: var(--danger-light);
            color: var(--danger);
            padding: 0.25rem 0.75rem;
            border-radius: 50px;
            font-size: 0.75rem;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.05em;
        }

        /* Radio Button Groups */
        .radio-group {
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            gap: 0.75rem;
            margin-bottom: 1.5rem;
        }

        .radio-option {
            position: relative;
        }

        .radio-option input[type="radio"] {
            position: absolute;
            opacity: 0;
            width: 0;
            height: 0;
        }

        .radio-label {
            display: flex;
            align-items: center;
            justify-content: center;
            gap: 0.5rem;
            padding: 0.875rem 1rem;
            border: 2px solid var(--gray-300);
            border-radius: 12px;
            font-weight: 600;
            font-size: 0.875rem;
            cursor: pointer;
            transition: all 0.2s ease;
            background: white;
        }

        .radio-option input[type="radio"]:checked + .radio-label.success {
            background: var(--success);
            border-color: var(--success);
            color: white;
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
        }

        .radio-option input[type="radio"]:checked + .radio-label.danger {
            background: var(--danger);
            border-color: var(--danger);
            color: white;
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
        }

        .radio-option input[type="radio"]:checked + .radio-label.warning {
            background: var(--warning);
            border-color: var(--warning);
            color: white;
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
        }

        .radio-label:hover {
            transform: translateY(-1px);
            box-shadow: var(--shadow-sm);
        }

        /* Form Elements */
        .form-group {
            display: grid;
            grid-template-columns: 2fr 1fr;
            gap: 1rem;
            align-items: start;
        }

        .form-control {
            width: 100%;
            padding: 0.875rem 1rem;
            border: 1px solid var(--gray-300);
            border-radius: 8px;
            font-size: 0.875rem;
            transition: all 0.2s ease;
            background: white;
        }

        .form-control:focus {
            outline: none;
            border-color: var(--primary);
            box-shadow: 0 0 0 3px rgba(59, 130, 246, 0.1);
        }

        .form-label {
            font-weight: 600;
            color: var(--gray-700);
            margin-bottom: 0.5rem;
            display: block;
        }

        /* Photo Upload */
        .photo-upload {
            display: flex;
            flex-direction: column;
            align-items: center;
            gap: 1rem;
        }

        .photo-btn {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.875rem 1.5rem;
            background: linear-gradient(135deg, var(--primary), var(--primary-dark));
            color: white;
            border: none;
            border-radius: 8px;
            font-weight: 600;
            cursor: pointer;
            transition: all 0.2s ease;
        }

        .photo-btn:hover {
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
        }

        .photo-preview {
            max-width: 120px;
            max-height: 120px;
            border-radius: 8px;
            box-shadow: var(--shadow-sm);
        }

        .photo-success {
            color: var(--success);
            font-size: 0.875rem;
            font-weight: 500;
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        /* Buttons */
        .btn {
            display: inline-flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.875rem 1.5rem;
            border: 1px solid transparent;
            border-radius: 8px;
            font-size: 0.875rem;
            font-weight: 600;
            text-decoration: none;
            cursor: pointer;
            transition: all 0.2s ease;
            text-align: center;
            justify-content: center;
        }

        .btn-primary {
            background: linear-gradient(135deg, var(--primary), var(--primary-dark));
            color: white;
        }

        .btn-primary:hover {
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
            color: white;
        }

        .btn-success {
            background: linear-gradient(135deg, var(--success), #059669);
            color: white;
        }

        .btn-success:hover {
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
            color: white;
        }

        .btn-secondary {
            border-color: var(--gray-300);
            color: var(--gray-700);
            background: white;
        }

        .btn-secondary:hover {
            background: var(--gray-50);
            color: var(--gray-900);
            border-color: var(--gray-400);
        }

        .btn-lg {
            padding: 1rem 2rem;
            font-size: 1rem;
        }

        /* Fixed Save Bar */
        .fixed-save-bar {
            position: fixed;
            bottom: 0;
            left: 0;
            right: 0;
            background: rgba(255, 255, 255, 0.95);
            backdrop-filter: blur(20px);
            border-top: 1px solid rgba(255, 255, 255, 0.2);
            padding: 1.5rem;
            box-shadow: var(--shadow-xl);
            z-index: 1000;
        }

        .save-bar-content {
            max-width: 1400px;
            margin: 0 auto;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .save-info {
            display: flex;
            align-items: center;
            gap: 1rem;
        }

        .save-icon {
            width: 48px;
            height: 48px;
            background: linear-gradient(135deg, var(--success), #059669);
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            color: white;
            font-size: 1.25rem;
        }

        .save-text {
            font-weight: 600;
            color: var(--gray-900);
        }

        .progress-badge {
            background: var(--primary-light);
            color: var(--primary);
            padding: 0.5rem 1rem;
            border-radius: 50px;
            font-size: 0.875rem;
            font-weight: 600;
        }

        .save-actions {
            display: flex;
            gap: 1rem;
        }

        /* Alerts */
        .alert {
            padding: 1.5rem;
            border-radius: 16px;
            margin-bottom: 2rem;
            border: 1px solid transparent;
            display: flex;
            align-items: flex-start;
            gap: 1rem;
        }

        .alert-success {
            background: var(--success-light);
            border-color: var(--success);
            color: var(--success);
        }

        .alert-danger {
            background: var(--danger-light);
            border-color: var(--danger);
            color: var(--danger);
        }

        .alert-warning {
            background: var(--warning-light);
            border-color: var(--warning);
            color: var(--warning);
        }

        .alert-icon {
            font-size: 1.25rem;
            flex-shrink: 0;
        }

        .alert-content {
            flex: 1;
        }

        .alert-title {
            font-weight: 700;
            margin-bottom: 0.5rem;
        }

        .alert-actions {
            margin-top: 1rem;
            display: flex;
            gap: 0.75rem;
        }

        /* Empty State */
        .empty-state {
            text-align: center;
            padding: 4rem 2rem;
        }

        .empty-icon {
            font-size: 4rem;
            color: var(--gray-400);
            margin-bottom: 1.5rem;
        }

        .empty-title {
            font-size: 1.5rem;
            font-weight: 700;
            color: var(--gray-700);
            margin: 0 0 0.75rem 0;
        }

        .empty-description {
            color: var(--gray-500);
            margin: 0 0 2rem 0;
            font-size: 1.125rem;
        }

        /* Responsive */
        @media (max-width: 1024px) {
            .form-group {
                grid-template-columns: 1fr;
            }
        }

        @media (max-width: 768px) {
            .main-container {
                padding: 1rem;
            }

            .hero-section {
                padding: 2rem 1.5rem;
            }

            .hero-title {
                font-size: 2rem;
            }

            .radio-group {
                grid-template-columns: 1fr;
            }

            .save-bar-content {
                flex-direction: column;
                gap: 1rem;
            }

            .save-actions {
                width: 100%;
                justify-content: center;
            }

            .nav-links {
                flex-wrap: wrap;
                gap: 0.5rem;
            }

            .nav-link {
                font-size: 0.8125rem;
                padding: 0.5rem 0.75rem;
            }
        }

        @media (max-width: 480px) {
            .equipment-card {
                padding: 1rem;
            }

            .elemento-card {
                padding: 1rem;
            }

            .btn {
                padding: 0.75rem 1rem;
                font-size: 0.8125rem;
            }
        }

        /* Loading Animation */
        @keyframes pulse {
            0%, 100% { opacity: 1; }
            50% { opacity: 0.5; }
        }

        .loading {
            animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;
        }

        /* Scroll Animations */
        @keyframes fadeInUp {
            from {
                opacity: 0;
                transform: translateY(30px);
            }
            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .animate-fade-in-up {
            animation: fadeInUp 0.6s ease-out;
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="header">
        <div class="header-content">
            <a href="dashboard.php" class="logo">
                <i class="fas fa-fire-extinguisher"></i>
                <?php echo APP_NAME; ?>
            </a>
            
            <div class="nav-links">
                <a href="dashboard.php" class="nav-link">
                    <i class="fas fa-home"></i>
                    Dashboard
                </a>
                <a href="inspecciones.php" class="nav-link">
                    <i class="fas fa-list"></i>
                    Inspecciones
                </a>
                <a href="gestionar_equipos.php" class="nav-link">
                    <i class="fas fa-cogs"></i>
                    Equipos
                </a>
                <a href="nueva_inspeccion.php" class="nav-link primary">
                    <i class="fas fa-plus"></i>
                    Nueva Inspección
                </a>
            </div>
        </div>
    </header>

    <div class="main-container">
        <!-- Hero Section -->
        <div class="hero-section animate-fade-in-up">
            <div class="breadcrumb">
                <a href="dashboard.php">Dashboard</a>
                <i class="fas fa-chevron-right"></i>
                <a href="inspecciones.php">Inspecciones</a>
                <i class="fas fa-chevron-right"></i>
                <span>Inspección por Equipos</span>
            </div>
            
            <h1 class="hero-title">
                <i class="fas fa-clipboard-check"></i>
                Inspección por Equipos
            </h1>
            <p class="hero-subtitle">
                Sistema avanzado de inspección individual por equipos con fotos y seguimiento completo
            </p>
        </div>

        <!-- Messages -->
        <?php if (isset($mensaje_exito)): ?>
            <div class="alert alert-success animate-fade-in-up">
                <div class="alert-icon">
                    <i class="fas fa-check-circle"></i>
                </div>
                <div class="alert-content">
                    <div class="alert-title">¡Inspección Guardada Exitosamente!</div>
                    <p><?php echo $mensaje_exito; ?></p>
                    <div class="alert-actions">
                        <a href="inspecciones.php" class="btn btn-success">
                            <i class="fas fa-list"></i>
                            Ver Inspecciones
                        </a>
                        <a href="?paso=1" class="btn btn-secondary">
                            <i class="fas fa-plus"></i>
                            Nueva Inspección
                        </a>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <?php if (isset($mensaje_error)): ?>
            <div class="alert alert-danger animate-fade-in-up">
                <div class="alert-icon">
                    <i class="fas fa-exclamation-triangle"></i>
                </div>
                <div class="alert-content">
                    <div class="alert-title">Error al Guardar</div>
                    <p><?php echo $mensaje_error; ?></p>
                </div>
            </div>
        <?php endif; ?>

        <?php if ($paso == 1 || !$inmueble_id || !$tipo_id): ?>
            <!-- STEP 1: Selection -->
            <div class="animate-fade-in-up">
                <div class="card">
                    <div class="card-header">
                        <h3 class="card-title">
                            <i class="fas fa-search"></i>
                            Paso 1: Selecciona Inmueble y Tipo de Equipo
                        </h3>
                    </div>
                    <div class="card-body">
                        <form method="GET">
                            <input type="hidden" name="paso" value="2">
                            
                            <div style="display: grid; grid-template-columns: 1fr 1fr; gap: 2rem; margin-bottom: 2rem;">
                                <div>
                                    <label class="form-label">
                                        <i class="fas fa-building"></i>
                                        Inmueble
                                    </label>
                                    <select name="inmueble" class="form-control" required>
                                        <option value="">Seleccionar inmueble...</option>
                                        <?php foreach ($inmuebles as $inm): ?>
                                            <option value="<?php echo $inm['id']; ?>">
                                                <?php echo htmlspecialchars($inm['nombre']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                
                                <div>
                                    <label class="form-label">
                                        <i class="fas fa-cogs"></i>
                                        Tipo de Equipo
                                    </label>
                                    <select name="tipo" class="form-control" required>
                                        <option value="">Seleccionar tipo...</option>
                                        <?php foreach ($tipos as $tipo): ?>
                                            <option value="<?php echo $tipo['id']; ?>">
                                                <?php echo htmlspecialchars($tipo['nombre']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                            
                            <div style="text-align: center;">
                                <button type="submit" class="btn btn-primary btn-lg">
                                    <i class="fas fa-search"></i>
                                    Buscar Equipos Disponibles
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

        <?php elseif (empty($equipos)): ?>
            <!-- NO EQUIPMENT FOUND -->
            <div class="animate-fade-in-up">
                <div class="card">
                    <div class="card-body">
                        <div class="empty-state">
                            <div class="empty-icon">
                                <i class="fas fa-exclamation-triangle"></i>
                            </div>
                            <h3 class="empty-title">No hay equipos registrados</h3>
                            <p class="empty-description">
                                No se encontraron equipos para esta combinación de inmueble y tipo.
                            </p>
                            <div style="display: flex; gap: 1rem; justify-content: center;">
                                <a href="gestionar_equipos.php" class="btn btn-success">
                                    <i class="fas fa-plus"></i>
                                    Registrar Equipos
                                </a>
                                <a href="?paso=1" class="btn btn-secondary">
                                    <i class="fas fa-arrow-left"></i>
                                    Volver a Selección
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        <?php else: ?>
            <!-- STEP 2: Complete Inspection -->
            <form method="POST" enctype="multipart/form-data" id="inspeccionForm">
                <input type="hidden" name="inmueble_id" value="<?php echo $inmueble_id; ?>">
                <input type="hidden" name="tipo_inspeccion_id" value="<?php echo $tipo_id; ?>">
                
                <div style="display: grid; grid-template-columns: 1fr 2fr; gap: 2rem;">
                    <!-- Sidebar Info -->
                    <div class="animate-fade-in-up" style="animation-delay: 0.1s;">
                        <div class="card" style="position: sticky; top: 100px;">
                            <div class="card-header">
                                <h5 class="card-title">
                                    <i class="fas fa-info-circle"></i>
                                    Información de la Inspección
                                </h5>
                            </div>
                            <div class="card-body">
                                <div style="margin-bottom: 1.5rem;">
                                    <strong style="color: var(--gray-600);">Inmueble:</strong><br>
                                    <span style="font-weight: 600; color: var(--gray-900);">
                                        <?php 
                                        $inm_sel = array_filter($inmuebles, fn($i) => $i['id'] == $inmueble_id);
                                        echo htmlspecialchars(reset($inm_sel)['nombre']);
                                        ?>
                                    </span>
                                </div>
                                
                                <div style="margin-bottom: 1.5rem;">
                                    <strong style="color: var(--gray-600);">Tipo:</strong><br>
                                    <span style="font-weight: 600; color: var(--gray-900);">
                                        <?php 
                                        $tipo_sel = array_filter($tipos, fn($t) => $t['id'] == $tipo_id);
                                        echo htmlspecialchars(reset($tipo_sel)['nombre']);
                                        ?>
                                    </span>
                                </div>
                                
                                <div style="display: grid; grid-template-columns: 1fr 1fr; gap: 1rem; margin-bottom: 2rem;">
                                    <div style="text-align: center; padding: 1rem; background: var(--primary-light); border-radius: 12px;">
                                        <div style="font-size: 1.5rem; font-weight: 800; color: var(--primary);">
                                            <?php echo count($equipos); ?>
                                        </div>
                                        <div style="font-size: 0.875rem; color: var(--gray-600);">Equipos</div>
                                    </div>
                                    <div style="text-align: center; padding: 1rem; background: var(--success-light); border-radius: 12px;">
                                        <div style="font-size: 1.5rem; font-weight: 800; color: var(--success);">
                                            <?php echo count($elementos); ?>
                                        </div>
                                        <div style="font-size: 0.875rem; color: var(--gray-600);">Elementos</div>
                                    </div>
                                </div>
                                
                                <hr style="border: none; height: 1px; background: var(--gray-200); margin: 2rem 0;">
                                
                                <!-- Additional Data -->
                                <div style="margin-bottom: 1rem;">
                                    <label class="form-label">Número de Contrato:</label>
                                    <input type="text" name="numero_contrato" class="form-control" placeholder="Ej: CT-2024-001">
                                </div>
                                
                                <div style="margin-bottom: 1rem;">
                                    <label class="form-label">Contratista:</label>
                                    <input type="text" name="contratista_nombre" class="form-control" placeholder="Nombre del contratista">
                                </div>
                                
                                <div style="margin-bottom: 1rem;">
                                    <label class="form-label">Comentarios Generales:</label>
                                    <textarea name="comentarios_generales" class="form-control" rows="3" placeholder="Observaciones generales de la inspección..."></textarea>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Main Content -->
                    <div class="animate-fade-in-up" style="animation-delay: 0.2s;">
                        <!-- Equipment Selection -->
                        <div class="card" style="margin-bottom: 2rem;">
                            <div class="card-header">
                                <h5 class="card-title">
                                    <i class="fas fa-check-square"></i>
                                    Selecciona Equipos a Inspeccionar
                                </h5>
                            </div>
                            <div class="card-body">
                                <div style="display: grid; grid-template-columns: repeat(auto-fit, minmax(300px, 1fr)); gap: 1rem;">
                                    <?php foreach ($equipos as $equipo): ?>
                                        <div class="equipment-card" onclick="toggleEquipo(<?php echo $equipo['id']; ?>)">
                                            <input type="checkbox" id="eq_<?php echo $equipo['id']; ?>" style="display: none;">
                                            <div class="equipment-info">
                                                <div class="equipment-title">
                                                    <i class="fas fa-cog"></i>
                                                    <?php echo htmlspecialchars($equipo['codigo_equipo']); ?>
                                                </div>
                                                <div class="equipment-location">
                                                    <i class="fas fa-map-marker-alt"></i>
                                                    <?php echo htmlspecialchars($equipo['ubicacion']); ?>
                                                </div>
                                                <?php if ($equipo['numero_serie']): ?>
                                                    <div class="equipment-serial">
                                                        S/N: <?php echo htmlspecialchars($equipo['numero_serie']); ?>
                                                    </div>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                                
                                <div style="text-align: center; margin-top: 2rem;">
                                    <button type="button" class="btn btn-success btn-lg" onclick="mostrarInspecciones()">
                                        <i class="fas fa-play"></i>
                                        Comenzar Inspección
                                    </button>
                                    <div id="equipos-seleccionados" style="margin-top: 1rem; color: var(--gray-500); font-weight: 500;"></div>
                                </div>
                            </div>
                        </div>
                        
                        <!-- Equipment Inspections -->
                        <div id="inspecciones-container" style="display: none;">
                            <div class="alert alert-success" style="margin-bottom: 2rem;">
                                <div class="alert-icon">
                                    <i class="fas fa-check-circle"></i>
                                </div>
                                <div class="alert-content">
                                    <div class="alert-title">¡Perfecto!</div>
                                    <p>Ahora inspecciona cada equipo seleccionado completando todos los elementos requeridos.</p>
                                </div>
                            </div>
                            
                            <?php foreach ($equipos as $equipo): ?>
                                <div class="inspection-section equipo-inspeccion" id="insp_<?php echo $equipo['id']; ?>" style="display: none;">
                                    <div class="inspection-header">
                                        <div>
                                            <h4 class="inspection-title">
                                                <i class="fas fa-cog"></i>
                                                Inspeccionando: <?php echo htmlspecialchars($equipo['codigo_equipo']); ?>
                                            </h4>
                                            <p style="color: var(--gray-600); margin: 0; display: flex; align-items: center; gap: 0.5rem;">
                                                <i class="fas fa-map-marker-alt"></i>
                                                <?php echo htmlspecialchars($equipo['ubicacion']); ?>
                                            </p>
                                        </div>
                                        <div class="inspection-badge">
                                            <i class="fas fa-star"></i>
                                            Equipo Específico
                                        </div>
                                    </div>
                                    
                                    <?php if (empty($elementos)): ?>
                                        <div class="alert alert-warning">
                                            <div class="alert-icon">
                                                <i class="fas fa-exclamation-triangle"></i>
                                            </div>
                                            <div class="alert-content">
                                                <div class="alert-title">No hay elementos configurados</div>
                                                <p>No se encontraron elementos de inspección para este tipo de equipo.</p>
                                            </div>
                                        </div>
                                    <?php else: ?>
                                        <?php foreach ($elementos as $elemento): ?>
                                            <div class="elemento-card">
                                                <div class="elemento-header">
                                                    <div class="elemento-title">
                                                        <?php echo htmlspecialchars($elemento['descripcion']); ?>
                                                    </div>
                                                    <?php if ($elemento['obligatorio']): ?>
                                                        <div class="required-badge">
                                                            <i class="fas fa-asterisk"></i>
                                                            Obligatorio
                                                        </div>
                                                    <?php endif; ?>
                                                </div>
                                                
                                                <?php if ($elemento['tipo_respuesta'] === 'si_no_nc'): ?>
                                                    <div class="radio-group">
                                                        <div class="radio-option">
                                                            <input type="radio" 
                                                                   name="eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>" 
                                                                   id="si_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                                   value="si">
                                                            <label class="radio-label success" 
                                                                   for="si_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>">
                                                                <i class="fas fa-check"></i>
                                                                SÍ
                                                            </label>
                                                        </div>
                                                        
                                                        <div class="radio-option">
                                                            <input type="radio" 
                                                                   name="eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>" 
                                                                   id="no_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                                   value="no">
                                                            <label class="radio-label danger" 
                                                                   for="no_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>">
                                                                <i class="fas fa-times"></i>
                                                                NO
                                                            </label>
                                                        </div>
                                                        
                                                        <div class="radio-option">
                                                            <input type="radio" 
                                                                   name="eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>" 
                                                                   id="nc_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                                   value="nc">
                                                            <label class="radio-label warning" 
                                                                   for="nc_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>">
                                                                <i class="fas fa-minus"></i>
                                                                N/C
                                                            </label>
                                                        </div>
                                                    </div>
                                                <?php endif; ?>
                                                
                                                <div class="form-group">
                                                    <div>
                                                        <label class="form-label">Observaciones específicas:</label>
                                                        <input type="text" 
                                                               name="obs_eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>"
                                                               class="form-control" 
                                                               placeholder="Detalles específicos para <?php echo htmlspecialchars($equipo['codigo_equipo']); ?>...">
                                                    </div>
                                                    <div class="photo-upload">
                                                        <input type="file" 
                                                               name="foto_eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>"
                                                               id="foto_eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>"
                                                               accept="image/*" 
                                                               style="display: none;"
                                                               onchange="previewFoto(this)">
                                                        <button type="button" class="photo-btn" 
                                                                onclick="document.getElementById('foto_eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>').click()">
                                                            <i class="fas fa-camera"></i>
                                                            Tomar Foto
                                                        </button>
                                                        <div id="preview_eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>"></div>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </form>
        <?php endif; ?>
    </div>

    <!-- Fixed Save Bar -->
    <div class="fixed-save-bar" id="saveBar" style="display: none;">
        <div class="save-bar-content">
            <div class="save-info">
                <div class="save-icon">
                    <i class="fas fa-save"></i>
                </div>
                <div>
                    <div class="save-text">Inspección lista para guardar</div>
                    <div id="progreso-badge" class="progress-badge">0% completado</div>
                </div>
            </div>
            <div class="save-actions">
                <button type="button" class="btn btn-secondary" onclick="guardarBorrador()">
                    <i class="fas fa-save"></i>
                    Guardar Borrador
                </button>
                <button type="button" class="btn btn-success" onclick="completarInspeccion()">
                    <i class="fas fa-check-circle"></i>
                    Completar Inspección
                </button>
            </div>
        </div>
    </div>

    <script>
        let equiposSeleccionados = [];

        function toggleEquipo(equipoId) {
            const checkbox = document.getElementById('eq_' + equipoId);
            const card = checkbox.closest('.equipment-card');
            
            checkbox.checked = !checkbox.checked;
            
            if (checkbox.checked) {
                card.classList.add('selected');
                if (!equiposSeleccionados.includes(equipoId)) {
                    equiposSeleccionados.push(equipoId);
                }
            } else {
                card.classList.remove('selected');
                equiposSeleccionados = equiposSeleccionados.filter(id => id !== equipoId);
            }
            
            document.getElementById('equipos-seleccionados').textContent = 
                equiposSeleccionados.length > 0 ? 
                `${equiposSeleccionados.length} equipo(s) seleccionado(s)` : '';
        }

        function mostrarInspecciones() {
            if (equiposSeleccionados.length === 0) {
                alert('⚠️ Por favor selecciona al menos un equipo para inspeccionar.');
                return;
            }
            
            document.getElementById('inspecciones-container').style.display = 'block';
            document.getElementById('saveBar').style.display = 'block';
            
            equiposSeleccionados.forEach(equipoId => {
                const inspeccion = document.getElementById('insp_' + equipoId);
                if (inspeccion) {
                    inspeccion.style.display = 'block';
                }
            });
            
            document.getElementById('inspecciones-container').scrollIntoView({
                behavior: 'smooth'
            });
            
            actualizarProgreso();
        }

        function previewFoto(input) {
            const previewDiv = document.getElementById('preview_' + input.id.replace('foto_', ''));
            
            if (input.files && input.files[0]) {
                const reader = new FileReader();
                reader.onload = function(e) {
                    previewDiv.innerHTML = `
                        <img src="${e.target.result}" class="photo-preview" alt="Preview">
                        <div class="photo-success">
                            <i class="fas fa-check"></i>
                            Foto seleccionada
                        </div>
                    `;
                };
                reader.readAsDataURL(input.files[0]);
            }
        }

        function actualizarProgreso() {
            const totalElementos = document.querySelectorAll('input[type="radio"]').length / 3;
            const elementosRespondidos = document.querySelectorAll('input[type="radio"]:checked').length;
            const progreso = totalElementos > 0 ? Math.round((elementosRespondidos / totalElementos) * 100) : 0;
            
            document.getElementById('progreso-badge').textContent = `${progreso}% completado`;
        }

        function guardarBorrador() {
            const form = document.getElementById('inspeccionForm');
            const estadoInput = document.createElement('input');
            estadoInput.type = 'hidden';
            estadoInput.name = 'estado';
            estadoInput.value = 'borrador';
            form.appendChild(estadoInput);
            
            const guardarInput = document.createElement('input');
            guardarInput.type = 'hidden';
            guardarInput.name = 'guardar_inspeccion';
            guardarInput.value = '1';
            form.appendChild(guardarInput);
            
            form.submit();
        }

        function completarInspeccion() {
            if (confirm('¿Estás seguro de completar esta inspección? No podrás editarla después.')) {
                const form = document.getElementById('inspeccionForm');
                const estadoInput = document.createElement('input');
                estadoInput.type = 'hidden';
                estadoInput.name = 'estado';
                estadoInput.value = 'completada';
                form.appendChild(estadoInput);
                
                const guardarInput = document.createElement('input');
                guardarInput.type = 'hidden';
                guardarInput.name = 'guardar_inspeccion';
                guardarInput.value = '1';
                form.appendChild(guardarInput);
                
                form.submit();
            }
        }

        // Update progress when answering
        document.addEventListener('change', function(e) {
            if (e.target.type === 'radio') {
                actualizarProgreso();
            }
        });

        // Initialize animations
        document.addEventListener('DOMContentLoaded', function() {
            // Add stagger animation to equipment cards
            const equipmentCards = document.querySelectorAll('.equipment-card');
            equipmentCards.forEach((card, index) => {
                card.style.animationDelay = `${0.1 + (index * 0.05)}s`;
                card.classList.add('animate-fade-in-up');
            });
        });

        console.log('✅ Sistema de inspección por equipos cargado completamente');
    </script>
</body>
</html>
