<?php
require_once 'config/database.php';

// Variables simples
$database = new Database();
$db = $database->getConnection();

$paso = $_GET['paso'] ?? 1;
$inmueble_id = $_GET['inmueble'] ?? null;
$tipo_id = $_GET['tipo'] ?? null;

// Obtener datos básicos
$inmuebles = [];
$tipos = [];
$equipos = [];
$elementos = [];

try {
    // Inmuebles
    $query = "SELECT * FROM inmuebles ORDER BY nombre";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $inmuebles = $stmt->fetchAll();
    
    // Tipos
    $query = "SELECT * FROM tipos_inspeccion WHERE activo = 1 ORDER BY nombre";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $tipos = $stmt->fetchAll();
    
    // Si hay inmueble y tipo seleccionados, buscar equipos
    if ($inmueble_id && $tipo_id) {
        $query = "SELECT * FROM equipos WHERE inmueble_id = ? AND tipo_inspeccion_id = ? AND estado_equipo = 'activo'";
        $stmt = $db->prepare($query);
        $stmt->execute([$inmueble_id, $tipo_id]);
        $equipos = $stmt->fetchAll();
        
        // Elementos de inspección
        $query = "SELECT e.*, s.nombre as seccion_nombre 
                  FROM elementos_inspeccion e 
                  LEFT JOIN secciones_inspeccion s ON e.seccion_id = s.id 
                  WHERE s.tipo_inspeccion_id = ? 
                  ORDER BY s.orden, e.orden";
        $stmt = $db->prepare($query);
        $stmt->execute([$tipo_id]);
        $elementos = $stmt->fetchAll();
    }
} catch (Exception $e) {
    $error = "Error: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Inspección por Equipos - FUNCIONAL</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .equipment-card {
            border: 2px solid #ddd;
            border-radius: 10px;
            padding: 15px;
            margin: 10px 0;
            cursor: pointer;
            transition: all 0.3s;
        }
        .equipment-card:hover {
            border-color: #007bff;
            background-color: #f8f9ff;
        }
        .equipment-card.selected {
            border-color: #28a745;
            background-color: #f0fff0;
        }
        .inspection-section {
            background: #f8f9fa;
            border: 1px solid #dee2e6;
            border-radius: 10px;
            padding: 20px;
            margin: 20px 0;
        }
        .debug-box {
            background: #fff3cd;
            border: 1px solid #ffeaa7;
            border-radius: 5px;
            padding: 10px;
            margin: 10px 0;
            font-family: monospace;
            font-size: 12px;
        }
    </style>
</head>
<body>
    <div class="container-fluid py-4">
        <!-- Header -->
        <div class="row">
            <div class="col-12">
                <div class="bg-primary text-white p-4 rounded mb-4 text-center">
                    <h1><i class="fas fa-clipboard-check"></i> Inspección por Equipos Específicos</h1>
                    <p>Inspecciona cada equipo individualmente con total trazabilidad</p>
                </div>
            </div>
        </div>

        <!-- Debug Info -->
        <div class="debug-box">
            <strong>🔍 DEBUG:</strong><br>
            Paso: <?php echo $paso; ?><br>
            Inmueble ID: <?php echo $inmueble_id ?? 'No seleccionado'; ?><br>
            Tipo ID: <?php echo $tipo_id ?? 'No seleccionado'; ?><br>
            Inmuebles encontrados: <?php echo count($inmuebles); ?><br>
            Tipos encontrados: <?php echo count($tipos); ?><br>
            Equipos encontrados: <?php echo count($equipos); ?><br>
            Elementos encontrados: <?php echo count($elementos); ?><br>
        </div>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger">❌ <?php echo $error; ?></div>
        <?php endif; ?>

        <?php if ($paso == 1 || !$inmueble_id || !$tipo_id): ?>
            <!-- PASO 1: Selección -->
            <div class="row justify-content-center">
                <div class="col-lg-8">
                    <div class="card">
                        <div class="card-header">
                            <h3>Paso 1: Selecciona Inmueble y Tipo</h3>
                        </div>
                        <div class="card-body">
                            <form method="GET">
                                <input type="hidden" name="paso" value="2">
                                
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <label class="form-label">Inmueble:</label>
                                        <select name="inmueble" class="form-control" required>
                                            <option value="">Seleccionar...</option>
                                            <?php foreach ($inmuebles as $inm): ?>
                                                <option value="<?php echo $inm['id']; ?>">
                                                    <?php echo htmlspecialchars($inm['nombre']); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                    
                                    <div class="col-md-6 mb-3">
                                        <label class="form-label">Tipo de Equipo:</label>
                                        <select name="tipo" class="form-control" required>
                                            <option value="">Seleccionar...</option>
                                            <?php foreach ($tipos as $tipo): ?>
                                                <option value="<?php echo $tipo['id']; ?>">
                                                    <?php echo htmlspecialchars($tipo['nombre']); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                </div>
                                
                                <div class="text-center">
                                    <button type="submit" class="btn btn-primary btn-lg">
                                        🔍 Buscar Equipos
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>

        <?php elseif (empty($equipos)): ?>
            <!-- NO HAY EQUIPOS -->
            <div class="row justify-content-center">
                <div class="col-lg-8">
                    <div class="alert alert-warning text-center">
                        <h3>⚠️ No hay equipos registrados</h3>
                        <p>No se encontraron equipos para esta combinación.</p>
                        <div class="d-flex gap-2 justify-content-center">
                            <a href="gestionar_equipos.php" class="btn btn-success">
                                ➕ Registrar Equipos
                            </a>
                            <a href="?paso=1" class="btn btn-secondary">
                                ⬅️ Volver
                            </a>
                        </div>
                    </div>
                </div>
            </div>

        <?php else: ?>
            <!-- PASO 2: Inspección -->
            <div class="row">
                <div class="col-lg-4">
                    <!-- Info General -->
                    <div class="card">
                        <div class="card-header">
                            <h5>📋 Información</h5>
                        </div>
                        <div class="card-body">
                            <p><strong>Inmueble:</strong><br>
                            <?php 
                            $inm_sel = array_filter($inmuebles, fn($i) => $i['id'] == $inmueble_id);
                            echo htmlspecialchars(reset($inm_sel)['nombre']);
                            ?></p>
                            
                            <p><strong>Tipo:</strong><br>
                            <?php 
                            $tipo_sel = array_filter($tipos, fn($t) => $t['id'] == $tipo_id);
                            echo htmlspecialchars(reset($tipo_sel)['nombre']);
                            ?></p>
                            
                            <p><strong>Equipos disponibles:</strong> <?php echo count($equipos); ?></p>
                            <p><strong>Elementos de inspección:</strong> <?php echo count($elementos); ?></p>
                        </div>
                    </div>
                </div>
                
                <div class="col-lg-8">
                    <!-- Selección de Equipos -->
                    <div class="card mb-4">
                        <div class="card-header">
                            <h5>✅ Selecciona Equipos a Inspeccionar</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <?php foreach ($equipos as $equipo): ?>
                                    <div class="col-md-6">
                                        <div class="equipment-card" onclick="toggleEquipo(<?php echo $equipo['id']; ?>)">
                                            <input type="checkbox" id="eq_<?php echo $equipo['id']; ?>" style="display: none;">
                                            <div class="fw-bold text-primary">
                                                🔧 <?php echo htmlspecialchars($equipo['codigo_equipo']); ?>
                                            </div>
                                            <div class="text-muted">
                                                📍 <?php echo htmlspecialchars($equipo['ubicacion']); ?>
                                            </div>
                                            <?php if ($equipo['numero_serie']): ?>
                                                <small>S/N: <?php echo htmlspecialchars($equipo['numero_serie']); ?></small>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                            
                            <div class="text-center mt-3">
                                <button type="button" class="btn btn-success btn-lg" onclick="mostrarInspecciones()">
                                    ▶️ Comenzar Inspección
                                </button>
                                <div id="equipos-seleccionados" class="mt-2 text-muted"></div>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Inspecciones por Equipo -->
                    <div id="inspecciones-container" style="display: none;">
                        <div class="alert alert-success">
                            <strong>🎉 ¡Perfecto!</strong> Ahora inspecciona cada equipo seleccionado.
                        </div>
                        
                        <?php foreach ($equipos as $equipo): ?>
                            <div class="inspection-section equipo-inspeccion" id="insp_<?php echo $equipo['id']; ?>" style="display: none;">
                                <div class="d-flex justify-content-between align-items-center mb-3">
                                    <div>
                                        <h4 class="text-primary mb-1">
                                            🔧 Inspeccionando: <?php echo htmlspecialchars($equipo['codigo_equipo']); ?>
                                        </h4>
                                        <p class="text-muted mb-0">
                                            📍 <?php echo htmlspecialchars($equipo['ubicacion']); ?>
                                        </p>
                                    </div>
                                    <span class="badge bg-success fs-6">Equipo Específico</span>
                                </div>
                                
                                <?php if (empty($elementos)): ?>
                                    <div class="alert alert-warning">
                                        ⚠️ No hay elementos de inspección configurados para este tipo.
                                    </div>
                                <?php else: ?>
                                    <?php foreach ($elementos as $elemento): ?>
                                        <div class="border rounded p-3 mb-3 bg-white">
                                            <div class="d-flex justify-content-between align-items-start mb-2">
                                                <strong><?php echo htmlspecialchars($elemento['descripcion']); ?></strong>
                                                <?php if ($elemento['obligatorio']): ?>
                                                    <span class="badge bg-danger">Obligatorio</span>
                                                <?php endif; ?>
                                            </div>
                                            
                                            <?php if ($elemento['tipo_respuesta'] === 'si_no_nc'): ?>
                                                <div class="btn-group w-100 mb-2" role="group">
                                                    <input type="radio" class="btn-check" 
                                                           name="eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>" 
                                                           id="si_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                           value="si">
                                                    <label class="btn btn-outline-success" 
                                                           for="si_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>">
                                                        ✅ SÍ
                                                    </label>
                                                    
                                                    <input type="radio" class="btn-check" 
                                                           name="eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>" 
                                                           id="no_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                           value="no">
                                                    <label class="btn btn-outline-danger" 
                                                           for="no_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>">
                                                        ❌ NO
                                                    </label>
                                                    
                                                    <input type="radio" class="btn-check" 
                                                           name="eq_<?php echo $equipo['id']; ?>_elem_<?php echo $elemento['id']; ?>" 
                                                           id="nc_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                           value="nc">
                                                    <label class="btn btn-outline-warning" 
                                                           for="nc_<?php echo $equipo['id']; ?>_<?php echo $elemento['id']; ?>">
                                                        ➖ N/C
                                                    </label>
                                                </div>
                                            <?php endif; ?>
                                            
                                            <input type="text" class="form-control" 
                                                   placeholder="Observaciones específicas para <?php echo htmlspecialchars($equipo['codigo_equipo']); ?>">
                                        </div>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        let equiposSeleccionados = [];

        function toggleEquipo(equipoId) {
            const checkbox = document.getElementById('eq_' + equipoId);
            const card = checkbox.closest('.equipment-card');
            
            // Toggle
            checkbox.checked = !checkbox.checked;
            
            if (checkbox.checked) {
                card.classList.add('selected');
                if (!equiposSeleccionados.includes(equipoId)) {
                    equiposSeleccionados.push(equipoId);
                }
            } else {
                card.classList.remove('selected');
                equiposSeleccionados = equiposSeleccionados.filter(id => id !== equipoId);
            }
            
            // Actualizar contador
            document.getElementById('equipos-seleccionados').textContent = 
                equiposSeleccionados.length > 0 ? 
                `${equiposSeleccionados.length} equipo(s) seleccionado(s)` : '';
            
            console.log('Equipos seleccionados:', equiposSeleccionados);
        }

        function mostrarInspecciones() {
            if (equiposSeleccionados.length === 0) {
                alert('⚠️ Por favor selecciona al menos un equipo para inspeccionar.');
                return;
            }
            
            // Mostrar contenedor
            document.getElementById('inspecciones-container').style.display = 'block';
            
            // Mostrar solo inspecciones de equipos seleccionados
            equiposSeleccionados.forEach(equipoId => {
                const inspeccion = document.getElementById('insp_' + equipoId);
                if (inspeccion) {
                    inspeccion.style.display = 'block';
                }
            });
            
            // Scroll suave
            document.getElementById('inspecciones-container').scrollIntoView({
                behavior: 'smooth'
            });
            
            console.log('✅ Mostrando inspecciones para equipos:', equiposSeleccionados);
        }

        // Debug al cargar
        console.log('🔍 Página cargada');
        console.log('Equipos disponibles:', <?php echo count($equipos); ?>);
        console.log('Elementos disponibles:', <?php echo count($elementos); ?>);
    </script>
</body>
</html>
