<?php
// Conexión directa a la base de datos
$host = 'localhost';
$dbname = 'sistema_inspeccion';
$username = 'root';
$password = '';

echo "<h2>🔧 Instalador Simple del Sistema de Aprobación</h2>";

try {
    $conn = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8mb4", $username, $password);
    $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    
    echo "<p>✅ Conexión a la base de datos exitosa</p>";
    
    // Lista de campos a agregar
    $campos = [
        'aprobador_id' => 'INT NULL',
        'fecha_aprobacion' => 'DATETIME NULL',
        'comentarios_aprobacion' => 'TEXT NULL',
        'rechazador_id' => 'INT NULL',
        'fecha_rechazo' => 'DATETIME NULL',
        'motivo_rechazo' => 'TEXT NULL'
    ];
    
    echo "<h3>📋 Verificando campos existentes:</h3>";
    
    // Verificar qué campos ya existen
    $query = "DESCRIBE inspecciones";
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $existing_columns = $stmt->fetchAll(PDO::FETCH_COLUMN);
    
    echo "<p><strong>Campos actuales en la tabla inspecciones:</strong></p>";
    echo "<ul>";
    foreach ($existing_columns as $col) {
        echo "<li>$col</li>";
    }
    echo "</ul>";
    
    $campos_agregados = 0;
    $campos_existentes = 0;
    
    echo "<h3>🔧 Agregando campos faltantes:</h3>";
    
    foreach ($campos as $campo => $tipo) {
        if (in_array($campo, $existing_columns)) {
            echo "<p>✅ <strong>$campo</strong> - Ya existe</p>";
            $campos_existentes++;
        } else {
            echo "<p>⏳ <strong>$campo</strong> - Agregando...</p>";
            
            try {
                $alter_query = "ALTER TABLE inspecciones ADD COLUMN $campo $tipo";
                $conn->exec($alter_query);
                echo "<p>✅ <strong>$campo</strong> - Agregado exitosamente</p>";
                $campos_agregados++;
            } catch (Exception $e) {
                echo "<p>❌ <strong>$campo</strong> - Error: " . $e->getMessage() . "</p>";
            }
        }
    }
    
    echo "<hr>";
    echo "<h3>📊 Resumen:</h3>";
    echo "<p>✅ Campos ya existentes: $campos_existentes</p>";
    echo "<p>➕ Campos agregados: $campos_agregados</p>";
    
    if ($campos_agregados > 0 || $campos_existentes == count($campos)) {
        echo "<div style='background: #d4edda; padding: 15px; border-radius: 5px; margin: 15px 0;'>";
        echo "<h4>🎉 ¡Sistema de Aprobación Instalado!</h4>";
        echo "<p>Todos los campos necesarios están disponibles.</p>";
        echo "</div>";
        
        // Verificar estructura final
        echo "<h3>🔍 Estructura final de la tabla:</h3>";
        $final_query = "DESCRIBE inspecciones";
        $final_stmt = $conn->prepare($final_query);
        $final_stmt->execute();
        $final_columns = $final_stmt->fetchAll(PDO::FETCH_ASSOC);
        
        echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
        echo "<tr><th>Campo</th><th>Tipo</th><th>Nulo</th><th>Clave</th><th>Por Defecto</th></tr>";
        foreach ($final_columns as $col) {
            echo "<tr>";
            echo "<td>" . $col['Field'] . "</td>";
            echo "<td>" . $col['Type'] . "</td>";
            echo "<td>" . $col['Null'] . "</td>";
            echo "<td>" . $col['Key'] . "</td>";
            echo "<td>" . $col['Default'] . "</td>";
            echo "</tr>";
        }
        echo "</table>";
    }
    
} catch (Exception $e) {
    echo "<div style='background: #f8d7da; padding: 15px; border-radius: 5px; margin: 15px 0;'>";
    echo "<h4>❌ Error en la instalación</h4>";
    echo "<p>" . $e->getMessage() . "</p>";
    echo "<p><strong>Verifica:</strong></p>";
    echo "<ul>";
    echo "<li>Que XAMPP esté ejecutándose</li>";
    echo "<li>Que la base de datos 'sistema_inspeccion' exista</li>";
    echo "<li>Que las credenciales sean correctas</li>";
    echo "</ul>";
    echo "</div>";
}

echo "<hr>";
echo "<h3>🔗 Próximos pasos:</h3>";
echo "<p><a href='dashboard.php'>🏠 Ir al Dashboard</a></p>";
echo "<p><a href='inspecciones.php'>📋 Ver Inspecciones</a></p>";
echo "<p><a href='aprobar_inspeccion.php?id=1'>✅ Probar Aprobación (si existe inspección ID 1)</a></p>";
?>
