<?php
require_once 'config/database.php';

class FirmaInspeccion {
    private $conn;
    private $table_name = "firmas_inspeccion";

    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
    }

    public function guardarFirma($inspeccion_id, $tipo_firma, $nombre_firmante, $cargo_firmante, $firma_base64) {
        try {
            // Eliminar firma anterior del mismo tipo si existe
            $delete_query = "DELETE FROM " . $this->table_name . " 
                       WHERE inspeccion_id = ? AND tipo_firma = ?";
            $delete_stmt = $this->conn->prepare($delete_query);
            $delete_stmt->execute([$inspeccion_id, $tipo_firma]);

            // Obtener datos del servidor de forma segura
            $ip_address = $_SERVER['REMOTE_ADDR'] ?? 'unknown';
            $user_agent = $_SERVER['HTTP_USER_AGENT'] ?? 'unknown';

            // Insertar nueva firma
            $query = "INSERT INTO " . $this->table_name . " 
                 (inspeccion_id, tipo_firma, nombre_firmante, cargo_firmante, firma_base64, ip_address, user_agent) 
                 VALUES (?, ?, ?, ?, ?, ?, ?)";
        
            $stmt = $this->conn->prepare($query);
            $result = $stmt->execute([
                $inspeccion_id,
                $tipo_firma, 
                $nombre_firmante,
                $cargo_firmante,
                $firma_base64,
                $ip_address,
                $user_agent
            ]);

            if ($result) {
                // Verificar si todas las firmas requeridas están completas
                $this->verificarFirmasCompletas($inspeccion_id);
                return true;
            }
            return false;
        } catch (Exception $e) {
            error_log("Error al guardar firma: " . $e->getMessage());
            return false;
        }
    }

    public function getFirmasByInspeccion($inspeccion_id) {
        $query = "SELECT * FROM " . $this->table_name . " 
             WHERE inspeccion_id = ? 
             ORDER BY fecha_firma ASC";
    
        $stmt = $this->conn->prepare($query);
        $stmt->execute([$inspeccion_id]);
    
        return $stmt->fetchAll();
    }

    public function getFirmaPorTipo($inspeccion_id, $tipo_firma) {
        $query = "SELECT * FROM " . $this->table_name . " 
             WHERE inspeccion_id = ? AND tipo_firma = ?";
    
        $stmt = $this->conn->prepare($query);
        $stmt->execute([$inspeccion_id, $tipo_firma]);
    
        return $stmt->fetch();
    }

    private function verificarFirmasCompletas($inspeccion_id) {
        // Contar firmas existentes
        $query = "SELECT COUNT(DISTINCT tipo_firma) as total_firmas 
             FROM " . $this->table_name . " 
             WHERE inspeccion_id = ?";
    
        $stmt = $this->conn->prepare($query);
        $stmt->execute([$inspeccion_id]);
        $result = $stmt->fetch();

        // Si hay al menos 2 firmas (inspector + responsable), marcar como firmada
        if ($result['total_firmas'] >= 2) {
            $update_query = "UPDATE inspecciones 
                       SET firmada = 1, fecha_firma = CURRENT_TIMESTAMP 
                       WHERE id = ?";
        $update_stmt = $this->conn->prepare($update_query);
        $update_stmt->execute([$inspeccion_id]);
    }
}

    public function eliminarFirma($inspeccion_id, $tipo_firma) {
        $query = "DELETE FROM " . $this->table_name . " 
             WHERE inspeccion_id = ? AND tipo_firma = ?";
    
        $stmt = $this->conn->prepare($query);
    
        if ($stmt->execute([$inspeccion_id, $tipo_firma])) {
            // Actualizar estado de firmada
            $update_query = "UPDATE inspecciones SET firmada = 0, fecha_firma = NULL WHERE id = ?";
            $update_stmt = $this->conn->prepare($update_query);
            $update_stmt->execute([$inspeccion_id]);
            return true;
        }
        return false;
    }
}
?>
