<?php
require_once 'config/database.php';

class FotoInspeccion {
    private $conn;
    private $table_name = "fotos_inspeccion";
    private $upload_dir = "uploads/fotos_inspeccion/";

    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
        
        // Crear directorio si no existe
        if (!file_exists($this->upload_dir)) {
            mkdir($this->upload_dir, 0777, true);
        }
    }

    public function uploadFoto($inspeccion_id, $elemento_id, $file, $descripcion = '') {
        // Validar archivo
        $allowed_types = ['image/jpeg', 'image/png', 'image/gif'];
        if (!in_array($file['type'], $allowed_types)) {
            return ['success' => false, 'message' => 'Tipo de archivo no permitido'];
        }

        if ($file['size'] > 5 * 1024 * 1024) { // 5MB máximo
            return ['success' => false, 'message' => 'El archivo es demasiado grande (máximo 5MB)'];
        }

        // Generar nombre único
        $extension = pathinfo($file['name'], PATHINFO_EXTENSION);
        $nombre_archivo = 'insp_' . $inspeccion_id . '_elem_' . $elemento_id . '_' . time() . '.' . $extension;
        $ruta_completa = $this->upload_dir . $nombre_archivo;

        // Subir archivo
        if (move_uploaded_file($file['tmp_name'], $ruta_completa)) {
            // Guardar en base de datos
            $query = "INSERT INTO " . $this->table_name . " 
                      (inspeccion_id, elemento_id, nombre_archivo, ruta_archivo, descripcion) 
                      VALUES (:inspeccion_id, :elemento_id, :nombre_archivo, :ruta_archivo, :descripcion)";
            
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':inspeccion_id', $inspeccion_id);
            $stmt->bindParam(':elemento_id', $elemento_id);
            $stmt->bindParam(':nombre_archivo', $nombre_archivo);
            $stmt->bindParam(':ruta_archivo', $ruta_completa);
            $stmt->bindParam(':descripcion', $descripcion);

            if ($stmt->execute()) {
                return ['success' => true, 'id' => $this->conn->lastInsertId(), 'filename' => $nombre_archivo];
            }
        }

        return ['success' => false, 'message' => 'Error al subir el archivo'];
    }

    public function getFotosByInspeccion($inspeccion_id) {
        $query = "SELECT * FROM " . $this->table_name . " WHERE inspeccion_id = :inspeccion_id ORDER BY fecha_subida";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':inspeccion_id', $inspeccion_id);
        $stmt->execute();
        
        return $stmt->fetchAll();
    }

    public function getFotosByElemento($inspeccion_id, $elemento_id) {
        $query = "SELECT * FROM " . $this->table_name . " 
                  WHERE inspeccion_id = :inspeccion_id AND elemento_id = :elemento_id 
                  ORDER BY fecha_subida";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':inspeccion_id', $inspeccion_id);
        $stmt->bindParam(':elemento_id', $elemento_id);
        $stmt->execute();
        
        return $stmt->fetchAll();
    }

    public function deleteFoto($id) {
        // Obtener información del archivo
        $query = "SELECT ruta_archivo FROM " . $this->table_name . " WHERE id = :id";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);
        $stmt->execute();
        $foto = $stmt->fetch();

        if ($foto) {
            // Eliminar archivo físico
            if (file_exists($foto['ruta_archivo'])) {
                unlink($foto['ruta_archivo']);
            }

            // Eliminar registro de base de datos
            $delete_query = "DELETE FROM " . $this->table_name . " WHERE id = :id";
            $delete_stmt = $this->conn->prepare($delete_query);
            $delete_stmt->bindParam(':id', $id);
            
            return $delete_stmt->execute();
        }

        return false;
    }
}
?>
