<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/Inmueble.php';
require_once 'models/TipoInspeccion.php';

requireLogin();

$inspeccion = new Inspeccion();
$inmueble = new Inmueble();
$tipoInspeccion = new TipoInspeccion();

$inmuebles = $inmueble->getAll();
$tipos_inspeccion = $tipoInspeccion->getActive(); // Solo tipos activos

$message = '';
$message_type = '';

// Obtener elementos según el tipo seleccionado
$elementos = [];
$elementos_por_seccion = [];
$tipo_seleccionado = null;

if (isset($_GET['tipo']) && !empty($_GET['tipo'])) {
    $tipo_seleccionado = $_GET['tipo'];
    $elementos = $inspeccion->getElementosInspeccion($tipo_seleccionado);
    
    // Agrupar elementos por sección
    foreach ($elementos as $elemento) {
        $elementos_por_seccion[$elemento['seccion_nombre']][] = $elemento;
    }
} elseif (isset($_POST['tipo_inspeccion_id']) && !empty($_POST['tipo_inspeccion_id'])) {
    $tipo_seleccionado = $_POST['tipo_inspeccion_id'];
    $elementos = $inspeccion->getElementosInspeccion($tipo_seleccionado);
    
    // Agrupar elementos por sección
    foreach ($elementos as $elemento) {
        $elementos_por_seccion[$elemento['seccion_nombre']][] = $elemento;
    }
}

// Debug: Mostrar datos recibidos
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    echo "<pre style='background: #f0f0f0; padding: 10px; margin: 10px; border: 1px solid #ccc;'>";
    echo "=== DEBUG POST DATA ===\n";
    echo "POST: " . print_r($_POST, true) . "\n";
    echo "FILES: " . print_r($_FILES, true) . "\n";
    echo "SESSION: " . print_r($_SESSION, true) . "\n";
    echo "TIPO INSPECCION RECIBIDO: " . $_POST['tipo_inspeccion_id'] . "\n";
    echo "========================\n";
    echo "</pre>";
    
    try {
        $uploadDir = 'uploads/inspecciones/';
        if (!file_exists($uploadDir)) {
            mkdir($uploadDir, 0777, true);
        }

        // Determinar el estado inicial basado en si se está completando
        $estado_inicial = 'borrador'; // Por defecto es borrador

        // Verificar si se hizo clic en "Completar Inspección"
        if (isset($_POST['completar']) || (isset($_POST['action']) && $_POST['action'] === 'completar')) {
            $estado_inicial = 'completada';
            echo "<script>console.log('🎯 COMPLETAR DETECTADO - Estado: completada');</script>";
        } else {
            echo "<script>console.log('📝 GUARDAR DETECTADO - Estado: borrador');</script>";
        }

        echo "<script>console.log('Estado final que se guardará: $estado_inicial');</script>";
        
        $data = [
            'inmueble_id' => $_POST['inmueble_id'],
            'inspector_id' => $_SESSION['user_id'],
            'tipo_inspeccion_id' => $_POST['tipo_inspeccion_id'], // Ahora dinámico
            'numero_contrato' => cleanInput($_POST['numero_contrato']),
            'fecha_inspeccion' => $_POST['fecha_inspeccion'],
            'comentarios' => cleanInput($_POST['comentarios']),
            'contratista_nombre' => cleanInput($_POST['contratista_nombre']),
            'contratista_direccion' => cleanInput($_POST['contratista_direccion']),
            'contratista_licencia' => cleanInput($_POST['contratista_licencia']),
            'estado' => $estado_inicial
        ];

        $inspeccion_id = $inspeccion->create($data);
        
        if ($inspeccion_id) {
            $respuestas = [];
            foreach ($_POST as $key => $value) {
                if (strpos($key, 'elemento_') === 0) {
                    $elemento_id = str_replace('elemento_', '', $key);
                    $observaciones_key = 'observaciones_' . $elemento_id;
                    
                    $respuestas[$elemento_id] = [
                        'respuesta' => $value,
                        'observaciones' => isset($_POST[$observaciones_key]) ? cleanInput($_POST[$observaciones_key]) : ''
                    ];

                    $foto_key = 'foto_' . $elemento_id;
                    if (isset($_FILES[$foto_key]) && $_FILES[$foto_key]['error'] === UPLOAD_ERR_OK) {
                        $file = $_FILES[$foto_key];
                        $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
                        
                        if (in_array($file['type'], $allowedTypes) && $file['size'] <= 5 * 1024 * 1024) {
                            $extension = pathinfo($file['name'], PATHINFO_EXTENSION);
                            $filename = 'insp_' . $inspeccion_id . '_elem_' . $elemento_id . '_' . time() . '.' . $extension;
                            $filepath = $uploadDir . $filename;
                            
                            if (move_uploaded_file($file['tmp_name'], $filepath)) {
                                $respuestas[$elemento_id]['foto'] = $filepath;
                            }
                        }
                    }
                }
            }
            
            if ($inspeccion->saveRespuestas($inspeccion_id, $respuestas)) {
                if ($estado_inicial === 'completada') {
                    $message = '¡Inspección completada exitosamente!';
                } else {
                    $message = '¡Inspección guardada como borrador!';
                }
                $message_type = 'success';
                
                // Debug: mostrar estado
                echo "<script>console.log('Estado guardado: $estado_inicial');</script>";
                echo "<script>alert('$message'); window.location.href='ver_inspeccion.php?id=$inspeccion_id';</script>";
                exit();
            } else {
                $message = 'Error al guardar las respuestas de la inspección';
                $message_type = 'danger';
            }
        } else {
            $message = 'Error al crear la inspección';
            $message_type = 'danger';
        }
    } catch (Exception $e) {
        $message = 'Error: ' . $e->getMessage();
        $message_type = 'danger';
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Nueva Inspección - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary: #0070f3;
            --success: #00d084;
            --warning: #f5a623;
            --danger: #e00;
            --gray-50: #fafafa;
            --gray-100: #f4f4f5;
            --gray-200: #e4e4e7;
            --gray-300: #d4d4d8;
            --gray-600: #52525b;
            --gray-700: #3f3f46;
            --gray-900: #18181b;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
            background-color: var(--gray-50);
            color: var(--gray-900);
        }

        .header {
            background: white;
            border-bottom: 1px solid var(--gray-200);
            padding: 1rem 0;
            position: sticky;
            top: 0;
            z-index: 50;
        }

        .container-custom {
            max-width: 1200px;
            margin: 0 auto;
            padding: 2rem 1rem;
        }

        .card {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
            margin-bottom: 1.5rem;
        }

        .card-header {
            padding: 1.5rem;
            border-bottom: 1px solid var(--gray-200);
            background-color: var(--gray-50);
        }

        .card-body {
            padding: 1.5rem;
        }

        .progress-sidebar {
            position: sticky;
            top: 6rem;
        }

        .progress-circle {
            width: 80px;
            height: 80px;
            border-radius: 50%;
            background: conic-gradient(var(--success) 0deg, var(--gray-200) 0deg);
            display: flex;
            align-items: center;
            justify-content: center;
            margin: 0 auto 1rem;
            position: relative;
        }

        .progress-circle::before {
            content: '';
            width: 60px;
            height: 60px;
            border-radius: 50%;
            background: white;
            position: absolute;
        }

        .progress-text {
            position: relative;
            z-index: 1;
            font-weight: 600;
        }

        .form-control {
            padding: 0.75rem;
            border: 1px solid var(--gray-300);
            border-radius: 8px;
            font-size: 0.875rem;
        }

        .form-control:focus {
            border-color: var(--primary);
            box-shadow: 0 0 0 3px rgba(0, 112, 243, 0.1);
        }

        .inspection-element {
            background: white;
            margin: 1rem;
            padding: 1.5rem;
            border-radius: 8px;
            border: 1px solid var(--gray-200);
        }

        .response-options {
            display: flex;
            gap: 0.75rem;
            margin: 1rem 0;
        }

        .response-option {
            flex: 1;
        }

        .response-option input[type="radio"] {
            display: none;
        }

        .response-label {
            display: flex;
            align-items: center;
            justify-content: center;
            gap: 0.5rem;
            padding: 0.75rem;
            border: 2px solid var(--gray-200);
            border-radius: 8px;
            cursor: pointer;
            transition: all 0.2s;
            font-weight: 500;
            text-align: center;
        }

        .response-si input:checked + .response-label {
            background: var(--success);
            border-color: var(--success);
            color: white;
        }

        .response-no input:checked + .response-label {
            background: var(--danger);
            border-color: var(--danger);
            color: white;
        }

        .response-nc input:checked + .response-label {
            background: var(--warning);
            border-color: var(--warning);
            color: white;
        }

        .photo-upload {
            border: 2px dashed var(--gray-300);
            border-radius: 8px;
            padding: 1.5rem;
            text-align: center;
            cursor: pointer;
            margin-top: 1rem;
        }

        .photo-upload.has-image {
            border-color: var(--success);
            background: #f0fdf4;
        }

        .photo-preview {
            max-width: 120px;
            max-height: 120px;
            border-radius: 8px;
            margin: 0.5rem auto 0;
            display: none;
        }

        .btn {
            padding: 0.75rem 1.5rem;
            border: none;
            border-radius: 8px;
            font-weight: 500;
            cursor: pointer;
            transition: all 0.2s;
        }

        .btn-primary {
            background: var(--primary);
            color: white;
        }

        .btn-success {
            background: var(--success);
            color: white;
        }

        .btn-secondary {
            background: var(--gray-200);
            color: var(--gray-700);
        }

        .action-bar {
            position: sticky;
            bottom: 0;
            background: white;
            border-top: 1px solid var(--gray-200);
            padding: 1rem;
            margin: 2rem -1rem -2rem;
        }

        .section-badge {
            padding: 0.25rem 0.5rem;
            border-radius: 12px;
            font-size: 0.75rem;
            font-weight: 600;
        }

        .badge-pending {
            background: var(--gray-100);
            color: var(--gray-600);
        }

        .badge-partial {
            background: #fef3c7;
            color: #92400e;
        }

        .badge-complete {
            background: #d1fae5;
            color: #065f46;
        }

        .debug-info {
            position: fixed;
            top: 10px;
            right: 10px;
            background: #000;
            color: #0f0;
            padding: 10px;
            border-radius: 5px;
            font-family: monospace;
            font-size: 12px;
            z-index: 1000;
            max-width: 300px;
        }

        .tipo-selector {
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            color: white;
            border-radius: 15px;
            padding: 2rem;
            margin-bottom: 2rem;
            text-align: center;
        }

        .tipo-card {
            background: white;
            border-radius: 12px;
            padding: 1.5rem;
            margin: 1rem;
            cursor: pointer;
            transition: all 0.3s;
            border: 2px solid transparent;
        }

        .tipo-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 25px rgba(0,0,0,0.15);
        }

        .tipo-card.selected {
            border-color: var(--success);
            background: #f0fdf4;
        }

        .empty-state {
            text-align: center;
            padding: 3rem;
            color: var(--gray-600);
        }
    </style>
</head>
<body>
    <!-- Debug Info -->
    <div id="debugInfo" class="debug-info" style="display: none;">
        <div>Total: <span id="debugTotal">0</span></div>
        <div>Respondidos: <span id="debugAnswered">0</span></div>
        <div>Progreso: <span id="debugProgress">0%</span></div>
        <div>Fotos: <span id="debugPhotos">0</span></div>
    </div>

    <!-- Header -->
    <header class="header">
        <div class="container-fluid">
            <div class="d-flex justify-content-between align-items-center">
                <a href="dashboard.php" class="text-decoration-none text-dark fw-bold">
                    <i class="fas fa-fire-extinguisher me-2"></i>
                    <?php echo APP_NAME; ?>
                </a>
                <div>
                    <button type="button" onclick="toggleDebug()" class="btn btn-sm btn-outline-secondary me-2">
                        <i class="fas fa-bug"></i> Debug
                    </button>
                    <a href="dashboard.php" class="btn btn-sm btn-outline-primary">
                        <i class="fas fa-arrow-left"></i> Volver
                    </a>
                </div>
            </div>
        </div>
    </header>

    <!-- Alert -->
    <?php if ($message): ?>
        <div class="alert alert-<?php echo $message_type; ?> alert-dismissible fade show m-3" role="alert">
            <i class="fas fa-<?php echo $message_type === 'success' ? 'check-circle' : 'exclamation-triangle'; ?> me-2"></i>
            <?php echo $message; ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
        </div>
    <?php endif; ?>

    <div class="container-custom">
        <?php if (empty($inmuebles)): ?>
            <!-- Empty State - No Properties -->
            <div class="card">
                <div class="card-body text-center py-5">
                    <i class="fas fa-building fa-4x text-muted mb-3"></i>
                    <h3 class="text-muted">No hay inmuebles registrados</h3>
                    <p class="text-muted">Necesitas registrar al menos un inmueble antes de crear una inspección</p>
                    <a href="inmuebles.php" class="btn btn-primary">
                        <i class="fas fa-plus me-2"></i>Registrar Primer Inmueble
                    </a>
                </div>
            </div>
        <?php elseif (empty($tipos_inspeccion)): ?>
            <!-- Empty State - No Inspection Types -->
            <div class="card">
                <div class="card-body text-center py-5">
                    <i class="fas fa-clipboard-list fa-4x text-muted mb-3"></i>
                    <h3 class="text-muted">No hay tipos de inspección activos</h3>
                    <p class="text-muted">Necesitas activar al menos un tipo de inspección</p>
                    <a href="admin_inspecciones.php" class="btn btn-primary">
                        <i class="fas fa-cog me-2"></i>Configurar Inspecciones
                    </a>
                </div>
            </div>
        <?php elseif (!$tipo_seleccionado): ?>
            <!-- Selector de Tipo de Inspección -->
            <div class="tipo-selector">
                <h2 class="mb-4">
                    <i class="fas fa-clipboard-check me-3"></i>
                    Selecciona el Tipo de Inspección
                </h2>
                <p class="mb-4">Elige qué tipo de inspección vas a realizar</p>
            </div>

            <div class="row">
                <?php foreach ($tipos_inspeccion as $tipo): ?>
                    <div class="col-md-6 col-lg-4">
                        <div class="tipo-card" onclick="seleccionarTipo(<?php echo $tipo['id']; ?>)">
                            <div class="text-center">
                                <i class="fas fa-<?php 
                                    switch(strtolower($tipo['nombre'])) {
                                        case 'bombas contra incendio':
                                        case 'bomba contra incendio':
                                            echo 'fire-extinguisher';
                                            break;
                                        case 'extintores':
                                        case 'extintor':
                                            echo 'fire-extinguisher';
                                            break;
                                        case 'rociadores':
                                        case 'rociador':
                                        case 'sprinklers':
                                            echo 'shower';
                                            break;
                                        case 'alarmas':
                                        case 'alarma':
                                        case 'sistema de alarmas':
                                            echo 'bell';
                                            break;
                                        case 'iluminación de emergencia':
                                        case 'luces de emergencia':
                                            echo 'lightbulb';
                                            break;
                                        case 'señalización':
                                        case 'señales':
                                            echo 'sign';
                                            break;
                                        default:
                                            echo 'clipboard-check';
                                    }
                                ?> fa-3x text-primary mb-3"></i>
                                <h5 class="fw-bold"><?php echo htmlspecialchars($tipo['nombre']); ?></h5>
                                <?php if ($tipo['descripcion']): ?>
                                    <p class="text-muted small"><?php echo htmlspecialchars($tipo['descripcion']); ?></p>
                                <?php endif; ?>
                                
                                <?php
                                // Obtener estadísticas del tipo
                                $secciones = $tipoInspeccion->getSecciones($tipo['id']);
                                $elementos = $tipoInspeccion->getElementos($tipo['id']);
                                ?>
                                
                                <div class="d-flex justify-content-center gap-3 mt-3">
                                    <small class="text-muted">
                                        <i class="fas fa-layer-group me-1"></i>
                                        <?php echo count($secciones); ?> secciones
                                    </small>
                                    <small class="text-muted">
                                        <i class="fas fa-question-circle me-1"></i>
                                        <?php echo count($elementos); ?> preguntas
                                    </small>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>

            <div class="text-center mt-4">
                <p class="text-muted">
                    <i class="fas fa-info-circle me-2"></i>
                    ¿No encuentras el tipo que necesitas? 
                    <a href="admin_inspecciones.php" class="text-decoration-none">Configura nuevos tipos aquí</a>
                </p>
            </div>

        <?php else: ?>
            <!-- Formulario de Inspección -->
            <div class="row">
                <!-- Progress Sidebar -->
                <div class="col-lg-3">
                    <div class="progress-sidebar">
                        <div class="card">
                            <div class="card-header text-center">
                                <div class="progress-circle" id="progressCircle">
                                    <span class="progress-text" id="progressText">0%</span>
                                </div>
                                <h6 class="mb-0">Progreso de Inspección</h6>
                                <?php 
                                $tipo_info = $tipoInspeccion->getById($tipo_seleccionado);
                                if ($tipo_info): ?>
                                    <small class="text-muted"><?php echo htmlspecialchars($tipo_info['nombre']); ?></small>
                                <?php endif; ?>
                            </div>
                            <div class="card-body">
                                <?php if (!empty($elementos_por_seccion)): ?>
                                    <?php foreach ($elementos_por_seccion as $seccion_nombre => $elementos_seccion): ?>
                                        <div class="d-flex justify-content-between align-items-center mb-2">
                                            <small class="text-muted"><?php echo htmlspecialchars($seccion_nombre); ?></small>
                                            <span class="section-badge badge-pending" id="badge-<?php echo md5($seccion_nombre); ?>">
                                                0/<?php echo count($elementos_seccion); ?>
                                            </span>
                                        </div>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <div class="text-center text-muted">
                                        <i class="fas fa-exclamation-triangle mb-2"></i>
                                        <p class="small">Este tipo de inspección no tiene elementos configurados</p>
                                        <a href="admin_elementos.php?tipo=<?php echo $tipo_seleccionado; ?>" class="btn btn-sm btn-outline-primary">
                                            Configurar Elementos
                                        </a>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Main Content -->
                <div class="col-lg-9">
                    <?php if (empty($elementos_por_seccion)): ?>
                        <!-- Empty State - No Elements -->
                        <div class="card">
                            <div class="card-body text-center py-5">
                                <i class="fas fa-clipboard-list fa-4x text-muted mb-3"></i>
                                <h4 class="text-muted">Tipo de inspección sin configurar</h4>
                                <p class="text-muted">Este tipo de inspección no tiene elementos/preguntas configuradas</p>
                                <div class="d-flex gap-2 justify-content-center">
                                    <a href="admin_elementos.php?tipo=<?php echo $tipo_seleccionado; ?>" class="btn btn-primary">
                                        <i class="fas fa-cog me-2"></i>Configurar Elementos
                                    </a>
                                    <a href="nueva_inspeccion.php" class="btn btn-secondary">
                                        <i class="fas fa-arrow-left me-2"></i>Elegir Otro Tipo
                                    </a>
                                </div>
                            </div>
                        </div>
                    <?php else: ?>
                        <form method="POST" id="inspectionForm" enctype="multipart/form-data">
                            <input type="hidden" name="tipo_inspeccion_id" value="<?php echo $tipo_seleccionado; ?>">
                            
                            <!-- Debug: mostrar el tipo seleccionado -->
                            <div class="alert alert-info" style="display: none;" id="debugTipo">
                                <strong>Debug:</strong> Tipo seleccionado = <?php echo $tipo_seleccionado; ?>
                            </div>

                            <!-- General Information -->
                            <div class="card">
                                <div class="card-header">
                                    <h5 class="mb-0">
                                        <i class="fas fa-info-circle me-2"></i>
                                        Información General
                                    </h5>
                                </div>
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-md-6 mb-3">
                                            <label class="form-label">Tipo de Inspección</label>
                                            <div class="d-flex align-items-center">
                                                <input type="text" class="form-control" 
                                                       value="<?php echo htmlspecialchars($tipo_info['nombre']); ?>" readonly>
                                                <a href="nueva_inspeccion.php" class="btn btn-outline-secondary ms-2" title="Cambiar tipo">
                                                    <i class="fas fa-exchange-alt"></i>
                                                </a>
                                            </div>
                                        </div>
                                        <div class="col-md-6 mb-3">
                                            <label class="form-label">Inmueble *</label>
                                            <select class="form-control" name="inmueble_id" required>
                                                <option value="">Seleccionar inmueble...</option>
                                                <?php foreach ($inmuebles as $inm): ?>
                                                    <option value="<?php echo $inm['id']; ?>">
                                                        <?php echo htmlspecialchars($inm['nombre']); ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                        <div class="col-md-6 mb-3">
                                            <label class="form-label">N.º de Contrato</label>
                                            <input type="text" class="form-control" name="numero_contrato">
                                        </div>
                                        <div class="col-md-6 mb-3">
                                            <label class="form-label">Fecha de Inspección *</label>
                                            <input type="date" class="form-control" name="fecha_inspeccion" 
                                                   value="<?php echo date('Y-m-d'); ?>" required>
                                        </div>
                                        <div class="col-md-6 mb-3">
                                            <label class="form-label">Inspector</label>
                                            <input type="text" class="form-control" 
                                                   value="<?php echo $_SESSION['user_name']; ?>" readonly>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- Inspection Sections -->
                            <div class="accordion" id="inspectionAccordion">
                                <?php $section_index = 0; ?>
                                <?php foreach ($elementos_por_seccion as $seccion_nombre => $elementos_seccion): ?>
                                    <div class="accordion-item">
                                        <h2 class="accordion-header">
                                            <button class="accordion-button <?php echo $section_index === 0 ? '' : 'collapsed'; ?>" 
                                                    type="button" data-bs-toggle="collapse" 
                                                    data-bs-target="#collapse<?php echo $section_index; ?>">
                                                <i class="fas fa-cogs me-2"></i>
                                                <?php echo htmlspecialchars($seccion_nombre); ?>
                                                <span class="section-badge badge-pending ms-auto me-3" id="section-badge-<?php echo md5($seccion_nombre); ?>">
                                                    0/<?php echo count($elementos_seccion); ?>
                                                </span>
                                            </button>
                                        </h2>
                                        <div id="collapse<?php echo $section_index; ?>" 
                                             class="accordion-collapse collapse <?php echo $section_index === 0 ? 'show' : ''; ?>" 
                                             data-bs-parent="#inspectionAccordion">
                                            <div class="accordion-body">
                                                <?php foreach ($elementos_seccion as $elemento): ?>
                                                    <div class="inspection-element" data-section="<?php echo md5($seccion_nombre); ?>" data-element="<?php echo $elemento['id']; ?>">
                                                        <div class="mb-3">
                                                            <strong><?php echo htmlspecialchars($elemento['descripcion']); ?></strong>
                                                            <?php if ($elemento['obligatorio']): ?>
                                                                <span class="badge bg-danger ms-2">Obligatorio</span>
                                                            <?php endif; ?>
                                                        </div>

                                                        <?php if ($elemento['tipo_respuesta'] === 'si_no_nc'): ?>
                                                            <div class="response-options">
                                                                <div class="response-option response-si">
                                                                    <input type="radio" id="si_<?php echo $elemento['id']; ?>" 
                                                                           name="elemento_<?php echo $elemento['id']; ?>" value="si" 
                                                                           <?php echo $elemento['obligatorio'] ? 'required' : ''; ?>>
                                                                    <label for="si_<?php echo $elemento['id']; ?>" class="response-label">
                                                                        <i class="fas fa-check"></i> SÍ
                                                                    </label>
                                                                </div>
                                                                <div class="response-option response-no">
                                                                    <input type="radio" id="no_<?php echo $elemento['id']; ?>" 
                                                                           name="elemento_<?php echo $elemento['id']; ?>" value="no" 
                                                                           <?php echo $elemento['obligatorio'] ? 'required' : ''; ?>>
                                                                    <label for="no_<?php echo $elemento['id']; ?>" class="response-label">
                                                                        <i class="fas fa-times"></i> NO
                                                                    </label>
                                                                </div>
                                                                <div class="response-option response-nc">
                                                                    <input type="radio" id="nc_<?php echo $elemento['id']; ?>" 
                                                                           name="elemento_<?php echo $elemento['id']; ?>" value="nc" 
                                                                           <?php echo $elemento['obligatorio'] ? 'required' : ''; ?>>
                                                                    <label for="nc_<?php echo $elemento['id']; ?>" class="response-label">
                                                                        <i class="fas fa-minus"></i> N/C
                                                                    </label>
                                                                </div>
                                                            </div>
                                                        <?php elseif ($elemento['tipo_respuesta'] === 'si_no'): ?>
                                                            <div class="response-options">
                                                                <div class="response-option response-si">
                                                                    <input type="radio" id="si_<?php echo $elemento['id']; ?>" 
                                                                           name="elemento_<?php echo $elemento['id']; ?>" value="si" 
                                                                           <?php echo $elemento['obligatorio'] ? 'required' : ''; ?>>
                                                                    <label for="si_<?php echo $elemento['id']; ?>" class="response-label">
                                                                        <i class="fas fa-check"></i> SÍ
                                                                    </label>
                                                                </div>
                                                                <div class="response-option response-no">
                                                                    <input type="radio" id="no_<?php echo $elemento['id']; ?>" 
                                                                           name="elemento_<?php echo $elemento['id']; ?>" value="no" 
                                                                           <?php echo $elemento['obligatorio'] ? 'required' : ''; ?>>
                                                                    <label for="no_<?php echo $elemento['id']; ?>" class="response-label">
                                                                        <i class="fas fa-times"></i> NO
                                                                    </label>
                                                                </div>
                                                            </div>
                                                        <?php elseif ($elemento['tipo_respuesta'] === 'texto'): ?>
                                                            <div class="mb-3">
                                                                <textarea class="form-control" name="elemento_<?php echo $elemento['id']; ?>" 
                                                                          rows="3" placeholder="Escriba su respuesta..." 
                                                                          <?php echo $elemento['obligatorio'] ? 'required' : ''; ?>></textarea>
                                                            </div>
                                                        <?php elseif ($elemento['tipo_respuesta'] === 'numero'): ?>
                                                            <div class="mb-3">
                                                                <input type="number" class="form-control" name="elemento_<?php echo $elemento['id']; ?>" 
                                                                       placeholder="Ingrese un número" step="0.01" 
                                                                       <?php echo $elemento['obligatorio'] ? 'required' : ''; ?>>
                                                            </div>
                                                        <?php endif; ?>

                                                        <div class="mb-3">
                                                            <input type="text" class="form-control" 
                                                                   name="observaciones_<?php echo $elemento['id']; ?>" 
                                                                   placeholder="Observaciones adicionales (opcional)">
                                                        </div>

                                                        <div class="photo-upload" onclick="document.getElementById('foto_<?php echo $elemento['id']; ?>').click()">
                                                            <input type="file" id="foto_<?php echo $elemento['id']; ?>" 
                                                                   name="foto_<?php echo $elemento['id']; ?>" accept="image/*" 
                                                                   style="display: none;" onchange="previewPhoto(this, <?php echo $elemento['id']; ?>)">
                                                            <div id="upload-content-<?php echo $elemento['id']; ?>">
                                                                <i class="fas fa-camera fa-2x text-muted mb-2"></i>
                                                                <p class="mb-0">Adjuntar Fotografía</p>
                                                            </div>
                                                            <img id="preview_<?php echo $elemento['id']; ?>" class="photo-preview" alt="Vista previa">
                                                        </div>
                                                    </div>
                                                <?php endforeach; ?>
                                            </div>
                                        </div>
                                    </div>
                                    <?php $section_index++; ?>
                                <?php endforeach; ?>
                            </div>

                            <!-- Contractor Information -->
                            <div class="card">
                                <div class="card-header">
                                    <h5 class="mb-0">
                                        <i class="fas fa-user-tie me-2"></i>
                                        Información del Contratista
                                    </h5>
                                </div>
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-md-6 mb-3">
                                            <label class="form-label">Nombre del Contratista</label>
                                            <input type="text" class="form-control" name="contratista_nombre">
                                        </div>
                                        <div class="col-md-6 mb-3">
                                            <label class="form-label">N.º de Licencia/Certificación</label>
                                            <input type="text" class="form-control" name="contratista_licencia">
                                        </div>
                                        <div class="col-12 mb-3">
                                            <label class="form-label">Dirección del Contratista</label>
                                            <textarea class="form-control" name="contratista_direccion" rows="3"></textarea>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- Comments -->
                            <div class="card">
                                <div class="card-header">
                                    <h5 class="mb-0">
                                        <i class="fas fa-comments me-2"></i>
                                        Comentarios Adicionales
                                    </h5>
                                </div>
                                <div class="card-body">
                                    <textarea class="form-control" name="comentarios" rows="4" 
                                              placeholder="Comentarios adicionales sobre la inspección..."></textarea>
                                </div>
                            </div>
                        </form>
                    <?php endif; ?>
                </div>
            </div>
        <?php endif; ?>
    </div>

    <!-- Action Bar -->
    <?php if ($tipo_seleccionado && !empty($elementos_por_seccion)): ?>
        <div class="action-bar">
            <div class="d-flex gap-3 justify-content-end">
                <a href="nueva_inspeccion.php" class="btn btn-secondary">
                    <i class="fas fa-arrow-left me-2"></i>Cambiar Tipo
                </a>
                <button type="submit" form="inspectionForm" class="btn btn-primary" id="saveBtn">
                    <i class="fas fa-save me-2"></i>Guardar Borrador
                </button>
                <button type="submit" form="inspectionForm" name="completar" class="btn btn-success" id="completeBtn">
                    <i class="fas fa-check me-2"></i>Completar Inspección
                </button>
            </div>
        </div>
    <?php endif; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Función para seleccionar tipo de inspección
        function seleccionarTipo(tipoId) {
            window.location.href = 'nueva_inspeccion.php?tipo=' + tipoId;
        }

        // Variables globales
        const totalElements = <?php echo !empty($elementos_por_seccion) ? array_sum(array_map('count', $elementos_por_seccion)) : 0; ?>;
        let answeredElements = 0;
        let photosUploaded = 0;

        console.log('🚀 Sistema iniciado - Total elementos:', totalElements);

        // Función para mostrar/ocultar debug
        function toggleDebug() {
            const debugInfo = document.getElementById('debugInfo');
            debugInfo.style.display = debugInfo.style.display === 'none' ? 'block' : 'none';
            updateDebugInfo();
        }

        // Actualizar información de debug
        function updateDebugInfo() {
            document.getElementById('debugTotal').textContent = totalElements;
            document.getElementById('debugAnswered').textContent = answeredElements;
            document.getElementById('debugProgress').textContent = Math.round((answeredElements / totalElements) * 100) + '%';
            document.getElementById('debugPhotos').textContent = photosUploaded;
        }

        // Función para previsualizar fotos
        function previewPhoto(input, elementId) {
            console.log('📸 Previsualizando foto para elemento:', elementId);
            
            const preview = document.getElementById('preview_' + elementId);
            const uploadContent = document.getElementById('upload-content-' + elementId);
            const uploadZone = input.closest('.photo-upload');
            
            if (input.files && input.files[0]) {
                const file = input.files[0];
                console.log('📁 Archivo:', file.name, 'Tamaño:', file.size);
                
                // Validar archivo
                if (!file.type.startsWith('image/')) {
                    alert('❌ Solo se permiten imágenes');
                    input.value = '';
                    return;
                }
                
                if (file.size > 5 * 1024 * 1024) {
                    alert('❌ Archivo muy grande (máximo 5MB)');
                    input.value = '';
                    return;
                }
                
                // Mostrar preview
                const reader = new FileReader();
                reader.onload = function(e) {
                    preview.src = e.target.result;
                    preview.style.display = 'block';
                    uploadContent.innerHTML = `
                        <i class="fas fa-check-circle fa-2x text-success mb-2"></i>
                        <p class="mb-0 text-success">✓ ${file.name}</p>
                        <small class="text-muted">Haz clic para cambiar</small>
                    `;
                    uploadZone.classList.add('has-image');
                    photosUploaded++;
                    updateDebugInfo();
                    console.log('✅ Foto cargada exitosamente');
                };
                reader.readAsDataURL(file);
            } else {
                // Restaurar estado
                preview.style.display = 'none';
                uploadContent.innerHTML = `
                    <i class="fas fa-camera fa-2x text-muted mb-2"></i>
                    <p class="mb-0">Adjuntar Fotografía</p>
                `;
                uploadZone.classList.remove('has-image');
                if (photosUploaded > 0) photosUploaded--;
                updateDebugInfo();
            }
        }

        // Función para actualizar progreso
        function updateProgress() {
            const checkedRadios = document.querySelectorAll('input[type="radio"]:checked');
            const filledTextareas = document.querySelectorAll('textarea[name^="elemento_"]:not([name^="observaciones_"])');
            const filledNumbers = document.querySelectorAll('input[type="number"][name^="elemento_"]');
            
            let filledTextCount = 0;
            filledTextareas.forEach(textarea => {
                if (textarea.value.trim() !== '') filledTextCount++;
            });
            
            let filledNumberCount = 0;
            filledNumbers.forEach(input => {
                if (input.value.trim() !== '') filledNumberCount++;
            });
            
            answeredElements = checkedRadios.length + filledTextCount + filledNumberCount;
            
            console.log('📊 Actualizando progreso:', answeredElements, '/', totalElements);
            
            const percentage = totalElements > 0 ? Math.round((answeredElements / totalElements) * 100) : 0;
            
            // Actualizar círculo
            const progressCircle = document.getElementById('progressCircle');
            const progressText = document.getElementById('progressText');
            
            if (progressCircle && progressText) {
                const degrees = (percentage / 100) * 360;
                progressCircle.style.background = `conic-gradient(var(--success) ${degrees}deg, var(--gray-200) ${degrees}deg)`;
                progressText.textContent = percentage + '%';
            }
            
            // Actualizar badges por sección
            const sections = {};
            checkedRadios.forEach(radio => {
                const element = radio.closest('.inspection-element');
                if (element) {
                    const section = element.dataset.section;
                    if (!sections[section]) sections[section] = 0;
                    sections[section]++;
                }
            });
            
            // Contar elementos de texto y número por sección
            filledTextareas.forEach(textarea => {
                if (textarea.value.trim() !== '') {
                    const element = textarea.closest('.inspection-element');
                    if (element) {
                        const section = element.dataset.section;
                        if (!sections[section]) sections[section] = 0;
                        sections[section]++;
                    }
                }
            });
            
            filledNumbers.forEach(input => {
                if (input.value.trim() !== '') {
                    const element = input.closest('.inspection-element');
                    if (element) {
                        const section = element.dataset.section;
                        if (!sections[section]) sections[section] = 0;
                        sections[section]++;
                    }
                }
            });
            
            // Actualizar cada sección
            <?php if (!empty($elementos_por_seccion)): ?>
                <?php foreach ($elementos_por_seccion as $seccion_nombre => $elementos_seccion): ?>
                    const sectionId_<?php echo md5($seccion_nombre); ?> = '<?php echo md5($seccion_nombre); ?>';
                    const count_<?php echo md5($seccion_nombre); ?> = sections[sectionId_<?php echo md5($seccion_nombre); ?>] || 0;
                    const total_<?php echo md5($seccion_nombre); ?> = <?php echo count($elementos_seccion); ?>;
                    
                    const badge_<?php echo md5($seccion_nombre); ?> = document.getElementById('badge-<?php echo md5($seccion_nombre); ?>');
                    const sectionBadge_<?php echo md5($seccion_nombre); ?> = document.getElementById('section-badge-<?php echo md5($seccion_nombre); ?>');
                    
                    if (badge_<?php echo md5($seccion_nombre); ?>) {
                        badge_<?php echo md5($seccion_nombre); ?>.textContent = count_<?php echo md5($seccion_nombre); ?> + '/' + total_<?php echo md5($seccion_nombre); ?>;
                        badge_<?php echo md5($seccion_nombre); ?>.className = 'section-badge ';
                        
                        if (count_<?php echo md5($seccion_nombre); ?> === total_<?php echo md5($seccion_nombre); ?>) {
                            badge_<?php echo md5($seccion_nombre); ?>.className += 'badge-complete';
                        } else if (count_<?php echo md5($seccion_nombre); ?> > 0) {
                            badge_<?php echo md5($seccion_nombre); ?>.className += 'badge-partial';
                        } else {
                            badge_<?php echo md5($seccion_nombre); ?>.className += 'badge-pending';
                        }
                    }
                    
                    if (sectionBadge_<?php echo md5($seccion_nombre); ?>) {
                        sectionBadge_<?php echo md5($seccion_nombre); ?>.textContent = count_<?php echo md5($seccion_nombre); ?> + '/' + total_<?php echo md5($seccion_nombre); ?>;
                        sectionBadge_<?php echo md5($seccion_nombre); ?>.className = 'section-badge ms-auto me-3 ';
                        
                        if (count_<?php echo md5($seccion_nombre); ?> === total_<?php echo md5($seccion_nombre); ?>) {
                            sectionBadge_<?php echo md5($seccion_nombre); ?>.className += 'badge-complete';
                        } else if (count_<?php echo md5($seccion_nombre); ?> > 0) {
                            sectionBadge_<?php echo md5($seccion_nombre); ?>.className += 'badge-partial';
                        } else {
                            sectionBadge_<?php echo md5($seccion_nombre); ?>.className += 'badge-pending';
                        }
                    }
                <?php endforeach; ?>
            <?php endif; ?>
            
            updateDebugInfo();
            console.log('✅ Progreso actualizado:', percentage + '%');
        }

        // Inicializar cuando el DOM esté listo
        document.addEventListener('DOMContentLoaded', function() {
            console.log('🎯 DOM cargado, configurando eventos...');
            
            // Configurar radio buttons
            const radioButtons = document.querySelectorAll('input[type="radio"]');
            console.log('🔘 Radio buttons encontrados:', radioButtons.length);
            
            radioButtons.forEach(radio => {
                radio.addEventListener('change', function() {
                    console.log('🔄 Radio cambiado:', this.name, '=', this.value);
                    updateProgress();
                });
            });

            // Configurar campos de texto y número
            const textInputs = document.querySelectorAll('textarea[name^="elemento_"], input[type="number"][name^="elemento_"]');
            textInputs.forEach(input => {
                input.addEventListener('input', function() {
                    updateProgress();
                });
            });

            // Configurar formulario
            const form = document.getElementById('inspectionForm');
            if (form) {
                form.addEventListener('submit', function(e) {
                    console.log('📤 Enviando formulario...');
                    
                    // Debug: verificar tipo de inspección
                    const tipoInspeccion = form.querySelector('input[name="tipo_inspeccion_id"]');
                    if (tipoInspeccion) {
                        console.log('🎯 Tipo de inspección:', tipoInspeccion.value);
                    } else {
                        console.error('❌ Campo tipo_inspeccion_id no encontrado!');
                    }
                    
                    console.log('🎯 Botón presionado:', e.submitter ? e.submitter.name : 'desconocido');
                    
                    // Agregar campo hidden para identificar la acción
                    const existingAction = form.querySelector('input[name="action"]');
                    if (existingAction) {
                        existingAction.remove();
                    }
                    
                    if (e.submitter && e.submitter.name === 'completar') {
                        const actionInput = document.createElement('input');
                        actionInput.type = 'hidden';
                        actionInput.name = 'action';
                        actionInput.value = 'completar';
                        form.appendChild(actionInput);
                        console.log('✅ Campo action=completar agregado');
                    }
                    
                    // Validaciones básicas
                    const inmueble = document.querySelector('select[name="inmueble_id"]').value;
                    const fecha = document.querySelector('input[name="fecha_inspeccion"]').value;
                    
                    if (!inmueble) {
                        e.preventDefault();
                        alert('❌ Selecciona un inmueble');
                        return false;
                    }
                    
                    if (!fecha) {
                        e.preventDefault();
                        alert('❌ Selecciona la fecha');
                        return false;
                    }
                    
                    // Validar si está completando
                    const isCompleting = e.submitter && e.submitter.name === 'completar';
                    
                    if (isCompleting && answeredElements < totalElements) {
                        e.preventDefault();
                        alert(`❌ Para completar debe responder todo.\nProgreso: ${answeredElements}/${totalElements}`);
                        return false;
                    }
                    
                    // Mostrar loading
                    const saveBtn = document.getElementById('saveBtn');
                    const completeBtn = document.getElementById('completeBtn');
                    
                    if (saveBtn) saveBtn.disabled = true;
                    if (completeBtn) completeBtn.disabled = true;
                    
                    if (isCompleting && completeBtn) {
                        completeBtn.innerHTML = '<i class="fas fa-spinner fa-spin me-2"></i>Completando...';
                    } else if (saveBtn) {
                        saveBtn.innerHTML = '<i class="fas fa-spinner fa-spin me-2"></i>Guardando...';
                    }
                    
                    console.log('✅ Formulario válido, enviando...');
                    return true;
                });
            }

            // Inicializar progreso
            updateProgress();
            updateDebugInfo();
            
            console.log('🎉 Sistema inicializado correctamente');
        });
    </script>
</body>
</html>
