<?php
require_once 'config/config.php';

requireAdmin(); // Solo administradores

$mensaje = '';
$tipo_mensaje = '';

if ($_POST && isset($_POST['optimizar'])) {
    $archivos_corregidos = [];
    
    // Lista de correcciones comunes
    $correcciones = [
        // Corregir enlaces a generar_pdf.php -> generar_pdf_simple.php
        'generar_pdf.php' => 'generar_pdf_simple.php',
        // Agregar más correcciones según sea necesario
    ];
    
    $archivos_a_revisar = [
        'dashboard.php',
        'inspecciones.php',
        'ver_inspeccion.php',
        'nueva_inspeccion.php'
    ];
    
    foreach ($archivos_a_revisar as $archivo) {
        if (file_exists($archivo)) {
            $contenido = file_get_contents($archivo);
            $contenido_original = $contenido;
            
            foreach ($correcciones as $incorrecto => $correcto) {
                $contenido = str_replace($incorrecto, $correcto, $contenido);
            }
            
            if ($contenido !== $contenido_original) {
                file_put_contents($archivo, $contenido);
                $archivos_corregidos[] = $archivo;
            }
        }
    }
    
    if (!empty($archivos_corregidos)) {
        $mensaje = 'Enlaces corregidos en: ' . implode(', ', $archivos_corregidos);
        $tipo_mensaje = 'success';
    } else {
        $mensaje = 'No se encontraron enlaces que corregir';
        $tipo_mensaje = 'info';
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Optimizar Navegación</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
</head>
<body>
    <div class="container py-4">
        <div class="bg-warning text-dark p-4 rounded mb-4">
            <h1><i class="fas fa-tools"></i> Optimizar Navegación</h1>
            <p class="mb-0">Herramienta para corregir enlaces rotos y optimizar la navegación</p>
        </div>

        <?php if ($mensaje): ?>
        <div class="alert alert-<?php echo $tipo_mensaje; ?>">
            <?php echo $mensaje; ?>
        </div>
        <?php endif; ?>

        <div class="card">
            <div class="card-header">
                <h5>🔧 Optimizaciones Disponibles</h5>
            </div>
            <div class="card-body">
                <form method="POST">
                    <div class="mb-3">
                        <h6>Correcciones que se aplicarán:</h6>
                        <ul>
                            <li>Corregir enlaces a <code>generar_pdf.php</code> → <code>generar_pdf_simple.php</code></li>
                            <li>Verificar enlaces de navegación principales</li>
                            <li>Optimizar rutas de redirección</li>
                        </ul>
                    </div>
                    
                    <button type="submit" name="optimizar" class="btn btn-warning">
                        <i class="fas fa-magic"></i> Optimizar Enlaces
                    </button>
                    <a href="verificar_navegacion.php" class="btn btn-info">
                        <i class="fas fa-search"></i> Verificar Navegación
                    </a>
                    <a href="dashboard.php" class="btn btn-secondary">
                        <i class="fas fa-home"></i> Volver al Dashboard
                    </a>
                </form>
            </div>
        </div>
    </div>
</body>
</html>
