<?php
require_once 'config/config.php';
require_once 'models/User.php';
require_once 'models/Inspeccion.php';

requireLogin();

$user = new User();
$user_data = $user->getById($_SESSION['user_id']);

$message = '';
$error = '';

// Procesar solo el formulario de perfil (no el de crear usuario)
if ($_POST && !isset($_POST['create_user'])) {
    $nombre = trim($_POST['nombre'] ?? '');
    $email = trim($_POST['email'] ?? '');
    $password_actual = $_POST['password_actual'] ?? '';
    $nueva_password = $_POST['nueva_password'] ?? '';
    $confirmar_password = $_POST['confirmar_password'] ?? '';
    
    // Validaciones básicas
    if (empty($nombre) || empty($email)) {
        $error = 'El nombre y email son obligatorios';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = 'El email no es válido';
    } else {
        // Manejar subida de foto
        $foto_perfil = null;
        if (isset($_FILES['foto_perfil']) && $_FILES['foto_perfil']['error'] === UPLOAD_ERR_OK) {
            $uploadDir = 'uploads/perfiles/';
            if (!file_exists($uploadDir)) {
                mkdir($uploadDir, 0777, true);
            }
            
            $file = $_FILES['foto_perfil'];
            $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
            
            if (in_array($file['type'], $allowedTypes) && $file['size'] <= 2 * 1024 * 1024) {
                $extension = pathinfo($file['name'], PATHINFO_EXTENSION);
                $filename = 'perfil_' . $_SESSION['user_id'] . '_' . time() . '.' . $extension;
                $filepath = $uploadDir . $filename;
                
                if (move_uploaded_file($file['tmp_name'], $filepath)) {
                    $foto_perfil = $filepath;
                    
                    // Eliminar foto anterior si existe
                    $foto_actual = isset($user_data['foto_perfil']) ? $user_data['foto_perfil'] : null;
                    if ($foto_actual && file_exists($foto_actual)) {
                        unlink($foto_actual);
                    }
                }
            } else {
                $error = 'Archivo de imagen no válido (máximo 2MB, formatos: JPG, PNG, GIF)';
            }
        }
        
        if (!$error) {
            // Si se quiere cambiar la contraseña
            if (!empty($nueva_password)) {
                if (empty($password_actual)) {
                    $error = 'Debes ingresar tu contraseña actual para cambiarla';
                } elseif ($nueva_password !== $confirmar_password) {
                    $error = 'Las nuevas contraseñas no coinciden';
                } elseif (strlen($nueva_password) < 6) {
                    $error = 'La nueva contraseña debe tener al menos 6 caracteres';
                } else {
                    // Verificar contraseña actual
                    if (!$user->verifyCurrentPassword($_SESSION['user_id'], $password_actual)) {
                        $error = 'La contraseña actual es incorrecta';
                    } else {
                        // Actualizar con nueva contraseña
                        if ($user->updateProfileWithPhoto($_SESSION['user_id'], $nombre, $email, $foto_perfil, $nueva_password)) {
                            $_SESSION['user_name'] = $nombre;
                            $_SESSION['user_email'] = $email;
                            $message = 'Perfil actualizado correctamente (incluyendo contraseña)';
                            $user_data = $user->getById($_SESSION['user_id']); // Recargar datos
                        } else {
                            $error = 'Error al actualizar el perfil';
                        }
                    }
                }
            } else {
                // Actualizar solo nombre, email y foto
                if ($user->updateProfileWithPhoto($_SESSION['user_id'], $nombre, $email, $foto_perfil)) {
                    $_SESSION['user_name'] = $nombre;
                    $_SESSION['user_email'] = $email;
                    $message = 'Perfil actualizado correctamente';
                    $user_data = $user->getById($_SESSION['user_id']); // Recargar datos
                } else {
                    $error = 'Error al actualizar el perfil';
                }
            }
        }
    }
}

// Obtener foto de perfil de forma segura
$foto_perfil = isset($user_data['foto_perfil']) ? $user_data['foto_perfil'] : null;
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Mi Perfil - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary: #0070f3;
            --success: #00d084;
            --warning: #f5a623;
            --danger: #e00;
            --gray-50: #fafafa;
            --gray-100: #f4f4f5;
            --gray-200: #e4e4e7;
            --gray-300: #d4d4d8;
            --gray-400: #a1a1aa;
            --gray-500: #71717a;
            --gray-600: #52525b;
            --gray-700: #3f3f46;
            --gray-800: #27272a;
            --gray-900: #18181b;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', sans-serif;
            background-color: var(--gray-50);
            color: var(--gray-900);
            line-height: 1.6;
        }

        .header {
            background: white;
            border-bottom: 1px solid var(--gray-200);
            padding: 1rem 0;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
        }

        .header-content {
            max-width: 1200px;
            margin: 0 auto;
            padding: 0 1rem;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .logo {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            font-weight: 600;
            font-size: 1.25rem;
            color: var(--gray-900);
            text-decoration: none;
        }

        .logo:hover {
            color: var(--primary);
        }

        .main-container {
            max-width: 800px;
            margin: 2rem auto;
            padding: 0 1rem;
        }

        .profile-card {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 12px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
            overflow: hidden;
        }

        .profile-header {
            background: linear-gradient(135deg, var(--primary), #0051cc);
            color: white;
            padding: 2rem;
            text-align: center;
        }

        .profile-avatar {
            width: 80px;
            height: 80px;
            background: rgba(255,255,255,0.2);
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            margin: 0 auto 1rem;
            font-size: 2rem;
        }

        .profile-name {
            font-size: 1.5rem;
            font-weight: 600;
            margin: 0 0 0.5rem 0;
        }

        .profile-role {
            opacity: 0.9;
            font-size: 1rem;
        }

        .profile-body {
            padding: 2rem;
        }

        .form-group {
            margin-bottom: 1.5rem;
        }

        .form-label {
            font-weight: 600;
            color: var(--gray-700);
            margin-bottom: 0.5rem;
            display: block;
        }

        .form-control {
            width: 100%;
            padding: 0.75rem;
            border: 1px solid var(--gray-300);
            border-radius: 8px;
            font-size: 1rem;
            transition: all 0.2s;
        }

        .form-control:focus {
            outline: none;
            border-color: var(--primary);
            box-shadow: 0 0 0 3px rgba(0, 112, 243, 0.1);
        }

        .btn {
            display: inline-flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.75rem 1.5rem;
            border: 1px solid transparent;
            border-radius: 8px;
            font-size: 1rem;
            font-weight: 500;
            text-decoration: none;
            cursor: pointer;
            transition: all 0.2s;
        }

        .btn-primary {
            background: var(--primary);
            color: white;
        }

        .btn-primary:hover {
            background: #0051cc;
            color: white;
        }

        .btn-outline-secondary {
            border-color: var(--gray-300);
            color: var(--gray-700);
        }

        .btn-outline-secondary:hover {
            background: var(--gray-100);
            color: var(--gray-900);
        }

        .alert {
            padding: 1rem;
            border-radius: 8px;
            margin-bottom: 1.5rem;
        }

        .alert-success {
            background: #dcfce7;
            color: #166534;
            border: 1px solid #bbf7d0;
        }

        .alert-danger {
            background: #fee2e2;
            color: #991b1b;
            border: 1px solid #fecaca;
        }

        .password-section {
            background: var(--gray-50);
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1.5rem;
            margin-top: 2rem;
        }

        .password-section h3 {
            color: var(--gray-800);
            margin-bottom: 1rem;
            font-size: 1.125rem;
        }

        .info-text {
            color: var(--gray-600);
            font-size: 0.875rem;
            margin-bottom: 1rem;
        }

        .stats-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 1rem;
            margin-bottom: 2rem;
        }

        .stat-card {
            background: var(--gray-50);
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1.5rem;
            text-align: center;
        }

        .stat-number {
            font-size: 2rem;
            font-weight: 700;
            color: var(--primary);
            margin-bottom: 0.5rem;
        }

        .stat-label {
            color: var(--gray-600);
            font-size: 0.875rem;
        }

        @media (max-width: 768px) {
            .main-container {
                margin: 1rem auto;
            }
            
            .profile-body {
                padding: 1.5rem;
            }
        }
    </style>
</head>
<body>
    <header class="header">
        <div class="header-content">
            <a href="dashboard.php" class="logo">
                <i class="fas fa-fire-extinguisher"></i>
                <?php echo APP_NAME; ?>
            </a>
            <a href="dashboard.php" class="btn btn-outline-secondary">
                <i class="fas fa-arrow-left"></i>
                Volver al Dashboard
            </a>
        </div>
    </header>

    <div class="main-container">
        <div class="profile-card">
            <div class="profile-header">
                <div class="profile-avatar">
                    <?php if ($foto_perfil && file_exists($foto_perfil)): ?>
                        <img src="<?php echo htmlspecialchars($foto_perfil); ?>" 
                             alt="Foto de perfil" 
                             style="width: 80px; height: 80px; border-radius: 50%; object-fit: cover;">
                    <?php else: ?>
                        <i class="fas fa-user"></i>
                    <?php endif; ?>
                </div>
                <h1 class="profile-name"><?php echo htmlspecialchars($user_data['nombre']); ?></h1>
                <p class="profile-role">
                    <i class="fas fa-shield-alt"></i>
                    <?php echo ucfirst($user_data['rol']); ?>
                </p>
            </div>

            <div class="profile-body">
                <?php if ($message): ?>
                    <div class="alert alert-success">
                        <i class="fas fa-check-circle"></i>
                        <?php echo htmlspecialchars($message); ?>
                    </div>
                <?php endif; ?>

                <?php if ($error): ?>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-circle"></i>
                        <?php echo htmlspecialchars($error); ?>
                    </div>
                <?php endif; ?>

                <!-- Estadísticas del usuario -->
                <div class="stats-grid">
                    <?php
                    $inspeccion = new Inspeccion();
                    $stats = $inspeccion->getStatsByUser($_SESSION['user_id']);
                    ?>
                    <div class="stat-card">
                        <div class="stat-number"><?php echo $stats['total'] ?? 0; ?></div>
                        <div class="stat-label">Inspecciones Totales</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?php echo $stats['completadas'] ?? 0; ?></div>
                        <div class="stat-label">Completadas</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-number"><?php echo $stats['borradores'] ?? 0; ?></div>
                        <div class="stat-label">Borradores</div>
                    </div>
                </div>

                <form method="POST" enctype="multipart/form-data">
                    <div class="form-group">
                        <label for="nombre" class="form-label">
                            <i class="fas fa-user"></i>
                            Nombre Completo
                        </label>
                        <input type="text" 
                               id="nombre" 
                               name="nombre" 
                               class="form-control" 
                               value="<?php echo htmlspecialchars($user_data['nombre']); ?>" 
                               required>
                    </div>

                    <div class="form-group">
                        <label for="email" class="form-label">
                            <i class="fas fa-envelope"></i>
                            Correo Electrónico
                        </label>
                        <input type="email" 
                               id="email" 
                               name="email" 
                               class="form-control" 
                               value="<?php echo htmlspecialchars($user_data['email']); ?>" 
                               required>
                    </div>

                    <div class="form-group">
                        <label for="foto_perfil" class="form-label">
                            <i class="fas fa-camera"></i>
                            Foto de Perfil
                        </label>
                        <input type="file" 
                               id="foto_perfil" 
                               name="foto_perfil" 
                               class="form-control" 
                               accept="image/*">
                        <small class="text-muted">Formatos permitidos: JPG, PNG, GIF. Tamaño máximo: 2MB</small>
                        <?php if ($foto_perfil): ?>
                            <div style="margin-top: 0.5rem;">
                                <img src="<?php echo htmlspecialchars($foto_perfil); ?>" 
                                     alt="Foto actual" 
                                     style="width: 60px; height: 60px; border-radius: 8px; object-fit: cover;">
                                <small class="text-muted d-block">Foto actual</small>
                            </div>
                        <?php endif; ?>
                    </div>

                    <div class="password-section">
                        <h3>
                            <i class="fas fa-lock"></i>
                            Cambiar Contraseña
                        </h3>
                        <p class="info-text">Deja estos campos vacíos si no deseas cambiar tu contraseña</p>

                        <div class="form-group">
                            <label for="password_actual" class="form-label">Contraseña Actual</label>
                            <input type="password" 
                                   id="password_actual" 
                                   name="password_actual" 
                                   class="form-control">
                        </div>

                        <div class="form-group">
                            <label for="nueva_password" class="form-label">Nueva Contraseña</label>
                            <input type="password" 
                                   id="nueva_password" 
                                   name="nueva_password" 
                                   class="form-control" 
                                   minlength="6">
                        </div>

                        <div class="form-group">
                            <label for="confirmar_password" class="form-label">Confirmar Nueva Contraseña</label>
                            <input type="password" 
                                   id="confirmar_password" 
                                   name="confirmar_password" 
                                   class="form-control" 
                                   minlength="6">
                        </div>
                    </div>

                    <div style="margin-top: 2rem; display: flex; gap: 1rem;">
                        <button type="submit" class="btn btn-primary">
                            <i class="fas fa-save"></i>
                            Guardar Cambios
                        </button>
                        <a href="dashboard.php" class="btn btn-outline-secondary">
                            <i class="fas fa-times"></i>
                            Cancelar
                        </a>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Validación de contraseñas en tiempo real
        document.getElementById('confirmar_password').addEventListener('input', function() {
            const nueva = document.getElementById('nueva_password').value;
            const confirmar = this.value;
            
            if (nueva && confirmar && nueva !== confirmar) {
                this.style.borderColor = 'var(--danger)';
            } else {
                this.style.borderColor = 'var(--gray-300)';
            }
        });
    </script>
</body>
</html>
