-- Crear base de datos
CREATE DATABASE IF NOT EXISTS sistema_inspeccion CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
USE sistema_inspeccion;

-- Tabla de usuarios
CREATE TABLE usuarios (
    id INT AUTO_INCREMENT PRIMARY KEY,
    nombre VARCHAR(100) NOT NULL,
    email VARCHAR(100) UNIQUE NOT NULL,
    password VARCHAR(255) NOT NULL,
    rol ENUM('admin', 'inspector') DEFAULT 'inspector',
    activo BOOLEAN DEFAULT TRUE,
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Tabla de inmuebles
CREATE TABLE inmuebles (
    id INT AUTO_INCREMENT PRIMARY KEY,
    nombre VARCHAR(200) NOT NULL,
    direccion TEXT NOT NULL,
    telefono VARCHAR(20),
    activo BOOLEAN DEFAULT TRUE,
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Tabla de tipos de inspección
CREATE TABLE tipos_inspeccion (
    id INT AUTO_INCREMENT PRIMARY KEY,
    nombre VARCHAR(100) NOT NULL,
    descripcion TEXT,
    activo BOOLEAN DEFAULT TRUE
);

-- Tabla de secciones de inspección
CREATE TABLE secciones_inspeccion (
    id INT AUTO_INCREMENT PRIMARY KEY,
    tipo_inspeccion_id INT,
    nombre VARCHAR(100) NOT NULL,
    orden INT DEFAULT 0,
    FOREIGN KEY (tipo_inspeccion_id) REFERENCES tipos_inspeccion(id)
);

-- Tabla de elementos de inspección
CREATE TABLE elementos_inspeccion (
    id INT AUTO_INCREMENT PRIMARY KEY,
    seccion_id INT,
    descripcion TEXT NOT NULL,
    orden INT DEFAULT 0,
    FOREIGN KEY (seccion_id) REFERENCES secciones_inspeccion(id)
);

-- Tabla de inspecciones realizadas
CREATE TABLE inspecciones (
    id INT AUTO_INCREMENT PRIMARY KEY,
    inmueble_id INT,
    inspector_id INT,
    tipo_inspeccion_id INT,
    numero_contrato VARCHAR(50),
    fecha_inspeccion DATE NOT NULL,
    comentarios TEXT,
    firma_inspector VARCHAR(200),
    contratista_nombre VARCHAR(200),
    contratista_direccion TEXT,
    contratista_licencia VARCHAR(100),
    estado ENUM('borrador', 'completada', 'aprobada') DEFAULT 'borrador',
    fecha_creacion TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (inmueble_id) REFERENCES inmuebles(id),
    FOREIGN KEY (inspector_id) REFERENCES usuarios(id),
    FOREIGN KEY (tipo_inspeccion_id) REFERENCES tipos_inspeccion(id)
);

-- Tabla de respuestas de inspección
CREATE TABLE respuestas_inspeccion (
    id INT AUTO_INCREMENT PRIMARY KEY,
    inspeccion_id INT,
    elemento_id INT,
    respuesta ENUM('si', 'no', 'nc') NOT NULL,
    observaciones TEXT,
    FOREIGN KEY (inspeccion_id) REFERENCES inspecciones(id) ON DELETE CASCADE,
    FOREIGN KEY (elemento_id) REFERENCES elementos_inspeccion(id)
);
