-- Agregar campos para el sistema de aprobación
-- Ejecutar este script para habilitar la funcionalidad de aprobación

-- Verificar si las columnas ya existen antes de agregarlas
SET @sql = '';

-- Agregar aprobador_id si no existe
SELECT COUNT(*) INTO @col_exists 
FROM information_schema.columns 
WHERE table_schema = DATABASE() 
AND table_name = 'inspecciones' 
AND column_name = 'aprobador_id';

IF @col_exists = 0 THEN
    SET @sql = CONCAT(@sql, 'ALTER TABLE inspecciones ADD COLUMN aprobador_id INT NULL AFTER estado;');
END IF;

-- Agregar fecha_aprobacion si no existe
SELECT COUNT(*) INTO @col_exists 
FROM information_schema.columns 
WHERE table_schema = DATABASE() 
AND table_name = 'inspecciones' 
AND column_name = 'fecha_aprobacion';

IF @col_exists = 0 THEN
    SET @sql = CONCAT(@sql, 'ALTER TABLE inspecciones ADD COLUMN fecha_aprobacion DATETIME NULL AFTER aprobador_id;');
END IF;

-- Agregar comentarios_aprobacion si no existe
SELECT COUNT(*) INTO @col_exists 
FROM information_schema.columns 
WHERE table_schema = DATABASE() 
AND table_name = 'inspecciones' 
AND column_name = 'comentarios_aprobacion';

IF @col_exists = 0 THEN
    SET @sql = CONCAT(@sql, 'ALTER TABLE inspecciones ADD COLUMN comentarios_aprobacion TEXT NULL AFTER fecha_aprobacion;');
END IF;

-- Agregar rechazador_id si no existe
SELECT COUNT(*) INTO @col_exists 
FROM information_schema.columns 
WHERE table_schema = DATABASE() 
AND table_name = 'inspecciones' 
AND column_name = 'rechazador_id';

IF @col_exists = 0 THEN
    SET @sql = CONCAT(@sql, 'ALTER TABLE inspecciones ADD COLUMN rechazador_id INT NULL AFTER comentarios_aprobacion;');
END IF;

-- Agregar fecha_rechazo si no existe
SELECT COUNT(*) INTO @col_exists 
FROM information_schema.columns 
WHERE table_schema = DATABASE() 
AND table_name = 'inspecciones' 
AND column_name = 'fecha_rechazo';

IF @col_exists = 0 THEN
    SET @sql = CONCAT(@sql, 'ALTER TABLE inspecciones ADD COLUMN fecha_rechazo DATETIME NULL AFTER rechazador_id;');
END IF;

-- Agregar motivo_rechazo si no existe
SELECT COUNT(*) INTO @col_exists 
FROM information_schema.columns 
WHERE table_schema = DATABASE() 
AND table_name = 'inspecciones' 
AND column_name = 'motivo_rechazo';

IF @col_exists = 0 THEN
    SET @sql = CONCAT(@sql, 'ALTER TABLE inspecciones ADD COLUMN motivo_rechazo TEXT NULL AFTER fecha_rechazo;');
END IF;

-- Ejecutar las alteraciones si hay alguna
IF LENGTH(@sql) > 0 THEN
    SET @sql = CONCAT(@sql, '');
    PREPARE stmt FROM @sql;
    EXECUTE stmt;
    DEALLOCATE PREPARE stmt;
    SELECT 'Campos de aprobación agregados exitosamente' as resultado;
ELSE
    SELECT 'Todos los campos de aprobación ya existen' as resultado;
END IF;

-- Agregar índices para mejorar rendimiento
CREATE INDEX IF NOT EXISTS idx_inspecciones_aprobador ON inspecciones(aprobador_id);
CREATE INDEX IF NOT EXISTS idx_inspecciones_rechazador ON inspecciones(rechazador_id);
CREATE INDEX IF NOT EXISTS idx_inspecciones_estado ON inspecciones(estado);

-- Agregar claves foráneas si no existen
-- Verificar si la FK ya existe
SELECT COUNT(*) INTO @fk_exists 
FROM information_schema.table_constraints 
WHERE table_schema = DATABASE() 
AND table_name = 'inspecciones' 
AND constraint_name = 'fk_inspecciones_aprobador';

IF @fk_exists = 0 THEN
    ALTER TABLE inspecciones 
    ADD CONSTRAINT fk_inspecciones_aprobador 
    FOREIGN KEY (aprobador_id) REFERENCES usuarios(id) ON DELETE SET NULL;
END IF;

-- Verificar si la FK ya existe
SELECT COUNT(*) INTO @fk_exists 
FROM information_schema.table_constraints 
WHERE table_schema = DATABASE() 
AND table_name = 'inspecciones' 
AND constraint_name = 'fk_inspecciones_rechazador';

IF @fk_exists = 0 THEN
    ALTER TABLE inspecciones 
    ADD CONSTRAINT fk_inspecciones_rechazador 
    FOREIGN KEY (rechazador_id) REFERENCES usuarios(id) ON DELETE SET NULL;
END IF;

SELECT 'Sistema de aprobación configurado correctamente' as mensaje;
