<?php
echo "<h2>🔌 Test de Conexión</h2>";

// Verificar que el archivo existe
if (file_exists('config/database.php')) {
    echo "<p>✅ Archivo config/database.php encontrado</p>";
    require_once 'config/database.php';
    
    // Verificar que la clase existe
    if (class_exists('Database')) {
        echo "<p>✅ Clase Database cargada correctamente</p>";
        
        try {
            $database = new Database();
            $db = $database->getConnection();
            
            if ($db) {
                echo "<p>✅ <strong>Conexión exitosa a la base de datos</strong></p>";
                
                // Probar una consulta simple
                $query = "SHOW TABLES";
                $stmt = $db->prepare($query);
                $stmt->execute();
                $tables = $stmt->fetchAll(PDO::FETCH_COLUMN);
                
                echo "<h3>📋 Tablas encontradas (" . count($tables) . "):</h3>";
                echo "<ul>";
                foreach ($tables as $table) {
                    echo "<li>$table</li>";
                }
                echo "</ul>";
                
                // Verificar específicamente la tabla equipos
                if (in_array('equipos', $tables)) {
                    echo "<p>✅ <strong>Tabla 'equipos' existe</strong></p>";
                    
                    // Contar equipos
                    $query = "SELECT COUNT(*) as total FROM equipos";
                    $stmt = $db->prepare($query);
                    $stmt->execute();
                    $count = $stmt->fetch(PDO::FETCH_ASSOC);
                    echo "<p>📦 Equipos registrados: <strong>" . $count['total'] . "</strong></p>";
                } else {
                    echo "<p>❌ <strong>Tabla 'equipos' NO existe</strong></p>";
                    echo "<p>🔧 <strong>Acción:</strong> Ejecuta el script SQL para crear la tabla</p>";
                }
                
            } else {
                echo "<p>❌ Error: No se pudo conectar a la base de datos</p>";
            }
            
        } catch (Exception $e) {
            echo "<p>❌ <strong>Error de conexión:</strong> " . $e->getMessage() . "</p>";
        }
        
    } else {
        echo "<p>❌ Error: Clase Database no encontrada</p>";
    }
    
} else {
    echo "<p>❌ Error: Archivo config/database.php no encontrado</p>";
    echo "<p>📁 Archivos en config/:</p>";
    if (is_dir('config')) {
        $files = scandir('config');
        echo "<ul>";
        foreach ($files as $file) {
            if ($file != '.' && $file != '..') {
                echo "<li>$file</li>";
            }
        }
        echo "</ul>";
    } else {
        echo "<p>❌ Directorio 'config' no existe</p>";
    }
}

echo "<hr>";
echo "<h3>🚀 Próximos pasos:</h3>";
echo "<ol>";
echo "<li>Si todo está ✅, ve a <a href='gestionar_equipos.php'>Gestionar Equipos</a></li>";
echo "<li>Si falta la tabla equipos, ejecuta el script SQL</li>";
echo "<li>Si hay errores de conexión, revisa config/database.php</li>";
echo "</ol>";

echo "<p><a href='dashboard.php'>← Volver al Dashboard</a></p>";
?>
