<?php
session_start();
echo "<h1>🔍 Test de Edición - Diagnóstico Completo</h1>";

// 1. Verificar archivos
echo "<h2>📁 Verificación de Archivos:</h2>";
$archivos_necesarios = [
    'editar_inspeccion.php',
    'inspecciones.php',
    'config/config.php',
    'models/Inspeccion.php'
];

foreach ($archivos_necesarios as $archivo) {
    $existe = file_exists($archivo);
    echo "• {$archivo}: " . ($existe ? "✅ EXISTE" : "❌ NO EXISTE") . "<br>";
    if ($existe) {
        echo "  - Tamaño: " . filesize($archivo) . " bytes<br>";
        echo "  - Permisos: " . substr(sprintf('%o', fileperms($archivo)), -4) . "<br>";
    }
}

// 2. Verificar sesión
echo "<h2>👤 Verificación de Sesión:</h2>";
echo "• session_id(): " . session_id() . "<br>";
echo "• user_id: " . ($_SESSION['user_id'] ?? 'NO DEFINIDO') . "<br>";
echo "• user_name: " . ($_SESSION['user_name'] ?? 'NO DEFINIDO') . "<br>";
echo "• rol: " . ($_SESSION['rol'] ?? 'NO DEFINIDO') . "<br>";

// 3. Función isAdmin
function isAdmin() {
    return isset($_SESSION['rol']) && $_SESSION['rol'] === 'administrador';
}
echo "• isAdmin(): " . (isAdmin() ? "✅ SÍ" : "❌ NO") . "<br>";

// 4. Probar conexión BD
echo "<h2>🗄️ Verificación de Base de Datos:</h2>";
try {
    require_once 'config/database.php';
    $database = new Database();
    $db = $database->getConnection();
    echo "• Conexión BD: ✅ OK<br>";
    
    // Obtener inspecciones
    $stmt = $db->query("SELECT id, estado, inspector_id FROM inspecciones LIMIT 5");
    $inspecciones = $stmt->fetchAll();
    echo "• Total inspecciones (primeras 5): " . count($inspecciones) . "<br>";
    
    foreach ($inspecciones as $insp) {
        $puede_editar = ($insp['estado'] === 'borrador' && $insp['inspector_id'] == ($_SESSION['user_id'] ?? 0)) || isAdmin();
        echo "  - ID: {$insp['id']}, Estado: {$insp['estado']}, Inspector: {$insp['inspector_id']}, Puede editar: " . ($puede_editar ? "✅" : "❌") . "<br>";
    }
    
} catch (Exception $e) {
    echo "• Error BD: ❌ " . $e->getMessage() . "<br>";
}

// 5. Probar enlaces directos
echo "<h2>🔗 Enlaces de Prueba:</h2>";
$test_ids = [1, 2, 3];
foreach ($test_ids as $id) {
    echo "• <a href='editar_inspeccion.php?id={$id}' target='_blank' style='color: blue; text-decoration: underline;'>Probar editar_inspeccion.php?id={$id}</a><br>";
}

// 6. Generar HTML de prueba
echo "<h2>🧪 Botón de Prueba:</h2>";
echo '<div style="border: 2px solid red; padding: 10px; margin: 10px 0;">';
echo '<a href="editar_inspeccion.php?id=1" class="btn btn-sm btn-outline-success" style="background: green; color: white; padding: 10px; text-decoration: none; border-radius: 5px;">';
echo '<i class="fas fa-edit"></i> EDITAR PRUEBA';
echo '</a>';
echo '</div>';

// 7. JavaScript de prueba
echo "<h2>⚡ Prueba JavaScript:</h2>";
?>
<script>
console.log('🚀 Test JavaScript iniciado');

function testEdit(id) {
    console.log('🔧 Probando edición para ID:', id);
    const url = 'editar_inspeccion.php?id=' + id;
    console.log('🔗 URL:', url);
    
    // Probar si el archivo existe
    fetch(url, { method: 'HEAD' })
        .then(response => {
            console.log('📡 Respuesta:', response.status);
            if (response.ok) {
                console.log('✅ Archivo accesible');
                window.location.href = url;
            } else {
                console.log('❌ Error:', response.status);
                alert('Error: ' + response.status);
            }
        })
        .catch(error => {
            console.log('💥 Error de red:', error);
            alert('Error de red: ' + error.message);
        });
}

// Probar automáticamente
document.addEventListener('DOMContentLoaded', function() {
    console.log('📄 DOM cargado');
    
    // Verificar si jQuery está disponible
    if (typeof $ !== 'undefined') {
        console.log('✅ jQuery disponible');
    } else {
        console.log('❌ jQuery NO disponible');
    }
    
    // Verificar Bootstrap
    if (typeof bootstrap !== 'undefined') {
        console.log('✅ Bootstrap disponible');
    } else {
        console.log('❌ Bootstrap NO disponible');
    }
});
</script>

<button onclick="testEdit(1)" style="background: blue; color: white; padding: 10px; border: none; border-radius: 5px; cursor: pointer;">
    🧪 PROBAR EDICIÓN CON JAVASCRIPT
</button>

<h2>📋 Instrucciones:</h2>
<ol>
    <li><strong>Abre la consola del navegador</strong> (F12 → Console)</li>
    <li><strong>Haz clic en los enlaces</strong> de prueba arriba</li>
    <li><strong>Haz clic en el botón JavaScript</strong> y revisa la consola</li>
    <li><strong>Verifica</strong> que todos los archivos existan</li>
    <li><strong>Confirma</strong> que tu sesión esté activa</li>
</ol>

<p><a href="inspecciones.php" style="color: blue;">🔙 Volver a inspecciones.php</a></p>
