<?php
require_once 'config/config.php';

requireLogin();

// Función para verificar si un archivo existe
function verificarArchivo($archivo) {
    return file_exists($archivo) ? '✅' : '❌';
}

// Función para verificar enlaces en un archivo
function verificarEnlaces($archivo) {
    if (!file_exists($archivo)) return [];
    
    $contenido = file_get_contents($archivo);
    $enlaces = [];
    
    // Buscar enlaces href
    preg_match_all('/href=["\']([^"\']+)["\']/', $contenido, $matches);
    foreach ($matches[1] as $enlace) {
        if (strpos($enlace, '.php') !== false && strpos($enlace, 'http') === false) {
            $enlaces[] = $enlace;
        }
    }
    
    // Buscar enlaces en JavaScript
    preg_match_all('/window\.location\.href\s*=\s*["\']([^"\']+)["\']/', $contenido, $matches);
    foreach ($matches[1] as $enlace) {
        if (strpos($enlace, '.php') !== false) {
            $enlaces[] = $enlace;
        }
    }
    
    return array_unique($enlaces);
}

$archivos_principales = [
    'login.php',
    'dashboard.php',
    'inspecciones.php',
    'nueva_inspeccion.php',
    'editar_inspeccion.php',
    'ver_inspeccion.php',
    'inmuebles.php',
    'gestionar_equipos.php',
    'usuarios.php',
    'perfil.php',
    'informes.php',
    'admin_inspecciones.php',
    'admin_elementos.php',
    'firmar_inspeccion.php',
    'generar_pdf_simple.php',
    'logout.php'
];
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Verificación de Navegación - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { background-color: #f8f9fa; }
        .card { margin-bottom: 1.5rem; }
        .archivo-ok { color: #28a745; }
        .archivo-error { color: #dc3545; }
        .enlace-ok { color: #28a745; }
        .enlace-error { color: #dc3545; }
        .enlace-warning { color: #ffc107; }
    </style>
</head>
<body>
    <div class="container py-4">
        <div class="row">
            <div class="col-12">
                <div class="bg-primary text-white p-4 rounded mb-4">
                    <h1><i class="fas fa-sitemap"></i> Verificación de Navegación</h1>
                    <p class="mb-0">Análisis completo de enlaces y navegación del sistema</p>
                </div>
            </div>
        </div>

        <!-- Verificación de Archivos Principales -->
        <div class="row">
            <div class="col-md-6">
                <div class="card">
                    <div class="card-header">
                        <h5><i class="fas fa-file-code"></i> Archivos Principales</h5>
                    </div>
                    <div class="card-body">
                        <?php foreach ($archivos_principales as $archivo): ?>
                            <div class="d-flex justify-content-between align-items-center mb-2">
                                <span><?php echo $archivo; ?></span>
                                <span class="<?php echo file_exists($archivo) ? 'archivo-ok' : 'archivo-error'; ?>">
                                    <?php echo verificarArchivo($archivo); ?>
                                </span>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>

            <div class="col-md-6">
                <div class="card">
                    <div class="card-header">
                        <h5><i class="fas fa-users-cog"></i> Permisos de Usuario</h5>
                    </div>
                    <div class="card-body">
                        <div class="mb-3">
                            <strong>Usuario Actual:</strong> <?php echo $_SESSION['user_name']; ?><br>
                            <strong>Rol:</strong> <?php echo $_SESSION['rol']; ?><br>
                            <strong>Es Admin:</strong> <?php echo isAdmin() ? '✅ SÍ' : '❌ NO'; ?>
                        </div>
                        
                        <h6>Acceso a Páginas:</h6>
                        <div class="small">
                            <div>📋 Inspecciones: ✅ Todos</div>
                            <div>👥 Usuarios: <?php echo isAdmin() ? '✅ Admin' : '❌ Solo Admin'; ?></div>
                            <div>⚙️ Admin Inspecciones: <?php echo isAdmin() ? '✅ Admin' : '❌ Solo Admin'; ?></div>
                            <div>🏠 Inmuebles: ✅ Todos</div>
                            <div>🔧 Equipos: ✅ Todos</div>
                            <div>📊 Informes: ✅ Todos</div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Mapa de Navegación -->
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h5><i class="fas fa-route"></i> Mapa de Navegación</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <!-- Dashboard -->
                            <div class="col-md-4 mb-4">
                                <div class="border rounded p-3">
                                    <h6 class="text-primary"><i class="fas fa-home"></i> Dashboard</h6>
                                    <div class="small">
                                        <div>→ <a href="nueva_inspeccion.php">Nueva Inspección</a></div>
                                        <div>→ <a href="inspecciones.php">Ver Inspecciones</a></div>
                                        <div>→ <a href="inmuebles.php">Gestionar Inmuebles</a></div>
                                        <div>→ <a href="gestionar_equipos.php">Gestionar Equipos</a></div>
                                        <div>→ <a href="informes.php">Informes</a></div>
                                        <div>→ <a href="perfil.php">Mi Perfil</a></div>
                                        <?php if (isAdmin()): ?>
                                        <div>→ <a href="usuarios.php">Gestionar Usuarios</a></div>
                                        <div>→ <a href="admin_inspecciones.php">Admin Inspecciones</a></div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>

                            <!-- Inspecciones -->
                            <div class="col-md-4 mb-4">
                                <div class="border rounded p-3">
                                    <h6 class="text-success"><i class="fas fa-clipboard-list"></i> Inspecciones</h6>
                                    <div class="small">
                                        <div>→ <a href="nueva_inspeccion.php">Nueva Inspección</a></div>
                                        <div>→ <a href="ver_inspeccion.php?id=1">Ver Inspección</a></div>
                                        <div>→ <a href="editar_inspeccion.php?id=1">Editar Inspección</a></div>
                                        <div>→ <a href="firmar_inspeccion.php?id=1">Firmar Inspección</a></div>
                                        <div>→ <a href="generar_pdf_simple.php?id=1">Generar PDF</a></div>
                                        <div>→ <a href="dashboard.php">← Dashboard</a></div>
                                    </div>
                                </div>
                            </div>

                            <!-- Administración -->
                            <div class="col-md-4 mb-4">
                                <div class="border rounded p-3">
                                    <h6 class="text-warning"><i class="fas fa-cogs"></i> Administración</h6>
                                    <div class="small">
                                        <?php if (isAdmin()): ?>
                                        <div>→ <a href="usuarios.php">Gestionar Usuarios</a></div>
                                        <div>→ <a href="admin_inspecciones.php">Admin Inspecciones</a></div>
                                        <div>→ <a href="admin_elementos.php?tipo_id=1">Admin Elementos</a></div>
                                        <div>→ <a href="inmuebles.php">Gestionar Inmuebles</a></div>
                                        <div>→ <a href="gestionar_equipos.php">Gestionar Equipos</a></div>
                                        <?php else: ?>
                                        <div class="text-muted">Solo para administradores</div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Análisis de Enlaces por Archivo -->
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h5><i class="fas fa-link"></i> Análisis de Enlaces</h5>
                    </div>
                    <div class="card-body">
                        <?php foreach ($archivos_principales as $archivo): ?>
                            <?php if (file_exists($archivo)): ?>
                                <div class="mb-3">
                                    <h6 class="text-primary"><?php echo $archivo; ?></h6>
                                    <?php 
                                    $enlaces = verificarEnlaces($archivo);
                                    if (empty($enlaces)): ?>
                                        <div class="text-muted small">No se encontraron enlaces PHP</div>
                                    <?php else: ?>
                                        <div class="row">
                                            <?php foreach ($enlaces as $enlace): ?>
                                                <?php 
                                                $enlace_limpio = preg_replace('/\?.*/', '', $enlace);
                                                $existe = file_exists($enlace_limpio);
                                                $clase = $existe ? 'enlace-ok' : 'enlace-error';
                                                $icono = $existe ? '✅' : '❌';
                                                ?>
                                                <div class="col-md-3 small">
                                                    <span class="<?php echo $clase; ?>">
                                                        <?php echo $icono; ?> <?php echo $enlace; ?>
                                                    </span>
                                                </div>
                                            <?php endforeach; ?>
                                        </div>
                                    <?php endif; ?>
                                </div>
                                <hr>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>

        <!-- Pruebas de Navegación -->
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h5><i class="fas fa-vial"></i> Pruebas de Navegación</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <h6>🧪 Flujo Principal</h6>
                                <div class="small">
                                    <div>1. <a href="dashboard.php" target="_blank">Dashboard</a></div>
                                    <div>2. <a href="nueva_inspeccion.php" target="_blank">Nueva Inspección</a></div>
                                    <div>3. <a href="inspecciones.php" target="_blank">Lista Inspecciones</a></div>
                                    <div>4. <a href="ver_inspeccion.php?id=1" target="_blank">Ver Inspección</a></div>
                                    <div>5. <a href="editar_inspeccion.php?id=1" target="_blank">Editar Inspección</a></div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <h6>⚙️ Flujo Administrativo</h6>
                                <div class="small">
                                    <?php if (isAdmin()): ?>
                                    <div>1. <a href="inmuebles.php" target="_blank">Gestionar Inmuebles</a></div>
                                    <div>2. <a href="usuarios.php" target="_blank">Gestionar Usuarios</a></div>
                                    <div>3. <a href="admin_inspecciones.php" target="_blank">Admin Inspecciones</a></div>
                                    <div>4. <a href="gestionar_equipos.php" target="_blank">Gestionar Equipos</a></div>
                                    <div>5. <a href="informes.php" target="_blank">Informes</a></div>
                                    <?php else: ?>
                                    <div class="text-muted">Requiere permisos de administrador</div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Acciones -->
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body text-center">
                        <h6>🔧 Acciones de Verificación</h6>
                        <div class="btn-group" role="group">
                            <a href="dashboard.php" class="btn btn-primary">
                                <i class="fas fa-home"></i> Ir al Dashboard
                            </a>
                            <a href="inspecciones.php" class="btn btn-success">
                                <i class="fas fa-clipboard-list"></i> Ver Inspecciones
                            </a>
                            <a href="nueva_inspeccion.php" class="btn btn-info">
                                <i class="fas fa-plus"></i> Nueva Inspección
                            </a>
                            <?php if (isAdmin()): ?>
                            <a href="admin_inspecciones.php" class="btn btn-warning">
                                <i class="fas fa-cogs"></i> Administrar
                            </a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
